@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -23,14 +22,12 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #define __COLLISION_H__
 
 #include "VCommon.h"
-#include "VApp.h"
+#include "helpers/VMath.h"
 
 class Block;
 class Entity;
 class Zone;
 
-namespace vapp {
-
   class CollisionSystem;
   struct GridCell;
 
@@ -105,7 +102,7 @@ namespace vapp {
 
     /* helpers */
     ColElement* _getColElement(T* id){
-      for(int i=0; i<m_ColElements.size(); i++){
+      for(unsigned int i=0; i<m_ColElements.size(); i++){
 	if(m_ColElements[i]->id == id){
 	  return m_ColElements[i];
 	}
@@ -117,7 +114,7 @@ namespace vapp {
     void _addColElementInCells(ColElement* pColElem);
 
     ColElement* _getAndRemoveColElement(T* id){
-      for(int i=0; i<m_ColElements.size(); i++){
+      for(unsigned int i=0; i<m_ColElements.size(); i++){
 	if(m_ColElements[i]->id == id){
 	  ColElement* pColElem = m_ColElements[i];
 	  m_ColElements.erase(m_ColElements.begin()+i);
@@ -150,14 +147,14 @@ namespace vapp {
   ===========================================================================*/
   class CollisionSystem {
   public:
-    CollisionSystem() {m_pGrid = NULL; m_bDebugFlag=false;}
-    ~CollisionSystem() {reset();}
+    CollisionSystem();
+    ~CollisionSystem();
     
     /* Methods */
     void reset(void);
     void setDims(float fMinX,float fMinY,
 		 float fMaxX,float fMaxY,
-		 int numberBackgroundLayers,
+		 unsigned int numberBackgroundLayers,
 		 std::vector<Vector2f>& layerOffsets);
     void defineLine(float x1,float y1,float x2,float y2, float grip);
 
@@ -249,7 +246,5 @@ namespace vapp {
     int _AddContactToList(dContact *pContacts,int nNumContacts,dContact *pc,int nMaxContacts);
   };
 
-}
-
 #endif
 
