@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -23,40 +22,37 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #define __CREDITS_H__
 
 #include "VCommon.h"
-#include "GUI.h"
+#include "gui/basic/GUI.h"
 
-namespace vapp {
-
-  /*===========================================================================
+/*===========================================================================
   Credits class
-  ===========================================================================*/
-  class Credits {
-    public:
-      /* Types */
-      struct Entry {
-        std::string Left, Right;
-      };
-    
-      /* Construction/destruction */
-      Credits();
-      ~Credits();
-      
-      /* Methods */
-      void init(App* v_pApp, float fBackgroundReplayLength,float fFadeInLength,float fFadeOutLength,const char *pcCredits);
-      void render(float fTime);
-      bool isFinished(void);
-      
-    private:
-      /* Data */
-      std::vector<Entry *> m_Entries;
-      float m_fTime,m_fReplayLength,m_fFadeIn,m_fFadeOut;
-      bool m_bBlackBackground;
-      FontManager* m_font;
-      App *m_pApp;
-      bool m_bFinished;
+===========================================================================*/
+class Credits {
+public:
+  /* Types */
+  struct Entry {
+    std::string Left, Right;
   };
-  
-}
-
+    
+  /* Construction/destruction */
+  Credits();
+  ~Credits();
+      
+  /* Methods */
+  void init(int backgroundReplayLength,
+	    int fadeInLength,
+	    int fadeOutLength,
+	    const char *pcCredits);
+  void render(int i_time);
+  bool isFinished(void);
+      
+private:
+  /* Data */
+  std::vector<Entry *> m_Entries;
+  int m_time,m_replayLength,m_fadeIn,m_fadeOut;
+  bool m_bBlackBackground;
+  FontManager* m_font;
+  bool m_bFinished;
+};
 
 #endif
