@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -25,7 +24,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "VCommon.h"
 #include "helpers/VExcept.h"
 
-namespace vapp {
 
   /*===========================================================================
   Output buffer section
@@ -63,18 +61,17 @@ namespace vapp {
       const char *convertOutputToInput(void);
       
       /* Some I/O */
-      void write(std::string s);
-
-      void read(std::string &s);
-
-      template<typename _T> void operator <<(_T n) {
-        writeBuf_LE(reinterpret_cast<const char *>(&n),sizeof(_T));
-      }
-      
-      template<typename _T> void operator >>(_T &n) {
-        readBuf_LE(reinterpret_cast<char *>(&n),sizeof(_T));
-      }
-      
+      void operator <<(bool n);
+      void operator >>(bool &n);
+      void operator <<(int n);
+      void operator >>(int &n);
+      void operator <<(unsigned int n);
+      void operator >>(unsigned int &n);
+      void operator <<(float n);
+      void operator >>(float &n);
+      void operator <<(std::string s);
+      void operator >>(std::string &s); 
+    
       /* Data interface */
       bool isOutput(void) {if(m_bInit && m_bOutput) return true; return false;}
       bool isInput(void) {if(m_bInit && !m_bOutput) return true; return false;}
@@ -83,7 +80,7 @@ namespace vapp {
       /* Data */
       bool m_bInit;
       bool m_bOutput;
-    
+
       /* Data - for output */    
       int m_nPartSize;
       std::vector<DBufferPart *> m_Parts;
@@ -99,8 +96,6 @@ namespace vapp {
       void _FreeDBuffer(void);
       void _NewPart(void);
   };
-  
-}
 
 #endif
 
