@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -25,8 +24,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "xmscene/BasicSceneStructs.h"
 #include "xmscene/Zone.h"
 #include "xmscene/Entity.h"
+#include "Sound.h"
 
-namespace vapp {
   /*===========================================================================
     Game event types
     ===========================================================================*/
@@ -69,27 +68,25 @@ namespace vapp {
     GAME_EVENT_SETDYNAMICENTITYSELFROTATION = 32,
     GAME_EVENT_CAMERAROTATE                 = 33,
     GAME_EVENT_CAMERAADAPTTOGRAVITY         = 34,
-    GAME_EVENT_ADDFORCETOPLAYER             = 35
+    GAME_EVENT_ADDFORCETOPLAYER             = 35,
+    GAME_EVENT_SETCAMERAROTATIONSPEED       = 36,
+    GAME_EVENT_PLAYSOUND                    = 37,
+    GAME_EVENT_PLAYMUSIC                    = 38,
+    GAME_EVENT_STOPMUSIC                    = 39
   };
-}
 
-namespace vapp {
 class MotoGameEvent;
 
 struct RecordedGameEvent {
-  vapp::MotoGameEvent *Event;     /* Event itself */
-  bool bPassed;                   /* Whether we have passed it */
+  MotoGameEvent *Event;     /* Event itself */
+  bool bPassed;             /* Whether we have passed it */
 };
 
-}
-
 #include "xmscene/Scene.h"
 
-namespace vapp {
-
 class MotoGameEvent {
   public:
-  MotoGameEvent(float p_fEventTime);
+  MotoGameEvent(int p_eventTime);
   virtual ~MotoGameEvent();
 
   virtual void doAction(MotoGame *p_pMotoGame)          = 0;
@@ -101,16 +98,16 @@ class MotoGameEvent {
   virtual std::string toString() = 0;
 
   static MotoGameEvent* getUnserialized(DBuffer &Buffer, bool bDisplayInformation = false);
-  float getEventTime();
+  int getEventTime();
 
   protected:
-  float m_fEventTime;
+  int m_eventTime;
 };
 
 class MGE_PlayersDie : public MotoGameEvent {
  public:
-  MGE_PlayersDie(float p_fEventTime);
-  MGE_PlayersDie(float p_fEventTime, bool p_bKilledByWrecker);
+  MGE_PlayersDie(int p_eventTime);
+  MGE_PlayersDie(int p_eventTime, bool p_bKilledByWrecker);
   ~MGE_PlayersDie();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -127,8 +124,8 @@ class MGE_PlayersDie : public MotoGameEvent {
 
 class MGE_PlayerDies : public MotoGameEvent {
  public:
-  MGE_PlayerDies(float p_fEventTime);
-  MGE_PlayerDies(float p_fEventTime, bool p_bKilledByWrecker, int i_player);
+  MGE_PlayerDies(int p_eventTime);
+  MGE_PlayerDies(int p_eventTime, bool p_bKilledByWrecker, int i_player);
   ~MGE_PlayerDies();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -146,8 +143,8 @@ class MGE_PlayerDies : public MotoGameEvent {
 
 class MGE_PlayersEnterZone : public MotoGameEvent {
  public:
-  MGE_PlayersEnterZone(float p_fEventTime);
-  MGE_PlayersEnterZone(float p_fEventTime, Zone *p_zone);
+  MGE_PlayersEnterZone(int p_eventTime);
+  MGE_PlayersEnterZone(int p_eventTime, Zone *p_zone);
   ~MGE_PlayersEnterZone();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -164,8 +161,8 @@ class MGE_PlayersEnterZone : public MotoGameEvent {
 
 class MGE_PlayerEntersZone : public MotoGameEvent {
  public:
-  MGE_PlayerEntersZone(float p_fEventTime);
-  MGE_PlayerEntersZone(float p_fEventTime, Zone *p_zone, int i_player);
+  MGE_PlayerEntersZone(int p_eventTime);
+  MGE_PlayerEntersZone(int p_eventTime, Zone *p_zone, int i_player);
   ~MGE_PlayerEntersZone();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -183,8 +180,8 @@ class MGE_PlayerEntersZone : public MotoGameEvent {
 
 class MGE_PlayersLeaveZone : public MotoGameEvent {
  public:
-  MGE_PlayersLeaveZone(float p_fEventTime);
-  MGE_PlayersLeaveZone(float p_fEventTime, Zone *p_zone);
+  MGE_PlayersLeaveZone(int p_eventTime);
+  MGE_PlayersLeaveZone(int p_eventTime, Zone *p_zone);
   ~MGE_PlayersLeaveZone();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -201,8 +198,8 @@ class MGE_PlayersLeaveZone : public MotoGameEvent {
 
 class MGE_PlayerLeavesZone : public MotoGameEvent {
  public:
-  MGE_PlayerLeavesZone(float p_fEventTime);
-  MGE_PlayerLeavesZone(float p_fEventTime, Zone *p_zone, int i_player);
+  MGE_PlayerLeavesZone(int p_eventTime);
+  MGE_PlayerLeavesZone(int p_eventTime, Zone *p_zone, int i_player);
   ~MGE_PlayerLeavesZone();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -220,8 +217,8 @@ class MGE_PlayerLeavesZone : public MotoGameEvent {
 
 class MGE_PlayersToucheEntity : public MotoGameEvent {
  public:
-  MGE_PlayersToucheEntity(float p_fEventTime);
-  MGE_PlayersToucheEntity(float p_fEventTime, std::string p_entityID, bool p_bTouchedWithHead);
+  MGE_PlayersToucheEntity(int p_eventTime);
+  MGE_PlayersToucheEntity(int p_eventTime, std::string p_entityID, bool p_bTouchedWithHead);
   ~MGE_PlayersToucheEntity();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -239,8 +236,8 @@ class MGE_PlayersToucheEntity : public MotoGameEvent {
 
 class MGE_PlayerTouchesEntity : public MotoGameEvent {
  public:
-  MGE_PlayerTouchesEntity(float p_fEventTime);
-  MGE_PlayerTouchesEntity(float p_fEventTime, std::string p_entityID, bool p_bTouchedWithHead, int i_player);
+  MGE_PlayerTouchesEntity(int p_eventTime);
+  MGE_PlayerTouchesEntity(int p_eventTime, std::string p_entityID, bool p_bTouchedWithHead, int i_player);
   ~MGE_PlayerTouchesEntity();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -259,8 +256,8 @@ class MGE_PlayerTouchesEntity : public MotoGameEvent {
 
 class MGE_EntityDestroyed : public MotoGameEvent {
  public:
-  MGE_EntityDestroyed(float p_fEventTime);
-  MGE_EntityDestroyed(float p_fEventTime, std::string i_entityId, EntitySpeciality i_entityType, Vector2f i_entityPosition, float i_entitySize);
+  MGE_EntityDestroyed(int p_eventTime);
+  MGE_EntityDestroyed(int p_eventTime, std::string i_entityId, EntitySpeciality i_entityType, Vector2f i_entityPosition, float i_entitySize);
   ~MGE_EntityDestroyed();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -283,7 +280,7 @@ class MGE_EntityDestroyed : public MotoGameEvent {
 
 class MGE_ClearMessages : public MotoGameEvent {
  public:
-  MGE_ClearMessages(float p_fEventTime);
+  MGE_ClearMessages(int p_eventTime);
   ~MGE_ClearMessages();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -299,8 +296,8 @@ class MGE_ClearMessages : public MotoGameEvent {
 
 class MGE_PlaceInGameArrow : public MotoGameEvent {
  public:
-  MGE_PlaceInGameArrow(float p_fEventTime);
-  MGE_PlaceInGameArrow(float p_fEventTime, float p_x, float p_y, float p_angle);
+  MGE_PlaceInGameArrow(int p_eventTime);
+  MGE_PlaceInGameArrow(int p_eventTime, float p_x, float p_y, float p_angle);
   ~MGE_PlaceInGameArrow();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -318,8 +315,8 @@ class MGE_PlaceInGameArrow : public MotoGameEvent {
 
 class MGE_PlaceScreenarrow : public MotoGameEvent {
  public:
-  MGE_PlaceScreenarrow(float p_fEventTime);
-  MGE_PlaceScreenarrow(float p_fEventTime, float p_x, float p_y, float p_angle);
+  MGE_PlaceScreenarrow(int p_eventTime);
+  MGE_PlaceScreenarrow(int p_eventTime, float p_x, float p_y, float p_angle);
   ~MGE_PlaceScreenarrow();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -337,7 +334,7 @@ class MGE_PlaceScreenarrow : public MotoGameEvent {
 
 class MGE_HideArrow : public MotoGameEvent {
  public:
-  MGE_HideArrow(float p_fEventTime);
+  MGE_HideArrow(int p_eventTime);
   ~MGE_HideArrow();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -353,8 +350,8 @@ class MGE_HideArrow : public MotoGameEvent {
 
 class MGE_Message : public MotoGameEvent {
  public:
-  MGE_Message(float p_fEventTime);
-  MGE_Message(float p_fEventTime, std::string p_message);
+  MGE_Message(int p_eventTime);
+  MGE_Message(int p_eventTime, std::string p_message);
   ~MGE_Message();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -371,8 +368,8 @@ class MGE_Message : public MotoGameEvent {
 
 class MGE_MoveBlock : public MotoGameEvent {
  public:
-  MGE_MoveBlock(float p_fEventTime);
-  MGE_MoveBlock(float p_fEventTime, std::string p_blockID, float p_x, float p_y);
+  MGE_MoveBlock(int p_eventTime);
+  MGE_MoveBlock(int p_eventTime, std::string p_blockID, float p_x, float p_y);
   ~MGE_MoveBlock();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -390,8 +387,8 @@ class MGE_MoveBlock : public MotoGameEvent {
 
 class MGE_SetBlockPos : public MotoGameEvent {
  public:
-  MGE_SetBlockPos(float p_fEventTime);
-  MGE_SetBlockPos(float p_fEventTime, std::string p_blockID, float p_x, float p_y);
+  MGE_SetBlockPos(int p_eventTime);
+  MGE_SetBlockPos(int p_eventTime, std::string p_blockID, float p_x, float p_y);
   ~MGE_SetBlockPos();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -409,8 +406,8 @@ class MGE_SetBlockPos : public MotoGameEvent {
 
 class MGE_SetGravity : public MotoGameEvent {
  public:
-  MGE_SetGravity(float p_fEventTime);
-  MGE_SetGravity(float p_fEventTime, float p_x, float p_y);
+  MGE_SetGravity(int p_eventTime);
+  MGE_SetGravity(int p_eventTime, float p_x, float p_y);
   ~MGE_SetGravity();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -427,8 +424,8 @@ class MGE_SetGravity : public MotoGameEvent {
 
 class MGE_SetPlayersPosition : public MotoGameEvent {
  public:
-  MGE_SetPlayersPosition(float p_fEventTime);
-  MGE_SetPlayersPosition(float p_fEventTime, float p_x, float p_y, bool p_bRight);
+  MGE_SetPlayersPosition(int p_eventTime);
+  MGE_SetPlayersPosition(int p_eventTime, float p_x, float p_y, bool p_bRight);
   ~MGE_SetPlayersPosition();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -446,8 +443,8 @@ class MGE_SetPlayersPosition : public MotoGameEvent {
 
 class MGE_SetPlayerPosition : public MotoGameEvent {
  public:
-  MGE_SetPlayerPosition(float p_fEventTime);
-  MGE_SetPlayerPosition(float p_fEventTime, float p_x, float p_y, bool p_bRight, int i_player);
+  MGE_SetPlayerPosition(int p_eventTime);
+  MGE_SetPlayerPosition(int p_eventTime, float p_x, float p_y, bool p_bRight, int i_player);
   ~MGE_SetPlayerPosition();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -466,8 +463,8 @@ class MGE_SetPlayerPosition : public MotoGameEvent {
 
 class MGE_AddForceToPlayer : public MotoGameEvent {
  public:
-  MGE_AddForceToPlayer(float p_fEventTime);
-  MGE_AddForceToPlayer(float p_fEventTime, const Vector2f& i_force, int i_player);
+  MGE_AddForceToPlayer(int p_eventTime);
+  MGE_AddForceToPlayer(int p_eventTime, const Vector2f& i_force, int i_startTime, int i_endTime, int i_player);
   ~MGE_AddForceToPlayer();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -480,13 +477,14 @@ class MGE_AddForceToPlayer : public MotoGameEvent {
 
  private:
   Vector2f m_force;
+  int      m_startTime, m_endTime;
   int      m_player;
 };
 
 class MGE_SetEntityPos : public MotoGameEvent {
  public:
-  MGE_SetEntityPos(float p_fEventTime);
-  MGE_SetEntityPos(float p_fEventTime, std::string p_entityID, float p_x, float p_y);
+  MGE_SetEntityPos(int p_eventTime);
+  MGE_SetEntityPos(int p_eventTime, std::string p_entityID, float p_x, float p_y);
   ~MGE_SetEntityPos();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -504,8 +502,8 @@ class MGE_SetEntityPos : public MotoGameEvent {
 
 class MGE_SetBlockCenter : public MotoGameEvent {
  public:
-  MGE_SetBlockCenter(float p_fEventTime);
-  MGE_SetBlockCenter(float p_fEventTime, std::string p_blockID, float p_x, float p_y);
+  MGE_SetBlockCenter(int p_eventTime);
+  MGE_SetBlockCenter(int p_eventTime, std::string p_blockID, float p_x, float p_y);
   ~MGE_SetBlockCenter();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -523,8 +521,8 @@ class MGE_SetBlockCenter : public MotoGameEvent {
 
 class MGE_SetBlockRotation : public MotoGameEvent {
  public:
-  MGE_SetBlockRotation(float p_fEventTime);
-  MGE_SetBlockRotation(float p_fEventTime, std::string p_blockID, float p_angle);
+  MGE_SetBlockRotation(int p_eventTime);
+  MGE_SetBlockRotation(int p_eventTime, std::string p_blockID, float p_angle);
   ~MGE_SetBlockRotation();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -542,10 +540,10 @@ class MGE_SetBlockRotation : public MotoGameEvent {
 
 class MGE_SetDynamicBlockSelfRotation : public MotoGameEvent {
  public:
-  MGE_SetDynamicBlockSelfRotation(float p_fEventTime);
-  MGE_SetDynamicBlockSelfRotation(float p_fEventTime,
+  MGE_SetDynamicBlockSelfRotation(int p_eventTime);
+  MGE_SetDynamicBlockSelfRotation(int p_eventTime,
 				  std::string p_blockID,
-				  float p_fPeriod,
+				  int   p_period,
 				  int   p_startTime,
 				  int   p_endTime);
   ~MGE_SetDynamicBlockSelfRotation();
@@ -561,19 +559,19 @@ class MGE_SetDynamicBlockSelfRotation : public MotoGameEvent {
  private:
   std::string m_blockID;
   float m_angle;
-  float m_fPeriod;
+  int m_period;
   int   m_startTime;
   int   m_endTime;
 };
 
 class MGE_SetDynamicEntityRotation : public MotoGameEvent {
  public:
-  MGE_SetDynamicEntityRotation(float p_fEventTime);
-  MGE_SetDynamicEntityRotation(float p_fEventTime,
+  MGE_SetDynamicEntityRotation(int p_eventTime);
+  MGE_SetDynamicEntityRotation(int p_eventTime,
                                std::string p_entityID,
                                float p_fInitAngle,
                                float p_fRadius,
-                               float p_fPeriod,
+                               int   p_period,
                                int   p_startTime,
                                int   p_endTime);
   ~MGE_SetDynamicEntityRotation();
@@ -590,17 +588,17 @@ class MGE_SetDynamicEntityRotation : public MotoGameEvent {
   std::string m_entityID;
   float m_fInitAngle;
   float m_fRadius;
-  float m_fPeriod;
+  int   m_period;
   int   m_startTime;
   int   m_endTime;
 };
 
 class MGE_SetDynamicEntitySelfRotation : public MotoGameEvent {
  public:
-  MGE_SetDynamicEntitySelfRotation(float p_fEventTime);
-  MGE_SetDynamicEntitySelfRotation(float p_fEventTime,
+  MGE_SetDynamicEntitySelfRotation(int p_eventTime);
+  MGE_SetDynamicEntitySelfRotation(int p_eventTime,
 				  std::string p_entityID,
-				  float p_fPeriod,
+				  int   p_period,
 				  int   p_startTime,
 				  int   p_endTime);
   ~MGE_SetDynamicEntitySelfRotation();
@@ -616,19 +614,19 @@ class MGE_SetDynamicEntitySelfRotation : public MotoGameEvent {
  private:
   std::string m_entityID;
   float m_angle;
-  float m_fPeriod;
+  int m_period;
   int   m_startTime;
   int   m_endTime;
 };
 
 class MGE_SetDynamicEntityTranslation : public MotoGameEvent {
  public:
-  MGE_SetDynamicEntityTranslation(float p_fEventTime);
-  MGE_SetDynamicEntityTranslation(float p_fEventTime,  
+  MGE_SetDynamicEntityTranslation(int p_eventTime);
+  MGE_SetDynamicEntityTranslation(int p_eventTime,  
                                   std::string p_entityID,
                                   float p_x,
                                   float p_y,
-                                  float p_fPeriod,
+                                  int   p_period,
                                   int   p_startTime,
                                   int   p_endTime);
   ~MGE_SetDynamicEntityTranslation();
@@ -644,15 +642,15 @@ class MGE_SetDynamicEntityTranslation : public MotoGameEvent {
  private:
   std::string m_entityID;
   float m_x, m_y;
-  float m_fPeriod;
+  int   m_period;
   int   m_startTime;
   int   m_endTime;
 };
 
 class MGE_SetDynamicEntityNone : public MotoGameEvent {
  public:
-  MGE_SetDynamicEntityNone(float p_fEventTime);
-  MGE_SetDynamicEntityNone(float p_fEventTime, std::string p_entityID);
+  MGE_SetDynamicEntityNone(int p_eventTime);
+  MGE_SetDynamicEntityNone(int p_eventTime, std::string p_entityID);
   ~MGE_SetDynamicEntityNone();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -669,12 +667,12 @@ class MGE_SetDynamicEntityNone : public MotoGameEvent {
 
 class MGE_SetDynamicBlockRotation : public MotoGameEvent {
  public:
-  MGE_SetDynamicBlockRotation(float p_fEventTime);
-  MGE_SetDynamicBlockRotation(float p_fEventTime,
+  MGE_SetDynamicBlockRotation(int p_eventTime);
+  MGE_SetDynamicBlockRotation(int p_eventTime,
                               std::string p_blockID,
                               float p_fInitAngle,
                               float p_fRadius,
-                              float p_fPeriod,
+                              int   p_period,
                               int   p_startTime,
                               int   p_endTime);
   ~MGE_SetDynamicBlockRotation();
@@ -691,19 +689,19 @@ class MGE_SetDynamicBlockRotation : public MotoGameEvent {
   std::string m_blockID;
   float m_fInitAngle;
   float m_fRadius;
-  float m_fPeriod;
+  int   m_period;
   int   m_startTime;
   int   m_endTime;
 };
 
 class MGE_SetDynamicBlockTranslation : public MotoGameEvent {
  public:
-  MGE_SetDynamicBlockTranslation(float p_fEventTime);
-  MGE_SetDynamicBlockTranslation(float p_fEventTime,  
+  MGE_SetDynamicBlockTranslation(int p_eventTime);
+  MGE_SetDynamicBlockTranslation(int p_eventTime,  
                                  std::string p_blockID,
                                  float p_x,
                                  float p_y,
-                                 float p_fPeriod,
+                                 int   p_period,
                                  int   p_startTime,
                                  int   p_endTime);
   ~MGE_SetDynamicBlockTranslation();
@@ -719,15 +717,15 @@ class MGE_SetDynamicBlockTranslation : public MotoGameEvent {
  private:
   std::string m_blockID;
   float m_x, m_y;
-  float m_fPeriod;
+  int   m_period;
   int   m_startTime;
   int   m_endTime;
 };
 
 class MGE_SetDynamicBlockNone : public MotoGameEvent {
  public:
-  MGE_SetDynamicBlockNone(float p_fEventTime);
-  MGE_SetDynamicBlockNone(float p_fEventTime, std::string p_blockID);
+  MGE_SetDynamicBlockNone(int p_eventTime);
+  MGE_SetDynamicBlockNone(int p_eventTime, std::string p_blockID);
   ~MGE_SetDynamicBlockNone();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -744,8 +742,8 @@ class MGE_SetDynamicBlockNone : public MotoGameEvent {
 
 class MGE_CameraMove : public MotoGameEvent {
  public:
-  MGE_CameraMove(float p_fEventTime);
-  MGE_CameraMove(float p_fEventTime, float p_moveX, float p_moveY);
+  MGE_CameraMove(int p_eventTime);
+  MGE_CameraMove(int p_eventTime, float p_moveX, float p_moveY);
   ~MGE_CameraMove();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -762,8 +760,8 @@ class MGE_CameraMove : public MotoGameEvent {
 
 class MGE_CameraZoom : public MotoGameEvent {
  public:
-  MGE_CameraZoom(float p_fEventTime);
-  MGE_CameraZoom(float p_fEventTime, float p_zoom);
+  MGE_CameraZoom(int p_eventTime);
+  MGE_CameraZoom(int p_eventTime, float p_zoom);
   ~MGE_CameraZoom();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -780,8 +778,8 @@ class MGE_CameraZoom : public MotoGameEvent {
 
 class MGE_PenalityTime : public MotoGameEvent {
  public:
-  MGE_PenalityTime(float p_fEventTime);
-  MGE_PenalityTime(float p_fEventTime, float p_penatityTime);
+  MGE_PenalityTime(int p_eventTime);
+  MGE_PenalityTime(int p_eventTime, int p_penatityTime);
   ~MGE_PenalityTime();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -793,13 +791,13 @@ class MGE_PenalityTime : public MotoGameEvent {
   std::string toString();
 
  private:
-  float m_penalityTime;
+  int m_penalityTime;
 };
 
 class MGE_CameraRotate : public MotoGameEvent {
  public:
-  MGE_CameraRotate(float p_fEventTime);
-  MGE_CameraRotate(float p_fEventTime, float p_angle);
+  MGE_CameraRotate(int p_eventTime);
+  MGE_CameraRotate(int p_eventTime, float p_angle);
   ~MGE_CameraRotate();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -816,7 +814,7 @@ class MGE_CameraRotate : public MotoGameEvent {
 
 class MGE_CameraAdaptToGravity : public MotoGameEvent {
  public:
-  MGE_CameraAdaptToGravity(float p_fEventTime);
+  MGE_CameraAdaptToGravity(int p_eventTime);
   ~MGE_CameraAdaptToGravity();
 
   void doAction(MotoGame *p_pMotoGame);
@@ -830,6 +828,78 @@ class MGE_CameraAdaptToGravity : public MotoGameEvent {
  private:
 };
 
-}
+class MGE_SetCameraRotationSpeed : public MotoGameEvent {                                         
+ public:                                                                                        
+   MGE_SetCameraRotationSpeed(int p_eventTime);                                                    
+   MGE_SetCameraRotationSpeed(int p_eventTime, float p_speed);
+   ~MGE_SetCameraRotationSpeed();                                                                  
+                                                                                                     
+   void doAction(MotoGame *p_pMotoGame);                                                         
+   void serialize(DBuffer &Buffer);                                                              
+   void unserialize(DBuffer &Buffer);                                                            
+   static GameEventType SgetType();                                                              
+   GameEventType getType();                                                                      
+	                                                                                                       
+   std::string toString();                                                                       
+		                                                                                                 
+   private:     
+   float m_speed;                                                                                  
+};
+                
 
+class MGE_PlaySound : public MotoGameEvent {
+ public:
+  MGE_PlaySound(int p_eventTime);
+  MGE_PlaySound(int p_eventTime, std::string p_soundName, float p_volume = DEFAULT_SAMPLE_VOLUME);
+  ~MGE_PlaySound();
+  
+  void doAction(MotoGame *p_pMotoGame);                                                    
+  void serialize(DBuffer &Buffer);                                                         
+  void unserialize(DBuffer &Buffer);                                                       
+  static GameEventType SgetType();                                                         
+  GameEventType getType();                                                                 
+	                                                                                                  
+  std::string toString();        
+  
+  private:
+  
+  std::string m_soundName;
+  float m_volume;
+  
+};
+
+class MGE_PlayMusic : public MotoGameEvent {                                                                    
+ public:                                                                                                        
+   MGE_PlayMusic(int p_eventTime);                                                                               
+   MGE_PlayMusic(int p_eventTime, std::string p_musicName);                                                      
+   ~MGE_PlayMusic();                                                                                             
+                                                                                                                       
+   void doAction(MotoGame *p_pMotoGame);                                                                         
+   void serialize(DBuffer &Buffer);                                                                              
+   void unserialize(DBuffer &Buffer);                                                                            
+   static GameEventType SgetType();                                                                              
+   GameEventType getType();                                                                                      
+		                                                                                                                 
+   std::string toString();                                                                                       
+		                                                                                                                   
+   private:                                                                                                      
+		                                                                                                                     
+   std::string m_musicName;                                                                                      
+		                                                                                                                       
+};
+
+class MGE_StopMusic : public MotoGameEvent {                                                                    
+ public:                                                                                                        
+   MGE_StopMusic(int p_eventTime);                                                                                                                               
+   ~MGE_StopMusic();                                                                                             
+                                                                                                                       
+   void doAction(MotoGame *p_pMotoGame);                                                                         
+   void serialize(DBuffer &Buffer);                                                                              
+   void unserialize(DBuffer &Buffer);                                                                            
+   static GameEventType SgetType();                                                                              
+   GameEventType getType();                                                                                      
+		                                                                                                                 
+   std::string toString();                                                                                       
+		                                                                                                                       
+};                                
 #endif /* __MOTOGAMEEVENT_H__ */
