@@ -1,6 +1,5 @@
 /*=============================================================================
   XMOTO
-  Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
   This file is part of XMOTO.
 
@@ -24,16 +23,15 @@
  */
 #include "PhysSettings.h"
 #include "xmscene/Scene.h"
-
-namespace vapp {
-
-
+#include "helpers/Log.h"
+#include "GameEvents.h"
+#include "DBuffer.h"
+#include "Game.h"
   
   /*===========================================================================
     Decoding of event stream
     ===========================================================================*/
   void MotoGame::unserializeGameEvents(DBuffer *Buffer, std::vector<RecordedGameEvent *> *v_ReplayEvents, bool bDisplayInformation) {
-    MotoGameEvent *v_event;
     RecordedGameEvent *p;    
 
     try {
@@ -45,7 +43,7 @@ namespace vapp {
       v_ReplayEvents->push_back(p);
       }
     } catch(Exception &e) {
-      Log("** Warning ** : unable to unserialize game events !");
+      Logger::Log("** Warning ** : unable to unserialize game events !");
       throw e;
     }
   }
@@ -53,16 +51,16 @@ namespace vapp {
   /*===========================================================================
     Encoding of event buffer 
     ===========================================================================*/
-  void MotoGame::_SerializeGameEventQueue(DBuffer &Buffer, MotoGameEvent *pEvent) {
-    pEvent->serialize(Buffer);
+  void MotoGame::_SerializeGameEventQueue(DBuffer* Buffer, MotoGameEvent *pEvent) {
+    pEvent->serialize(*Buffer);
   }
 
   /*===========================================================================
     Serializer
     ===========================================================================*/
-  void MotoGame::getSerializedBikeState(BikeState *i_bikeState, float i_fTime, SerializedBikeState *pState) {
+  void MotoGame::getSerializedBikeState(BikeState *i_bikeState, int i_time, SerializedBikeState *pState) {
     /* Get. */
-    pState->fGameTime = i_fTime;
+    pState->fGameTime = GameApp::timeToFloat(i_time);
     
     if(i_bikeState->Dir == DD_LEFT) pState->cFlags = SER_BIKE_STATE_DIR_LEFT;
     else if(i_bikeState->Dir == DD_RIGHT) pState->cFlags = SER_BIKE_STATE_DIR_RIGHT;
@@ -160,6 +158,3 @@ namespace vapp {
     }
   }      
 
-}
-
-
