@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -42,6 +41,7 @@ Central place to keep many in-game text strings
 #define GAMETEXT_8BIT                 _("8-bit")
 #define GAMETEXT_ABORT                _("Quit level")
 #define GAMETEXT_ADDTOFAVORITE       _("Add to favorite")
+#define GAMETEXT_ADDTOBLACKLIST       _("Add to blacklist")
 #define GAMETEXT_ACTION               _("Action")
 #define GAMETEXT_ALL                  _("All (on this computer)")
 #define GAMETEXT_ALL_LEVELS           _("All levels")
@@ -49,15 +49,14 @@ Central place to keep many in-game text strings
                                         "to the Internet to look for more levels\n" \
                                         "and best times of other players?")
 #define GAMETEXT_ALLRECORDS           _("All (on this computer)")
-#define GAMETEXT_ALREADYUSED          _("Already used!")
 #define GAMETEXT_AUDIO                _("Audio")
 #define GAMETEXT_AUTHOR               _("Author")
+#define GAMETEXT_AUTOMATIC            _("Automatic")
 #define GAMETEXT_AUTOSAVEREPLAYS      _("Automatic saving of replays")
 #define GAMETEXT_AUTOZOOM             _("Auto zoom")
 #define GAMETEXT_BESTTIMES            _("Best Times")
 #define GAMETEXT_BESTPLAYER           _("Best player")
 #define GAMETEXT_BRAKE                _("Brake")
-#define GAMETEXT_BUILTINLEVELS        _("Built-In Levels")
 #define GAMETEXT_BY_PLAYER            _("(by %s)")
 #define GAMETEXT_CAMERAMOVEXDOWN      _("Move Camera to left")
 #define GAMETEXT_CAMERAMOVEXUP        _("Move Camera to right")
@@ -68,7 +67,11 @@ Central place to keep many in-game text strings
 #define GAMETEXT_CHANGEDIR            _("Change direction")
 #define GAMETEXT_CHANGEKEY            _("Change Key...")
 #define GAMETEXT_CHECKINGFORLEVELS    _("Checking for new or updated levels...")
+#define GAMETEXT_CHILDREN_COMPLIANT   _("I'm a child")
 #define GAMETEXT_CHOOSELEVEL          _("Choose Level")
+#define GAMETEXT_CLEAN                _("Clean")
+#define GAMETEXT_CLEAN_CONFIRM(A) ngettext("Are you sure you want to delete %i replay", "Are you sure you want to delete %i replay", A)
+#define GAMETEXT_CLEAN_NOTHING_TO_DO  _("There is no replay to clean")
 #define GAMETEXT_CLOSE                _("Close")
 #define GAMETEXT_CONFIGUREJOYSTICK    _("Configure Joystick...")
 #define GAMETEXT_CONTROLS             _("Controls")
@@ -85,6 +88,8 @@ Central place to keep many in-game text strings
     ":Christoph Sommer;"                                                                     \
     ":Frederic Huard;"                                                                       \
     ":Brice Goglin;"                                                                         \
+    ":Kristian Jagd;"                                                                        \
+    ":Jens Erler;"                                                                           \
     ":;"                                                                                     \
     + std::string(_("Graphics")) +                                                           \
     ":Rasmus Neckelmann;"                                                                    \
@@ -102,17 +107,18 @@ Central place to keep many in-game text strings
     ":Jozef Riha (" + std::string(_("Slovak")) + ");"                                        \
     ":Nicolas Adenis-Lamarre (" + std::string(_("French")) + ");"                            \
     ":Wilhelm Francke (" + std::string(_("Norwegian")) + ");"                                \
-    ":Jonathan Sieber and Jens Erler (" + std::string(_("German")) + ");"                    \
+    ":Jonathan Sieber, Jens Erler (" + std::string(_("German")) + ");"                    \
     ":Maximum/Tuomo Koistinen (" + std::string(_("Finnish")) + ");"                                          \
     ":Trullo (" + std::string(_("Catalan")) + ");"                                           \
     ":Trullo (" + std::string(_("Spanish")) + ");"                                           \
     ":Mateusz Kosibowicz (" + std::string(_("Polish")) + ");"                                \
     ":Lucas Manzari (" + std::string(_("Italian")) + ");"                                    \
     ":Lukas Klingsbo (" + std::string(_("Swedish")) + ");"                                   \
-    ":Jan Kaláb (" + std::string(_("Czech")) + ");"                                          \
+    ":Jan KalÃ¡b (" + std::string(_("Czech")) + ");"                                          \
     ":" + std::string(_("Mikhail Brinchuk")) + " (" + std::string(_("Russian")) + ");"       \
     ":Lucas Hermann Negri (" + std::string(_("Brazilian Portuguese")) + ");"                 \
-    ":Jānis Rūcis (" + std::string(_("Latvian")) + ");"                 \
+    ":Jānis Rūcis (" + std::string(_("Latvian")) + ");"                                      \
+    ":Kristian Jagd (" + std::string(_("Danish")) + ");"                                     \
     ":;"                                                                                     \
     + std::string(_("Main testers")) +                                                       \
     ":Jose Alberto Coelho;"                                                                  \
@@ -124,6 +130,7 @@ Central place to keep many in-game text strings
     ":Samuel Mimram ("      + std::string(_("for Debian packaging"))      	     + ");"  \
     ":Dark ("               + std::string(_("for Gentoo packaging"))      	     + ");"  \
     ":Olivier Blin (" 	    + std::string(_("for Mandriva packaging"))    	     + ");"  \
+    ":Dmitry Marakasov ("   + std::string(_("for FreeBSD packaging"))                + ");"  \
     ":Balazs Rozsa (" 	    + std::string(_("for across/elma"))           	     + ");"  \
     ":Yves Berquin (" 	    + std::string(_("for making tinyxml"))        	     + ");"  \
     ":L. Peter Deutsch ("   + std::string(_("for the MD5 code"))          	     + ");"  \
@@ -133,7 +140,7 @@ Central place to keep many in-game text strings
     ":" 		    + std::string(_("Anyone who has helped in any way"))     + ";"
 
 #define GAMETEXT_CREDITSBUTTON        _("Credits")
-#define GAMETEXT_CURPLAYER            _("Player")
+#define GAMETEXT_PLAYER               _("Player")
 #define GAMETEXT_DATE                 _("Date")
 #define GAMETEXT_DB_UPGRADING               _("Upgrading database")
 #define GAMETEXT_DB_UPGRADING_STATS_PROFILE _("Upgrading database stats for the profile")
@@ -144,6 +151,7 @@ Central place to keep many in-game text strings
 #define GAMETEXT_DELETEREPLAYMESSAGE  _("Do you really want to delete replay?")
 #define GAMETEXT_DELETE               _("Delete")
 #define GAMETEXT_DELETEFROMFAVORITE  _("Delete from favorite")
+#define GAMETEXT_DELETEFROMBLACKLIST  _("Delete from blacklist")
 #define GAMETEXT_DELETEPROFILE        _("Delete")
 #define GAMETEXT_DESCRIPTION          _("Description")
 #define GAMETEXT_DISPLAYGHOSTTIMEDIFF _("Display Ghost time difference")
@@ -154,6 +162,7 @@ Central place to keep many in-game text strings
 #define GAMETEXT_DLHIGHSCORES         _("Downloading high-scores...")
 #define GAMETEXT_DLLEVELS             _("Downloading extra levels...\nPress ESC to abort.")
 #define GAMETEXT_DLLEVELSCHECK        _("Checking for new levels...")
+#define GAMETEXT_LOADNEWLEVELS        _("Loading new and updated levels...")
 #define GAMETEXT_DLROOMSLISTCHECK     _("Checking for existing rooms...")
 #define GAMETEXT_DLTHEME              _("Downloading theme data required by new levels...\nPress ESC to abort.")
 #define GAMETEXT_DLTHEMESLISTCHECK    _("Checking for new themes...")
@@ -171,17 +180,17 @@ Central place to keep many in-game text strings
 #define GAMETEXT_ENTERPLAYERNAME      _("Enter player name")
 #define GAMETEXT_ENTERREPLAYNAME      _("Enter name of replay")
 #define GAMETEXT_ERRORSINLEVEL        _("There are errors in the level, don't expect it to be playable!")
-#define GAMETEXT_EXTERNALLEVELS       _("External Levels")  
-#define GAMETEXT_FAILEDCHECKLEVELS    _("Failed to check for levels.\nCheck your Internet connection!")
-#define GAMETEXT_FAILEDDLHIGHSCORES   _("Failed to download high-scores.\nCheck your Internet connection!")
-#define GAMETEXT_FAILEDDLLEVELS       _("Failed to download levels.\nCheck your Internet connection!")
-#define GAMETEXT_FAILEDDLREPLAY       _("Failed to download the replay.\nCheck your Internet connection!")
-#define GAMETEXT_FAILEDDLROOMSLIST    _("Failed to download the rooms list.\nCheck your Internet connection!")
-#define GAMETEXT_FAILEDGETSELECTEDTHEME _("Failed to get the selected theme\nCheck your Internet connection!")
+#define GAMETEXT_CHECK_YOUR_WWW       _("Check your Internet connection !")  
+#define GAMETEXT_FAILEDCHECKLEVELS    _("Failed to check for levels.")
+#define GAMETEXT_FAILEDDLHIGHSCORES   _("Failed to download high-scores.")
+#define GAMETEXT_FAILEDDLLEVELS       _("Failed to download levels.")
+#define GAMETEXT_FAILEDDLREPLAY       _("Failed to download the replay.")
+#define GAMETEXT_FAILEDDLROOMSLIST    _("Failed to download the rooms list.")
+#define GAMETEXT_FAILEDGETSELECTEDTHEME _("Failed to get the selected theme")
 #define GAMETEXT_FAILEDTOINITLEVEL    _("Failed to initialize level!")
 #define GAMETEXT_FAILEDTOLOADREPLAY   _("Failed to load replay!")
 #define GAMETEXT_FAILEDTOSAVEREPLAY   _("Failed to save replay!\nMaybe you should try with another name?")
-#define GAMETEXT_FAILEDUPDATETHEMESLIST _("Failed to update the theme list\nCheck your Internet connection!")
+#define GAMETEXT_FAILEDUPDATETHEMESLIST _("Failed to update the theme list")
 #define GAMETEXT_FILE                 _("File")
 #define GAMETEXT_FILTER               _("Filter")
 #define GAMETEXT_FINISH               _("Finished!")
@@ -195,7 +204,8 @@ Central place to keep many in-game text strings
 #define GAMETEXT_GHOST_LOCAL          _("Local best")
 #define GAMETEXT_GHOST_BEST           _("Your best")
 #define GAMETEXT_GHOST_STRATEGIES_TYPE  _("Type")
-#define GAMETEXT_GHOST_STRATEGY_BESTOFROOM _("The highscore of the room")
+#define GAMETEXT_GHOST_STRATEGY_BESTOFREFROOM    _("The highscore of the reference room")
+#define GAMETEXT_GHOST_STRATEGY_BESTOFOTHERROOMS _("The highscore of the other rooms")
 #define GAMETEXT_GHOST_STRATEGY_MYBEST  _("The best of my replays (on this computer)")
 #define GAMETEXT_GHOST_STRATEGY_THEBEST _("The best of the replays (on this computer)")
 #define GAMETEXT_GHOSTOF              _("Ghost of %s")
@@ -212,12 +222,19 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 "  " + change_direction_KEY + " - " + std::string(_("Turns around and drives in the other direction")) + "\n" \
 "  Esc - " + std::string(_("Pause")) + "\n" \
 "  Return - " + std::string(_("Restart the level")) + "\n" \
-"  F12 - " + std::string(_("Take a screenshot")) + "\n" \
+"  PageDown/PageUp - " + std::string(_("Previous/Next level")) + "\n" \
+"  F3 - " + std::string(_("Add/remove to favorite levels")) + "\n"\
+"  ctrl+B - " + std::string(_("Add/remove to blacklisted levels")) + "\n"\
+"  ctrl+M - " + std::string(_("change mirror mode")) + "\n"\
+"  F8 - " + std::string(_("Enable/disable web")) + "\n" \
+"  F9 - " + std::string(_("Enable/disable ugly mode")) + "\n" \
 "  F5 - " + std::string(_("Reload levels, themes and replays from directories")) + "\n" \
+"  F12 - " + std::string(_("Take a screenshot")) + "\n" \
 "\n" \
  + std::string(_("Find all the strawberries and touch the flower to finish\nthe level.")) + "\n" \
  + std::string(_("Read the README file or check out the website at\nhttp://xmoto.tuxfamily.org for more information."))
 
+#define GAMETEXT_HIDEGHOSTS           _("Hide ghosts")
 #define GAMETEXT_HIGH                 _("High")
 #define GAMETEXT_LOAD_LEVEL_HOOK      _("Levels are being added into the database. Please wait.")
 #define GAMETEXT_INETCONF             _("Internet Configuration")
@@ -232,7 +249,14 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define GAMETEXT_JUSTDEAD_DISPLAYMENU _("Press ESC to display the menu")
 #define GAMETEXT_KEY                  _("Key")
 #define GAMETEXT_KEYBOARD             _("Keyboard")
+#define GAMETEXT_LANGUAGETAB          _("Language")
+#define GAMETEXT_LANGUAGE_NAME        _("Language name")
+#define GAMETEXT_LANGUAGE_CODE        _("Language code")
 #define GAMETEXT_LEVEL                _("Level")
+#define GAMETEXT_LEVEL_ADDED_TO_FAVORITE     _("Added to favorites")
+#define GAMETEXT_LEVEL_DELETED_FROM_FAVORITE _("Deleted from favorites")
+#define GAMETEXT_LEVEL_ADDED_TO_BLACKLIST     _("Added to blacklist")
+#define GAMETEXT_LEVEL_DELETED_FROM_BLACKLIST _("Deleted from blacklist")
 #define GAMETEXT_LEVELINFO            _("Level Info...")
 #define GAMETEXT_LEVELNAME            _("Level Name")
 #define GAMETEXT_LEVELCANNOTBELOADED  _("Level '%s' cannot be loaded")
@@ -251,22 +275,24 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define GAMETEXT_LOW                  _("Low")
 #define GAMETEXT_MEDIUM               _("Medium")
 #define GAMETEXT_MENUGFX              _("Menu Graphics")
+#define CONTEXTHELP_MINISTATTIMEFORPACKLEVEL _("Total time you scored / total highscore time for levels you finished")
 #define GAMETEXT_MISSINGTEXTURES      _("Level references unknown textures, it could be unplayable!")
 #define GAMETEXT_MONO                 _("Mono")
 #define GAMETEXT_MOSTPLAYEDLEVELSFOLLOW _("Following are your most played levels")
 #define GAMETEXT_MOTIONBLURGHOST      _("Motion blur ghost")
 #define GAMETEXT_MULTI                _("Multi")
+#define GAMETEXT_NOMULTISCENES        _("Semi-cooperative mode")
 #define GAMETEXT_MULTISTOPWHENONEFINISHES _("Stop the game once a player ends the level")
-#define GAMETEXT_NAME                 _("Name")
 #define GAMETEXT_NB_PLAYERS           _("Number of players")
 #define GAMETEXT_NEW                  _("New")
 #define GAMETEXT_NEWERXMOTOREQUIRED   _("X-Moto %s or newer required to load level")
 #define GAMETEXT_NEWHIGHSCORE         _("New highscore!")
 #define GAMETEXT_NEWHIGHSCOREPERSONAL _("New personal highscore!")
-#define GAMETEXT_NEWLEVELAVAIL        _("%d new or updated level available. Download now?")
+#define GAMETEXT_NEWLEVELAVAIL(A)     ngettext("%i new or updated level available. Download now ?",  \
+					       "%i new or updated levels available. Download now ?", \
+					       A)
 #define GAMETEXT_NEWLEVELS            _("New Levels")
 #define GAMETEXT_NEWLEVELS_AVAIBLE    _("New levels available!")
-#define GAMETEXT_NEWLEVELSAVAIL       _("%d new or updated levels available. Download now?")
 #define GAMETEXT_NEWPROFILE           _("New Profile...")
 #define GAMETEXT_NO                   _("No")
 #define GAMETEXT_NONEWLEVELS          _("No new or updated levels available.\n\nTry again another time.")
@@ -279,13 +305,14 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
                                       "All kinds of feedback are highly appreciated, so the game\n" \
                                       "can get better.\n" \
                                       "Mail bugs, ideas, comments, feature requests, hatemail, etc\n" \
-                                      "to nicolas at adenis-lamarre dot fr\n" \
+                                      "to xmoto@tuxfamily.org\n" \
                                       "\n" \
                                       "Also visit http://xmoto.tuxfamily.org to make sure you've\n" \
                                       "got the latest version.")
 #define GAMETEXT_NUMLEVELS            _("# Levels")
 #define GAMETEXT_OK                   _("OK")  
 #define GAMETEXT_OPEN                 _("Open")
+#define GAMETEXT_OPERATION_COMPLETED  _("Operation completed")
 #define GAMETEXT_OPTIONS              _("Options")
 #define GAMETEXT_OPTIONSREQURERESTART _("Some options will not take effect before next restart!")
 #define GAMETEXT_PACK_AUTHORS 	      _("By author")
@@ -296,11 +323,12 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define GAMETEXT_PACK_WEBVOTES 	      _("Web votes")
 #define GAMETEXT_PACK_STATS           _("Statistics")
 #define GAMETEXT_PACK_BEST_DRIVERS    _("By best driver")
+#define GAMETEXT_PACK_BY_LENGTH       _("By length")
 #define GAMETEXT_PAUSE                _("Pause")
 #define GAMETEXT_PASSWORD             _("Password")
 #define GAMETEXT_PERSONAL             _("Personal")
 #define GAMETEXT_PERSONALRECORDS      _("Personal")
-#define GAMETEXT_PLAYER(A)            ngettext("Player", "Players", A)
+#define GAMETEXT_NPLAYER(A)           ngettext("%i player", "%i players", A)
 #define GAMETEXT_PLAYERPROFILE        _("Player Profile")
 #define GAMETEXT_PLAYERPROFILES       _("Player Profiles")
 #define GAMETEXT_PLAYNEXT             _("Play Next Level")
@@ -314,25 +342,26 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define GAMETEXT_RANDOMIZE            _("Randomize")
 #define GAMETEXT_RELOADINGLEVELS      _("Reloading levels...")
 #define GAMETEXT_RELOADINGREPLAYS     _("Reloading replays...")
+#define GAMETEXT_RELOADINGTHEMES      _("Reloading themes...")
 #define GAMETEXT_REPLAY               _("Replay")
 #define GAMETEXT_REPLAYHELPTEXT(current_speed) _("Stop[esc] ||[space]  << >>[left/right keys]  < >[up/down keys]   Speed:") + current_speed + "x"
 #define GAMETEXT_REPLAYHELPTEXTNOREWIND(current_speed) _("Stop[esc] ||[space] >>[right key] < >[up/down keys]   Speed:") + current_speed + "x"
   // + "a" + "X"
 #define GAMETEXT_REPLAYNOTFOUND       _("The replay can't be played!")
+#define GAMETEXT_REPLAYOF             _("Replay of %s")
 #define GAMETEXT_REPLAYS              _("Replays")
 #define GAMETEXT_RESTART              _("Restart This Level")
 #define GAMETEXT_RESUME               _("Resume Playing")
 #define GAMETEXT_ROOM                 _("Room")
 #define GAMETEXT_RUNWINDOWED          _("Run Windowed")
 #define GAMETEXT_SAVE                 _("Save")
-#define GAMETEXT_SAVE_AS              _("Saved as")
+#define GAMETEXT_SAVE_AS              _("Saved as %s")
 #define GAMETEXT_SAVEREPLAY           _("Save Replay")
 #define GAMETEXT_SCREENRES            _("Screen Resolution")
 #define GAMETEXT_SHOW                 _("Show")
 #define GAMETEXT_SHOWENGINECOUNTER    _("Speedometer")
 #define GAMETEXT_SHOWINFO             _("Info...")
 #define GAMETEXT_SHOWMINIMAP          _("Show Mini Map")
-#define GAMETEXT_SCRIPTED             _("Scripted")
 #define GAMETEXT_STARTLEVEL           _("Play!")
 #define GAMETEXT_STATISTICS           _("Statistics")
 #define GAMETEXT_STATS                _("STATS")
@@ -345,20 +374,21 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define GAMETEXT_TIME                 _("Time")
 #define GAMETEXT_TRYAGAIN             _("Try This Level Again")
 #define GAMETEXT_TUTORIAL             _("Tutorial")
-#define GAMETEXT_UNKNOWNLEVEL         _("Unknown")
+#define GAMETEXT_UNKNOWN              _("Unknown")
 #define GAMETEXT_UNPACKED_LEVELS_PACK _("Unpacked levels")
-#define GAMETEXT_UNUPDATABLETHEMEONWEB _("Can't update this theme !\nThe theme is not avaible on the web\nor your theme list is not up to date")
+#define GAMETEXT_UNUPDATABLETHEMEONWEB _("Can't update this theme !\nThe theme is not available on the web\nor your theme list is not up to date")
 #define GAMETEXT_UPDATE               _("Update")
 #define GAMETEXT_UPDATED              _("Updated")
 #define GAMETEXT_UPDATEHIGHSCORES     _("Check WWW")
 #define GAMETEXT_UPDATEROOMSSLIST     _("Update the rooms list")
 #define GAMETEXT_UPDATETHEMESLIST     _("Update the theme list")
 #define GAMETEXT_UPDATINGLEVELS       _("Updating level lists...")
-#define GAMETEXT_UPLOAD_HIGHSCORE     _("Upload highscore")
+#define GAMETEXT_UPLOAD_HIGHSCORE     _("Upload")
 #define GAMETEXT_UPLOAD_ALL_HIGHSCORES _("Upload all highscores")
-#define GAMETEXT_UPLOAD_HIGHSCORE_ERROR _("An unexcepted error occured\nThe website has perhaps some troubles")
+#define GAMETEXT_UPLOAD_HIGHSCORE_ERROR _("An unexpected error has occurred. There may be some problems with the web site.")
 #define GAMETEXT_UPLOAD_HIGHSCORE_WEB_WARNING_BEFORE _("Oh no !")
 #define GAMETEXT_UPLOADING_HIGHSCORE  _("Uploading the highscore...")
+#define GAMETEXT_USECRAPPYINFORMATION _("Use crappy information")
 #define GAMETEXT_USEENVVARS           _("Use Environment Vars")
 #define GAMETEXT_USEPROFILE           _("Use Profile")
 #define GAMETEXT_USINGHTTPPROXY       _("Using HTTP Proxy")
@@ -372,14 +402,21 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define GAMETEXT_WORLDRECORDNA        "--:--:--"
 #define GAMETEXT_WWWMAINTAB           _("Main")
 #define GAMETEXT_WWWTAB               _("WWW")
-#define GAMETEXT_WWWROOMSTAB          _("Rooms")
+#define GAMETEXT_WWWROOMSTAB_REFERENCE _("Reference room")
+#define GAMETEXT_WWWROOMSTAB_OTHER     _("Room %i")
 
 #define GAMETEXT_XHOURS               _("%d hours") 
 #define GAMETEXT_XMINUTES             _("%d minutes")
-#define GAMETEXT_XMOTOGLOBALSTATS     _("(Stats since: %s)\n"                                         \
-                                      "X-Moto started %d times; %d plays (%d different levels),\n"  \
-                                      "%d deaths, %d finishes, and %d restarts.\nTime played: %s")
-#define GAMETEXT_XMOTOLEVELSTATS      _("%d plays, %d deaths, %d finishes, and %d restarts")
+
+#define GAMETEXT_XMOTOGLOBALSTATS_SINCE        _("Stats since: %s")
+#define GAMETEXT_XMOTOGLOBALSTATS_START(A)     ngettext("X-Moto started %d time", "X-Moto started %d times", A)
+#define GAMETEXT_XMOTOGLOBALSTATS_DIFFERENT(A) ngettext("%d different level", "%d different levels", A)
+#define GAMETEXT_XMOTOGLOBALSTATS_TIMEPLAYED   _("Time played: %s")
+#define GAMETEXT_XMOTOLEVELSTATS_PLAYS(A)    ngettext("%d play", "%d plays", A)
+#define GAMETEXT_XMOTOLEVELSTATS_DEATHS(A)   ngettext("%d death", "%d deaths", A)
+#define GAMETEXT_XMOTOLEVELSTATS_FINISHED(A) ngettext("%d finished", "%d finished", A)
+#define GAMETEXT_XMOTOLEVELSTATS_RESTART(A)  ngettext("%d restart", "%d restarts", A)
+
 #define GAMETEXT_XSECONDS             _("%d seconds")
 #define GAMETEXT_YES                  _("Yes")
 #define GAMETEXT_YES_FOR_ALL          _("Yes to all")
@@ -407,8 +444,6 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define CONTEXTHELP_HELP _("Instructions of how to play X-Moto")
 #define CONTEXTHELP_CHANGE_PLAYER _("Change player profile")
 #define CONTEXTHELP_TUTORIAL _("Play tutorial of how to play the game")
-#define CONTEXTHELP_OFFICIAL_LEVELS _("Official built-in levels")
-#define CONTEXTHELP_EXTERNAL_LEVELS _("Unofficial stand-alone external levels")
 #define CONTEXTHELP_PLAY_SELECTED_LEVEL _("Play the selected level")
 #define CONTEXTHELP_LEVEL_INFO _("View general information about the level, best times, and replays")
 #define CONTEXTHELP_RUN_REPLAY _("Run the selected replay")
@@ -423,6 +458,7 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define CONTEXTHELP_MINI_MAP _("Show a map of your surroundings when playing")
 #define CONTEXTHELP_DOWNLOAD_BEST_TIMES _("Automatically download best times off the net when the game starts")
 #define CONTEXTHELP_INGAME_WORLD_RECORD _("Show the World Record for a given level when playing")
+#define CONTEXTHELP_USECRAPPYINFORMATION _("Use crappy information from the website to update the crappy pack")
 #define CONTEXTHELP_HIGHCOLOR _("Enable high-color graphics")
 #define CONTEXTHELP_TRUECOLOR _("Enable true-color graphics")
 #define CONTEXTHELP_RESOLUTION _("Select graphics resolution")
@@ -461,9 +497,9 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define CONTEXTHELP_SHOWCONTEXTHELP _("Show helpful help strings such as this one")
 #define CONTEXTHELP_DOWNLOADLEVELS _("Let X-Moto look for more levels on the net, and install them automatically")
 #define CONTEXTHELP_DIRECTCONN _("Select this if you got a direct connection to the Internet")
-#define CONTEXTHELP_HTTPPROXY _("Select this if you connects to the Internet through an HTTP proxy")
-#define CONTEXTHELP_SOCKS4PROXY _("Select this if you connects to the Internet through a SOCKS4 proxy")
-#define CONTEXTHELP_SOCKS5PROXY _("Select this if you connects to the Internet through a SOCKS5 proxy")
+#define CONTEXTHELP_HTTPPROXY _("Select this if you connect to the Internet through an HTTP proxy")
+#define CONTEXTHELP_SOCKS4PROXY _("Select this if you connect to the Internet through a SOCKS4 proxy")
+#define CONTEXTHELP_SOCKS5PROXY _("Select this if you connect to the Internet through a SOCKS5 proxy")
 #define CONTEXTHELP_OKPROXY _("Use these settings")
 #define CONTEXTHELP_PROXYSERVER _("Write the IP address or host name of proxy server to use")
 #define CONTEXTHELP_PROXYPORT _("Write the port number used by the proxy server")
@@ -508,15 +544,27 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define CONTEXTHELP_ADDTOFAVORITE _("Add the level to the favorite levels list")
 #define CONTEXTHELP_DELETEFROMFAVORITE _("Delete the level from the favorite levels list")
 #define CONTEXTHELP_RANDOMIZE _("Puzzle the levels pack list")
-#define CONTEXTHELP_LEVEL_FILTER _("Put a text to limit the level list")
+#define CONTEXTHELP_LEVEL_FILTER _("Enter text to filter the level list")
 #define CONTEXTHELP_MULTI _("Choose the number of players")
-#define CONTEXTHELP_PROXYLOGIN    _("Your login in the room")
+#define CONTEXTHELP_PROXYLOGIN    _("Your proxy login")
 #define CONTEXTHELP_PROXYPASSWORD _("Your password associated with your login")
-#define CONTEXTHELP_REPLAYS_FILTER _("Filter on replay list")
-#define CONTEXTHELP_QUICKSTART _("Press to play immediatly to X-Moto")
-#define CONTEXTHELP_QUICKSTART_QUALITY    _("Increase or dicrease the quality of the levels selected")
-#define CONTEXTHELP_QUICKSTART_DIFFICULTY _("Increase or dicrease the difficulty of the levels selected")
+#define CONTEXTHELP_REPLAYS_FILTER _("Enter text to filter the replay list")
+#define CONTEXTHELP_QUICKSTART _("Press to play X-Moto immediately")
+#define CONTEXTHELP_QUICKSTART_QUALITY    _("Increase or decrease the quality of the levels selected")
+#define CONTEXTHELP_QUICKSTART_DIFFICULTY _("Increase or decrease the difficulty of the levels selected")
 #define CONTEXTHELP_MULTISTOPWHENONEFINISHES _("Stop the game once a player ends the level or continue while a player is running")
+#define CONTEXTHELP_GHOST_STRATEGY_MYBEST _("The best of my replays (on this computer)")
+#define CONTEXTHELP_GHOST_STRATEGY_THEBEST _("The best of the replays (on this computer)")
+#define CONTEXTHELP_GHOST_STRATEGY_BESTOFREFROOM _("The highscore of the reference room")
+#define CONTEXTHELP_GHOST_STRATEGY_BESTOFOTHERROOMS _("The highscore of the other rooms")
+#define CONTEXTHELP_HIDEGHOSTS _("Don't show the ghosts while playing")
+#define CONTEXTHELP_NOMULTISCENES _("The scene is shared by all the players")
+#define CONTEXTHELP_LANGUAGE_OPTIONS _("Change the X-Moto language")
+#define CONTEXTHELP_LANGUAGE_NAME _("Name of the language")
+#define CONTEXTHELP_LANGUAGE_CODE _("Code of the language")
+#define CONTEXTHELP_REPLAYS_CLEAN _("Delete replays that X-Moto estimates to be not interesting to keep")
+#define CONTEXTHELP_CHILDREN_COMPLIANT _("Remove levels not suitable for children")
+#define CONTEXTHELP_ROOM_ENABLE _("Enable this room")
 
 #define VPACKAGENAME_LEVELS_WITH_NO_HIGHSCORE   _("Levels with no highscore")
 #define VPACKAGENAME_INCOMPLETED_LEVELS         _("Levels you have not completed")
@@ -524,12 +572,13 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define VPACKAGENAME_ALL_LEVELS                 _("All levels")
 #define VPACKAGENAME_NEW_LEVELS                 _("New and updated levels")
 #define VPACKAGENAME_FAVORITE_LEVELS            _("Favorite levels")
+#define VPACKAGENAME_BLACKLIST_LEVELS            _("Blacklisted levels")
 #define VPACKAGENAME_NICEST_LEVELS              _("Nicest levels")
 #define VPACKAGENAME_HARDEST_LEVELS             _("Hardest levels")
 #define VPACKAGENAME_EASIEST_LEVELS             _("Easiest levels")
-#define VPACKAGENAME_CRAPIEST_LEVELS            _("Crapiest levels")
+#define VPACKAGENAME_CRAPPIEST_LEVELS            _("Crappiest levels")
 #define VPACKAGENAME_SCRIPTED                   _("Scripted levels")
-#define VPACKAGENAME_MUSICAL                    _("Musical")
+#define VPACKAGENAME_MUSICAL                    _("Musical levels")
 #define VPACKAGENAME_BEST_DRIVER                _("By best driver")
 #define VPACKAGENAME_LAST_PLAYED                _("Last played levels")
 #define VPACKAGENAME_NEVER_PLAYED               _("Never played levels")
@@ -538,40 +587,51 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define VPACKAGENAME_LAST_HIGHSCORES            _("Last highscores")
 #define VPACKAGENAME_LAST_LEVELS                _("Last levels")
 #define VPACKAGENAME_OLDEST_HIGHSCORES          _("Oldest highscores")
-#define VPACKAGENAME_MEDAL_PLATINIUM            _("Platinium")
+#define VPACKAGENAME_MEDAL_PLATINIUM            _("Platinum")
 #define VPACKAGENAME_MEDAL_GOLD                 _("Gold")
 #define VPACKAGENAME_MEDAL_SILVER               _("Silver")
 #define VPACKAGENAME_MEDAL_BRONZE               _("Bronze")
 #define VPACKAGENAME_MEDAL_NONE                 _("No medal")
 #define VPACKAGENAME_MY_LEVELS                  _("My levels")
+#define VPACKAGENAME_CRAPPY_LEVELS              _("Crappy levels")
+#define VPACKAGENAME_SHORT_LEVELS               _("Shortest levels")
+#define VPACKAGENAME_MEDIUM_LEVELS              _("Medium levels")
+#define VPACKAGENAME_LONG_LEVELS                _("Long levels")
+#define VPACKAGENAME_VERY_LONG_LEVELS           _("Very long levels")
 
-#define VPACKAGENAME_DESC_LEVELS_WITH_NO_HIGHSCORE   _("Levels with no highscore in you room")
+#define VPACKAGENAME_DESC_LEVELS_WITH_NO_HIGHSCORE   _("Levels with no highscore in your room")
 #define VPACKAGENAME_DESC_INCOMPLETED_LEVELS         _("Levels you have not completed")
 #define VPACKAGENAME_DESC_YOU_HAVE_NOT_THE_HIGHSCORE _("Somebody in the room made a better highscore than yours")
 #define VPACKAGENAME_DESC_ALL_LEVELS                 _("All X-Moto levels")
 #define VPACKAGENAME_DESC_NEW_LEVELS                 _("New and updated levels since your last check")
 #define VPACKAGENAME_DESC_FAVORITE_LEVELS            _("Your favorite levels")
+#define VPACKAGENAME_DESC_BLACKLIST_LEVELS            _("Your blacklisted levels")
 #define VPACKAGENAME_DESC_NICEST_LEVELS          _("Nicest X-Moto levels according to the web votes")
 #define VPACKAGENAME_DESC_HARDEST_LEVELS         _("Hardest X-Moto levels according to the web votes")
 #define VPACKAGENAME_DESC_EASIEST_LEVELS         _("Easiest X-Moto levels according to the web votes")
-#define VPACKAGENAME_DESC_CRAPIEST_LEVELS        _("Crapiest X-Moto levels according to the web votes")
+#define VPACKAGENAME_DESC_CRAPPIEST_LEVELS       _("Crappiest X-Moto levels according to the web votes")
 #define VPACKAGENAME_DESC_SCRIPTED                   _("X-Moto levels which are dynamic")
 #define VPACKAGENAME_DESC_MUSICAL                    _("X-Moto levels with a background music")
 #define VPACKAGENAME_DESC_LAST_PLAYED                _("Last levels you have played")
 #define VPACKAGENAME_DESC_NEVER_PLAYED               _("X-Moto levels you never played")
 #define VPACKAGENAME_DESC_MOST_PLAYED                _("X-Moto levels you have played the most")
 #define VPACKAGENAME_DESC_LESS_PLAYED                _("X-Moto levels you have played only a few times")
-#define VPACKAGENAME_DESC_LAST_HIGHSCORES        _("X-Moto levels having a recent highscore in you room")
+#define VPACKAGENAME_DESC_LAST_HIGHSCORES        _("X-Moto levels having a recent highscore in your room")
 #define VPACKAGENAME_DESC_LAST_LEVELS                _("Last created X-Moto levels")
-#define VPACKAGENAME_DESC_OLDEST_HIGHSCORES      _("X-Moto levels having an old highscore in you room")
+#define VPACKAGENAME_DESC_OLDEST_HIGHSCORES      _("X-Moto levels having an old highscore in your room")
 #define VPACKAGENAME_DESC_MEDAL_PLATINIUM        _("You have the room highscore")
-#define VPACKAGENAME_DESC_MEDAL_GOLD             _("You highscore finish time is almost the room highscore (95%)")
-#define VPACKAGENAME_DESC_MEDAL_SILVER           _("You highscore finish time is almost the room highscore (90%-95%)")
-#define VPACKAGENAME_DESC_MEDAL_BRONZE           _("You highscore finish time is almost the room highscore (80%-90%)")
+#define VPACKAGENAME_DESC_MEDAL_GOLD             _("Your personal highscore finish time is almost the room highscore (95%)")
+#define VPACKAGENAME_DESC_MEDAL_SILVER           _("Your personal highscore finish time is almost the room highscore (90%-95%)")
+#define VPACKAGENAME_DESC_MEDAL_BRONZE           _("Your personal highscore finish time is almost the room highscore (80%-90%)")
 #define VPACKAGENAME_DESC_MEDAL_NONE             _("The room highscore is really better than your own highscore")
-#define VPACKAGENAME_DESC_STANDARD               _("Level pack")
-#define VPACKAGENAME_DESC_BEST_DRIVERS           _("Highscores by")
+#define VPACKAGENAME_DESC_STANDARD               _("Level pack \"%s\"")
+#define VPACKAGENAME_DESC_BEST_DRIVERS           _("Highscores by %s")
 #define VPACKAGENAME_DESC_MY_LEVELS              _("External levels (the one you put into the 'My levels' directory)")
+#define VPACKAGENAME_DESC_CRAPPY_LEVELS          _("Levels marked 'crappy' are hidden in all other packs")
+#define VPACKAGENAME_DESC_SHORT_LEVELS           _("The shortest levels (less than 25 seconds)")
+#define VPACKAGENAME_DESC_MEDIUM_LEVELS          _("The medium levels (25 seconds to 60)")
+#define VPACKAGENAME_DESC_LONG_LEVELS            _("The long levels (1 minute to 2 minutes)")
+#define VPACKAGENAME_DESC_VERY_LONG_LEVELS       _("The longest levels (more than 2 minutes)")
 
 #define SYS_MSG_UGLY_MODE_ENABLED      	_("Ugly mode enabled")
 #define SYS_MSG_UGLY_MODE_DISABLED     	_("Ugly mode disabled")
@@ -579,9 +639,20 @@ std::string(_("You control your bike using the keyboard")) + ":\n" \
 #define SYS_MSG_THEME_MODE_DISABLED    	_("Theme mode disabled")
 #define SYS_MSG_UGLY_OVER_MODE_ENABLED  _("UglyOver mode enabled")
 #define SYS_MSG_UGLY_OVER_MODE_DISABLED _("UglyOver mode disabled")
-#define SYS_MSG_WWW_ENABLED   	       	_("Web connexion enabled")
-#define SYS_MSG_WWW_DISABLED  	       	_("Web connexion disabled")
+#define SYS_MSG_WWW_ENABLED   	       	_("Web connection enabled")
+#define SYS_MSG_WWW_DISABLED  	       	_("Web connection disabled")
 #define SYS_MSG_INTERPOLATION_ENABLED  	_("Replay interpolation enabled")
 #define SYS_MSG_INTERPOLATION_DISABLED 	_("Replay interpolation disabled")
+#define SYS_MSG_FPS_ENABLED             _("Fps enabled")
+#define SYS_MSG_FPS_DISABLED            _("Fps disabled")
+#define SYS_MSG_AUDIO_ENABLED           _("Audio enabled")
+#define SYS_MSG_AUDIO_DISABLED          _("Audio disabled")
+
+#define SYS_MSG_TRAIN_NO_RESTORE_AVAIL  _("No training positions stored")
+#define SYS_MSG_TRAIN_RESTORING         _("Training position %i/%i restored")
+#define SYS_MSG_TRAIN_STORED            _("Stored as training position %i")
+
+// font to use to choice the GROUP : currently, two groups, GENERAL and ASIAN
+#define FONT_GROUP _("FontGroup:GENERAL")
 
 #endif
