@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -26,6 +25,9 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "xmscene/Level.h"
 #include "db/xmDatabase.h"
 #include "XMotoLoadLevelsInterface.h"
+#include "helpers/Singleton.h"
+
+class WWWAppInterface;
 
 class LevelsPack {
   public:
@@ -33,6 +35,7 @@ class LevelsPack {
   ~LevelsPack();
 
   std::string Name() const;
+  void setName(const std::string& i_name);
   bool ShowTimes() const;
   bool ShowWebTimes() const;
   void setShowTimes(bool i_showTimes);
@@ -60,33 +63,34 @@ class LevelsPack {
   std::string m_description;
 };
 
-class LevelsManager {
+class LevelsManager : public Singleton<LevelsManager> {
+  friend class Singleton<LevelsManager>;
 
-  public:
+private:
   LevelsManager();
   ~LevelsManager();
 
+public:
   LevelsPack& LevelsPackByName(const std::string &i_name);
-  std::string LevelByFileName(xmDatabase *i_db, const std::string& i_fileName);
-  bool doesLevelExist(xmDatabase *i_db, const std::string& i_id);
+  std::string LevelByFileName(const std::string& i_fileName, xmDatabase *i_db);
+  bool doesLevelExist(const std::string& i_id, xmDatabase* i_db);
 
   bool doesLevelsPackExist(const std::string &i_name) const;
 
   /* to load or reload levels from files */
-  void makePacks(xmDatabase *i_db,
-		 const std::string& i_playerName,
+  void makePacks(const std::string& i_playerName,
 		 const std::string& i_id_room,
-		 bool i_bDebugMode);
-  void addExternalLevel(xmDatabase *i_db, std::string i_levelFile);
-  void reloadExternalLevels(xmDatabase *i_db, XMotoLoadLevelsInterface *i_loadLevelsInterface = NULL);
-  void reloadLevelsFromLvl(xmDatabase *i_db,
-			   XMotoLoadLevelsInterface *i_loadLevelsInterface = NULL);
+		 bool i_bDebugMode, xmDatabase *i_db);
+  void addExternalLevel(std::string i_levelFile, xmDatabase *i_db);
+  void reloadLevelsFromLvl(xmDatabase* i_db, XMotoLoadLevelsInterface *i_loadLevelsInterface = NULL);
 
   /* to load news levels */
   /* to reload levels already loaded (it will put them into the updateLevels list) */
   /* create the newLevels.xml file */
-  void updateLevelsFromLvl(xmDatabase *i_db, const std::vector<std::string> &NewLvl,
-			   const std::vector<std::string> &UpdatedLvl);
+  void updateLevelsFromLvl(const std::vector<std::string> &NewLvl,
+			   const std::vector<std::string> &UpdatedLvl,
+			   WWWAppInterface* pCaller,
+			   xmDatabase* i_db);
 
   const std::vector<LevelsPack *> &LevelsPacks();
 
@@ -95,17 +99,24 @@ class LevelsManager {
   
   void printLevelsList(xmDatabase *i_db) const;
 
-  void addToFavorite(xmDatabase *i_db, std::string i_profile, const std::string& i_id_level);
-  void delFromFavorite(xmDatabase *i_db, std::string i_profile, const std::string& i_id_level);
+  bool isInFavorite(std::string i_profile, const std::string& i_id_level, xmDatabase *i_db);
+  void addToFavorite(std::string i_profile, const std::string& i_id_level, xmDatabase *i_db);
+  void delFromFavorite(std::string i_profile, const std::string& i_id_level, xmDatabase *i_db);
 
-  static std::string getQuickStartPackQuery(xmDatabase *i_db,
-					    unsigned int i_qualityMIN, unsigned int i_difficultyMIN,
+  bool isInBlacklist(std::string i_profile, const std::string& i_id_level, xmDatabase *i_db);
+  void addToBlacklist(std::string i_profile, const std::string& i_id_level, xmDatabase *i_db);
+  void delFromBlacklist(std::string i_profile, const std::string& i_id_level, xmDatabase *i_db);
+
+
+  static std::string getQuickStartPackQuery(unsigned int i_qualityMIN, unsigned int i_difficultyMIN,
 					    unsigned int i_qualityMAX, unsigned int i_difficultyMAX,
-					    const std::string& i_profile, const std::string& i_id_room);
+					    const std::string& i_profile, const std::string& i_id_room, xmDatabase *i_db);
+  void reloadExternalLevels(xmDatabase* i_db, XMotoLoadLevelsInterface *i_loadLevelsInterface = NULL);
 
   private:
   void clean();
   void cleanPacks();
+  void reloadInternalLevels(xmDatabase* i_db, XMotoLoadLevelsInterface *i_loadLevelsInterface = NULL);
 
   std::vector<LevelsPack *> m_levelsPacks;
 };
