@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -25,59 +24,66 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "GameEvents.h"
 #include "Input.h"
 #include "Locales.h"
+#include "helpers/Log.h"
+#include "xmscene/Level.h"
+#include "xmscene/Block.h"
 
-vapp::MotoGame*     LuaLibGame::m_exec_world              = NULL;
-vapp::InputHandler* LuaLibGame::m_exec_activeInputHandler = NULL;
-luaL_reg            LuaLibGame::m_gameFuncs[] = {
-  {"GetTime",                     LuaLibGame::L_Game_GetTime},
-  {"Message",                     LuaLibGame::L_Game_Message},
-  {"IsPlayerInZone",              LuaLibGame::L_Game_IsPlayerInZone},
-  {"MoveBlock",                   LuaLibGame::L_Game_MoveBlock},
-  {"GetBlockPos",                 LuaLibGame::L_Game_GetBlockPos},
-  {"SetBlockPos",                 LuaLibGame::L_Game_SetBlockPos},
-  {"PlaceInGameArrow",            LuaLibGame::L_Game_PlaceInGameArrow},
-  {"PlaceScreenArrow",            LuaLibGame::L_Game_PlaceScreenArrow},
-  {"HideArrow",                   LuaLibGame::L_Game_HideArrow},
-  {"ClearMessages",               LuaLibGame::L_Game_ClearMessages},
-  {"SetGravity",                  LuaLibGame::L_Game_SetGravity},
-  {"GetGravity",                  LuaLibGame::L_Game_GetGravity},
-  {"SetPlayerPosition",           LuaLibGame::L_Game_SetPlayerPosition},
-  {"AddForceToPlayer",            LuaLibGame::L_Game_AddForceToPlayer},
-  {"GetPlayerPosition",           LuaLibGame::L_Game_GetPlayerPosition},
-  {"GetEntityPos",                LuaLibGame::L_Game_GetEntityPos},
-  {"SetEntityPos",                LuaLibGame::L_Game_SetEntityPos},
-  {"SetKeyHook",                  LuaLibGame::L_Game_SetKeyHook},
-  {"GetKeyByAction",              LuaLibGame::L_Game_GetKeyByAction},
-  {"Log",                         LuaLibGame::L_Game_Log},
-  {"SetBlockCenter",              LuaLibGame::L_Game_SetBlockCenter},
-  {"SetBlockRotation",            LuaLibGame::L_Game_SetBlockRotation},
+luaL_reg LuaLibGame::m_gameFuncs[] = {
+  {"GetTime",                      LuaLibGame::L_Game_GetTime},
+  {"Message",                      LuaLibGame::L_Game_Message},
+  {"IsPlayerInZone",               LuaLibGame::L_Game_IsPlayerInZone},
+  {"MoveBlock",                    LuaLibGame::L_Game_MoveBlock},
+  {"GetBlockPos",                  LuaLibGame::L_Game_GetBlockPos},
+  {"SetBlockPos",                  LuaLibGame::L_Game_SetBlockPos},
+  {"PlaceInGameArrow",             LuaLibGame::L_Game_PlaceInGameArrow},
+  {"PlaceScreenArrow",             LuaLibGame::L_Game_PlaceScreenArrow},
+  {"HideArrow",                    LuaLibGame::L_Game_HideArrow},
+  {"ClearMessages",                LuaLibGame::L_Game_ClearMessages},
+  {"SetGravity",                   LuaLibGame::L_Game_SetGravity},
+  {"GetGravity",                   LuaLibGame::L_Game_GetGravity},
+  {"SetPlayerPosition",            LuaLibGame::L_Game_SetPlayerPosition},
+  {"AddForceToPlayer",             LuaLibGame::L_Game_AddForceToPlayer},
+  {"GetPlayerPosition",            LuaLibGame::L_Game_GetPlayerPosition},
+  {"GetEntityPos",                 LuaLibGame::L_Game_GetEntityPos},
+  {"SetEntityPos",                 LuaLibGame::L_Game_SetEntityPos},
+  {"SetKeyHook",                   LuaLibGame::L_Game_SetKeyHook},
+  {"GetKeyByAction",               LuaLibGame::L_Game_GetKeyByAction},
+  {"Log",                          LuaLibGame::L_Game_Log},
+  {"SetBlockCenter",               LuaLibGame::L_Game_SetBlockCenter},
+  {"SetBlockRotation",             LuaLibGame::L_Game_SetBlockRotation},
   {"SetDynamicEntitySelfRotation", LuaLibGame::L_Game_SetDynamicEntitySelfRotation},
-  {"SetDynamicEntityRotation",    LuaLibGame::L_Game_SetDynamicEntityRotation},
-  {"SetDynamicEntityTranslation", LuaLibGame::L_Game_SetDynamicEntityTranslation},
-  {"SetDynamicEntityNone",        LuaLibGame::L_Game_SetDynamicEntityNone},
-  {"SetDynamicBlockRotation",     LuaLibGame::L_Game_SetDynamicBlockRotation},
-  {"SetDynamicBlockSelfRotation", LuaLibGame::L_Game_SetDynamicBlockSelfRotation},
-  {"SetDynamicBlockTranslation",  LuaLibGame::L_Game_SetDynamicBlockTranslation},
-  {"SetDynamicBlockNone",         LuaLibGame::L_Game_SetDynamicBlockNone},
-  {"CameraZoom",        	  LuaLibGame::L_Game_CameraZoom},
-  {"CameraMove",        	  LuaLibGame::L_Game_CameraMove},
-  {"GetEntityRadius",       	  LuaLibGame::L_Game_GetEntityRadius},
-  {"IsEntityTouched",       	  LuaLibGame::L_Game_IsEntityTouched},
-  {"KillPlayer",                  LuaLibGame::L_Game_KillPlayer},
-  {"KillEntity",                  LuaLibGame::L_Game_KillEntity},
-  {"RemainingStrawberries",       LuaLibGame::L_Game_RemainingStrawberries},
-  {"WinPlayer",                   LuaLibGame::L_Game_WinPlayer},
-  {"AddPenaltyTime",              LuaLibGame::L_Game_PenaltyTime},
-  {"IsAPlayerInZone",             LuaLibGame::L_Game_IsAPlayerInZone},
-  {"SetAPlayerPosition", 	  LuaLibGame::L_Game_SetAPlayerPosition},
-  {"GetAPlayerPosition", 	  LuaLibGame::L_Game_GetAPlayerPosition},
-  {"KillAPlayer", 		  LuaLibGame::L_Game_KillAPlayer},
-  {"WinAPlayer",  		  LuaLibGame::L_Game_WinAPlayer},
-  {"NumberOfPlayers",             LuaLibGame::L_Game_NumberOfPlayers},
-  {"CameraRotate",                LuaLibGame::L_Game_CameraRotate},
-  {"CameraAdaptToGravity",        LuaLibGame::L_Game_CameraAdaptToGravity},
+  {"SetDynamicEntityRotation",     LuaLibGame::L_Game_SetDynamicEntityRotation},
+  {"SetDynamicEntityTranslation",  LuaLibGame::L_Game_SetDynamicEntityTranslation},
+  {"SetDynamicEntityNone",         LuaLibGame::L_Game_SetDynamicEntityNone},
+  {"SetDynamicBlockRotation",      LuaLibGame::L_Game_SetDynamicBlockRotation},
+  {"SetDynamicBlockSelfRotation",  LuaLibGame::L_Game_SetDynamicBlockSelfRotation},
+  {"SetDynamicBlockTranslation",   LuaLibGame::L_Game_SetDynamicBlockTranslation},
+  {"SetDynamicBlockNone",          LuaLibGame::L_Game_SetDynamicBlockNone},
+  {"CameraZoom",        	   LuaLibGame::L_Game_CameraZoom},
+  {"CameraMove",        	   LuaLibGame::L_Game_CameraMove},
+  {"GetEntityRadius",       	   LuaLibGame::L_Game_GetEntityRadius},
+  {"IsEntityTouched",       	   LuaLibGame::L_Game_IsEntityTouched},
+  {"KillPlayer",                   LuaLibGame::L_Game_KillPlayer},
+  {"KillEntity",                   LuaLibGame::L_Game_KillEntity},
+  {"RemainingStrawberries",        LuaLibGame::L_Game_RemainingStrawberries},
+  {"WinPlayer",                    LuaLibGame::L_Game_WinPlayer},
+  {"AddPenaltyTime",               LuaLibGame::L_Game_PenaltyTime},
+  {"IsAPlayerInZone",              LuaLibGame::L_Game_IsAPlayerInZone},
+  {"SetAPlayerPosition", 	   LuaLibGame::L_Game_SetAPlayerPosition},
+  {"GetAPlayerPosition", 	   LuaLibGame::L_Game_GetAPlayerPosition},
+  {"KillAPlayer", 		   LuaLibGame::L_Game_KillAPlayer},
+  {"WinAPlayer",  		   LuaLibGame::L_Game_WinAPlayer},
+  {"NumberOfPlayers",              LuaLibGame::L_Game_NumberOfPlayers},
+  {"CameraRotate",                 LuaLibGame::L_Game_CameraRotate},
+  {"CameraAdaptToGravity",         LuaLibGame::L_Game_CameraAdaptToGravity},
+  {"SetCameraRotationSpeed",       LuaLibGame::L_Game_SetCameraRotationSpeed},
+  {"PlaySound",                    LuaLibGame::L_Game_PlaySound},
+  {"PlayMusic",                    LuaLibGame::L_Game_PlayMusic},
+  {"StopMusic",                    LuaLibGame::L_Game_StopMusic},
   {NULL, NULL}
 };
+MotoGame*     LuaLibGame::m_exec_world              = NULL;
+InputHandler* LuaLibGame::m_exec_activeInputHandler = NULL;
 
 /*===========================================================================
   Lua 5.1 compatibility code (Following is from lua 5.0.2)
@@ -93,15 +99,15 @@ lua_Number X_luaL_check_number(lua_State *L,int narg) {
   return d;    
 }
 
-LuaLibGame::LuaLibGame(vapp::MotoGame *i_pMotoGame, vapp::InputHandler *i_pActiveInputHandler) {
+LuaLibGame::LuaLibGame(MotoGame *i_pMotoGame) {
   m_pL = lua_open();
   luaopen_base(m_pL);   
   luaopen_math(m_pL);
   luaopen_table(m_pL);
-  luaL_openlib(m_pL,"Game", m_gameFuncs, 0);
+  luaL_openlib(m_pL, "Game", m_gameFuncs, 0);
 
   m_pMotoGame           = i_pMotoGame;
-  m_pActiveInputHandler = i_pActiveInputHandler;
+  m_pActiveInputHandler = InputHandler::instance();
 }
 
 LuaLibGame::~LuaLibGame() {
@@ -281,21 +287,24 @@ int LuaLibGame::L_Game_Log(lua_State *pL) {
   /* no event for this */
   
   std::string Out;
-  for(int i=0;i<lua_gettop(pL);i++) 
-    Out.append(luaL_checkstring(pL,i+1));
-  vapp::Log((char *)Out.c_str());    
+
+  for(int i=0; i<lua_gettop(pL); i++)
+    Out.append(luaL_checkstring(pL, i+1));
+
+  Logger::Log((char *)Out.c_str());
+
   return 0;    
 }
   
 int LuaLibGame::L_Game_ClearMessages(lua_State *pL) {
   /* event for this */
-  m_exec_world->createGameEvent(new vapp::MGE_ClearMessages(m_exec_world->getTime()));
+  m_exec_world->createGameEvent(new MGE_ClearMessages(m_exec_world->getTime()));
   return 0;
 }
 
 int LuaLibGame::L_Game_PlaceInGameArrow(lua_State *pL) {
   /* event for this */
-  m_exec_world->createGameEvent(new vapp::MGE_PlaceInGameArrow(m_exec_world->getTime(),
+  m_exec_world->createGameEvent(new MGE_PlaceInGameArrow(m_exec_world->getTime(),
 							X_luaL_check_number(pL,1),
 							X_luaL_check_number(pL,2),
 							X_luaL_check_number(pL,3)));
@@ -304,7 +313,7 @@ int LuaLibGame::L_Game_PlaceInGameArrow(lua_State *pL) {
 
 int LuaLibGame::L_Game_PlaceScreenArrow(lua_State *pL) {
   /* event for this */
-  m_exec_world->createGameEvent(new vapp::MGE_PlaceScreenarrow(m_exec_world->getTime(),
+  m_exec_world->createGameEvent(new MGE_PlaceScreenarrow(m_exec_world->getTime(),
 							X_luaL_check_number(pL,1),
 							X_luaL_check_number(pL,2),
 							X_luaL_check_number(pL,3)));
@@ -313,7 +322,7 @@ int LuaLibGame::L_Game_PlaceScreenArrow(lua_State *pL) {
 
 int LuaLibGame::L_Game_HideArrow(lua_State *pL) {
   /* event for this */
-  m_exec_world->createGameEvent(new vapp::MGE_HideArrow(m_exec_world->getTime()));
+  m_exec_world->createGameEvent(new MGE_HideArrow(m_exec_world->getTime()));
   return 0;
 }
   
@@ -321,7 +330,7 @@ int LuaLibGame::L_Game_GetTime(lua_State *pL) {
   /* no event for this */
 
   /* Get current game time */
-  lua_pushnumber(pL,m_exec_world->getTime());
+  lua_pushnumber(pL,m_exec_world->getTime() / 100.0);
   return 1;
 }
   
@@ -333,17 +342,17 @@ int LuaLibGame::L_Game_Message(lua_State *pL) {
   for(int i=0;i<lua_gettop(pL);i++) 
     Out.append(_(luaL_checkstring(pL, i+1)));
   
-  m_exec_world->createGameEvent(new vapp::MGE_Message(m_exec_world->getTime(), Out));
+  m_exec_world->createGameEvent(new MGE_Message(m_exec_world->getTime(), Out));
   return 0;
 }  
   
 int LuaLibGame::L_Game_IsPlayerInZone(lua_State *pL) {
   /* no event for this */
   bool res = false;
-  Zone* v_zone = &(m_exec_world->getLevelSrc()->getZoneById(luaL_checkstring(pL, 1)));
+  Zone* v_zone = m_exec_world->getLevelSrc()->getZoneById(luaL_checkstring(pL, 1));
 
-  for(int i=0; i<m_exec_world->Players().size(); i++) {
-    if(m_exec_world->Players()[i]->isTouching(*v_zone)) {
+  for(unsigned int i=0; i<m_exec_world->Players().size(); i++) {
+    if(m_exec_world->Players()[i]->isTouching(v_zone)) {
       res = true;
     }
   }
@@ -354,7 +363,7 @@ int LuaLibGame::L_Game_IsPlayerInZone(lua_State *pL) {
 int LuaLibGame::L_Game_MoveBlock(lua_State *pL) {
   /* event for this */
 
-  m_exec_world->createGameEvent(new vapp::MGE_MoveBlock(m_exec_world->getTime(),
+  m_exec_world->createGameEvent(new MGE_MoveBlock(m_exec_world->getTime(),
 						 luaL_checkstring(pL,1),
 						 X_luaL_check_number(pL,2),
 						 X_luaL_check_number(pL,3)));
@@ -365,16 +374,16 @@ int LuaLibGame::L_Game_GetBlockPos(lua_State *pL) {
   /* no event for this */
 
   /* Find the specified block and return its position */
-  Block &pBlock = m_exec_world->getLevelSrc()->getBlockById(luaL_checkstring(pL,1));
-  lua_pushnumber(pL,pBlock.DynamicPosition().x);
-  lua_pushnumber(pL,pBlock.DynamicPosition().y);
+  Block* pBlock = m_exec_world->getLevelSrc()->getBlockById(luaL_checkstring(pL,1));
+  lua_pushnumber(pL,pBlock->DynamicPosition().x);
+  lua_pushnumber(pL,pBlock->DynamicPosition().y);
   return 2;
 }
   
 int LuaLibGame::L_Game_SetBlockPos(lua_State *pL) {
   /* event for this */
 
-  m_exec_world->createGameEvent(new vapp::MGE_SetBlockPos(m_exec_world->getTime(),
+  m_exec_world->createGameEvent(new MGE_SetBlockPos(m_exec_world->getTime(),
 						   luaL_checkstring(pL,1),
 						   X_luaL_check_number(pL,2),
 						   X_luaL_check_number(pL,3)));
@@ -384,7 +393,7 @@ int LuaLibGame::L_Game_SetBlockPos(lua_State *pL) {
 int LuaLibGame::L_Game_SetGravity(lua_State *pL) {
   /* event for this */
 
-  m_exec_world->createGameEvent(new vapp::MGE_SetGravity(m_exec_world->getTime(),
+  m_exec_world->createGameEvent(new MGE_SetGravity(m_exec_world->getTime(),
 						  X_luaL_check_number(pL,1),
 						  X_luaL_check_number(pL,2)));
   return 0;
@@ -402,7 +411,7 @@ int LuaLibGame::L_Game_GetGravity(lua_State *pL) {
 int LuaLibGame::L_Game_SetPlayerPosition(lua_State *pL) {
   /* event for this */
   bool bRight = X_luaL_check_number(pL,3) > 0.0f;
-  m_exec_world->createGameEvent(new vapp::MGE_SetPlayersPosition(m_exec_world->getTime(),
+  m_exec_world->createGameEvent(new MGE_SetPlayersPosition(m_exec_world->getTime(),
 								 X_luaL_check_number(pL,1),
 								 X_luaL_check_number(pL,2),
 								 bRight));
@@ -431,7 +440,7 @@ int LuaLibGame::L_Game_GetEntityPos(lua_State *pL) {
   /* no event for this */
 
   /* Find the specified entity and return its position */
-  Entity *p = &(m_exec_world->getLevelSrc()->getEntityById(luaL_checkstring(pL,1)));
+  Entity *p = m_exec_world->getLevelSrc()->getEntityById(luaL_checkstring(pL,1));
   if(p != NULL) {
     lua_pushnumber(pL,p->DynamicPosition().x);
     lua_pushnumber(pL,p->DynamicPosition().y);
@@ -446,7 +455,7 @@ int LuaLibGame::L_Game_GetEntityPos(lua_State *pL) {
   
 int LuaLibGame::L_Game_GetEntityRadius(lua_State *pL) {
   /* no event for this */
-  lua_pushnumber(pL, m_exec_world->getLevelSrc()->getEntityById(luaL_checkstring(pL,1)).Size());
+  lua_pushnumber(pL, m_exec_world->getLevelSrc()->getEntityById(luaL_checkstring(pL,1))->Size());
   return 1;
 }
 
@@ -465,7 +474,7 @@ int LuaLibGame::L_Game_IsEntityTouched(lua_State *pL) {
 
 int LuaLibGame::L_Game_SetEntityPos(lua_State *pL) {
   /* event for this */
-  m_exec_world->createGameEvent(new vapp::MGE_SetEntityPos(m_exec_world->getTime(),
+  m_exec_world->createGameEvent(new MGE_SetEntityPos(m_exec_world->getTime(),
 						    luaL_checkstring(pL,1),
 						    X_luaL_check_number(pL,2),
 						    X_luaL_check_number(pL,3)));
@@ -493,7 +502,7 @@ int LuaLibGame::L_Game_GetKeyByAction(lua_State *pL) {
 
 int LuaLibGame::L_Game_SetBlockCenter(lua_State *pL) {
   /* event for this */    
-  m_exec_world->createGameEvent(new vapp::MGE_SetBlockCenter(m_exec_world->getTime(),
+  m_exec_world->createGameEvent(new MGE_SetBlockCenter(m_exec_world->getTime(),
 						      luaL_checkstring(pL,1),
 						      X_luaL_check_number(pL,2),
 						      X_luaL_check_number(pL,3)));
@@ -502,7 +511,7 @@ int LuaLibGame::L_Game_SetBlockCenter(lua_State *pL) {
     
 int LuaLibGame::L_Game_SetBlockRotation(lua_State *pL) {
   /* event for this */    
-  m_exec_world->createGameEvent(new vapp::MGE_SetBlockRotation(m_exec_world->getTime(),
+  m_exec_world->createGameEvent(new MGE_SetBlockRotation(m_exec_world->getTime(),
 							luaL_checkstring(pL,1),
 							X_luaL_check_number(pL,2)));
   return 0;
@@ -510,103 +519,103 @@ int LuaLibGame::L_Game_SetBlockRotation(lua_State *pL) {
     
 int LuaLibGame::L_Game_SetDynamicEntityRotation(lua_State *pL) {
   /* event for this */    
-  m_exec_world->createGameEvent(new vapp::MGE_SetDynamicEntityRotation(m_exec_world->getTime(),
-								luaL_checkstring(pL,1),
-								X_luaL_check_number(pL,2),
-								X_luaL_check_number(pL,3),
-								X_luaL_check_number(pL,4),
-								X_luaL_check_number(pL,5),
-								X_luaL_check_number(pL,6))); 
+  m_exec_world->createGameEvent(new MGE_SetDynamicEntityRotation(m_exec_world->getTime(),
+								 luaL_checkstring(pL,1),
+								 X_luaL_check_number(pL,2),
+								 X_luaL_check_number(pL,3),
+								 (int)(X_luaL_check_number(pL,4)),
+								 (int)X_luaL_check_number(pL,5),
+								 (int)X_luaL_check_number(pL,6))); 
   return 0;
 }
 
 int LuaLibGame::L_Game_SetDynamicEntitySelfRotation(lua_State *pL) {
   /* event for this */
-  m_exec_world->createGameEvent(new vapp::MGE_SetDynamicEntitySelfRotation(m_exec_world->getTime(),
-									   luaL_checkstring(pL,1),
-									   X_luaL_check_number(pL,2),
-									   X_luaL_check_number(pL,3),
-									   X_luaL_check_number(pL,4))); 
+  m_exec_world->createGameEvent(new MGE_SetDynamicEntitySelfRotation(m_exec_world->getTime(),
+								     luaL_checkstring(pL,1),
+								     (int)(X_luaL_check_number(pL,2)),
+								     (int)X_luaL_check_number(pL,3),
+								     (int)X_luaL_check_number(pL,4))); 
   return 0;
 }
 
 int LuaLibGame::L_Game_SetDynamicEntityTranslation(lua_State *pL) {
   /* event for this */    
-  m_exec_world->createGameEvent(new vapp::MGE_SetDynamicEntityTranslation(m_exec_world->getTime(),
-								   luaL_checkstring(pL,1),
-								   X_luaL_check_number(pL,2),
-								   X_luaL_check_number(pL,3),
-								   X_luaL_check_number(pL,4),
-								   X_luaL_check_number(pL,5),
-								   X_luaL_check_number(pL,6)));
+  m_exec_world->createGameEvent(new MGE_SetDynamicEntityTranslation(m_exec_world->getTime(),
+								    luaL_checkstring(pL,1),
+								    X_luaL_check_number(pL,2),
+								    X_luaL_check_number(pL,3),
+								    (int)(X_luaL_check_number(pL,4)),
+								    (int)X_luaL_check_number(pL,5),
+								    (int)X_luaL_check_number(pL,6)));
   return 0;
 }
 
 int LuaLibGame::L_Game_SetDynamicEntityNone(lua_State *pL) {
   /* event for this */    
-  m_exec_world->createGameEvent(new vapp::MGE_SetDynamicEntityNone(m_exec_world->getTime(),
+  m_exec_world->createGameEvent(new MGE_SetDynamicEntityNone(m_exec_world->getTime(),
 							    luaL_checkstring(pL,1)));
   return 0;
 }
 
 int LuaLibGame::L_Game_SetDynamicBlockRotation(lua_State *pL) {
   /* event for this */
-  m_exec_world->createGameEvent(new vapp::MGE_SetDynamicBlockRotation(m_exec_world->getTime(),
-							       luaL_checkstring(pL,1),
-							       X_luaL_check_number(pL,2),
-							       X_luaL_check_number(pL,3),
-							       X_luaL_check_number(pL,4),
-							       X_luaL_check_number(pL,5),
-							       X_luaL_check_number(pL,6))); 
+  m_exec_world->createGameEvent(new MGE_SetDynamicBlockRotation(m_exec_world->getTime(),
+								luaL_checkstring(pL,1),
+								X_luaL_check_number(pL,2),
+								X_luaL_check_number(pL,3),
+								(int)(X_luaL_check_number(pL,4)),
+								(int)X_luaL_check_number(pL,5),
+								(int)X_luaL_check_number(pL,6)));
   return 0;
 }
 
 int LuaLibGame::L_Game_SetDynamicBlockSelfRotation(lua_State *pL) {
   /* event for this */
-  m_exec_world->createGameEvent(new vapp::MGE_SetDynamicBlockSelfRotation(m_exec_world->getTime(),
-									  luaL_checkstring(pL,1),
-									  X_luaL_check_number(pL,2),
-									  X_luaL_check_number(pL,3),
-									  X_luaL_check_number(pL,4))); 
+  m_exec_world->createGameEvent(new MGE_SetDynamicBlockSelfRotation(m_exec_world->getTime(),
+								    luaL_checkstring(pL,1),
+								    (int)(X_luaL_check_number(pL,2)),
+								    (int)X_luaL_check_number(pL,3),
+								    (int)X_luaL_check_number(pL,4))); 
   return 0;
 }
 
 int LuaLibGame::L_Game_SetDynamicBlockTranslation(lua_State *pL) {
   /* event for this */    
-  m_exec_world->createGameEvent(new vapp::MGE_SetDynamicBlockTranslation(m_exec_world->getTime(),
-								  luaL_checkstring(pL,1),
-								  X_luaL_check_number(pL,2),
-								  X_luaL_check_number(pL,3),
-								  X_luaL_check_number(pL,4),
-								  X_luaL_check_number(pL,5),
-								  X_luaL_check_number(pL,6)));
+  m_exec_world->createGameEvent(new MGE_SetDynamicBlockTranslation(m_exec_world->getTime(),
+								   luaL_checkstring(pL,1),
+								   X_luaL_check_number(pL,2),
+								   X_luaL_check_number(pL,3),
+								   (int)(X_luaL_check_number(pL,4)),
+								   (int)X_luaL_check_number(pL,5),
+								   (int)X_luaL_check_number(pL,6)));
   return 0;
 }
 
 int LuaLibGame::L_Game_SetDynamicBlockNone(lua_State *pL) {
   /* event for this */    
-  m_exec_world->createGameEvent(new vapp::MGE_SetDynamicBlockNone(m_exec_world->getTime(),
+  m_exec_world->createGameEvent(new MGE_SetDynamicBlockNone(m_exec_world->getTime(),
 							   luaL_checkstring(pL,1)));
   return 0;
 }
 
 int LuaLibGame::L_Game_CameraZoom(lua_State *pL) {
   /* event for this */
-  m_exec_world->createGameEvent(new vapp::MGE_CameraZoom(m_exec_world->getTime(),
+  m_exec_world->createGameEvent(new MGE_CameraZoom(m_exec_world->getTime(),
 						  X_luaL_check_number(pL,1)));
   return 0;
 }
 
 int LuaLibGame::L_Game_CameraMove(lua_State *pL) {
   /* event for this */
-  m_exec_world->createGameEvent(new vapp::MGE_CameraMove(m_exec_world->getTime(),
+  m_exec_world->createGameEvent(new MGE_CameraMove(m_exec_world->getTime(),
 						  X_luaL_check_number(pL,1),
 						  X_luaL_check_number(pL,2)));
   return 0;
 }
 
 int LuaLibGame::L_Game_KillPlayer(lua_State *pL) {
-  m_exec_world->createGameEvent(new vapp::MGE_PlayersDie(m_exec_world->getTime(), false));
+  m_exec_world->createGameEvent(new MGE_PlayersDie(m_exec_world->getTime(), false));
   return 0;
 }
 
@@ -630,39 +639,39 @@ int LuaLibGame::L_Game_WinPlayer(lua_State *pL) {
 
 int LuaLibGame::L_Game_PenaltyTime(lua_State *pL) {
   /* event for this */
-  m_exec_world->createGameEvent(new vapp::MGE_PenalityTime(m_exec_world->getTime(),
-						    X_luaL_check_number(pL,1)));
+  m_exec_world->createGameEvent(new MGE_PenalityTime(m_exec_world->getTime(),
+						     (int)(X_luaL_check_number(pL,1)*100)));
   return 0;
 }
 
 int LuaLibGame::L_Game_IsAPlayerInZone(lua_State *pL) {
   /* no event for this */
-  Zone* v_zone = &(m_exec_world->getLevelSrc()->getZoneById(luaL_checkstring(pL, 1)));
-  int v_player = X_luaL_check_number(pL, 2);
+  Zone* v_zone = m_exec_world->getLevelSrc()->getZoneById(luaL_checkstring(pL, 1));
+  int v_player = (int)X_luaL_check_number(pL, 2);
 
-  if(v_player < 0 || v_player >= m_exec_world->Players().size()) {
+  if(v_player < 0 || (unsigned int)v_player >= m_exec_world->Players().size()) {
     std::ostringstream v_txt_player;
     v_txt_player << v_player;
     throw Exception("Invalid player " + v_txt_player.str());
   }
 
-  lua_pushboolean(pL, m_exec_world->Players()[v_player]->isTouching(*v_zone)?1:0);
+  lua_pushboolean(pL, m_exec_world->Players()[v_player]->isTouching(v_zone)?1:0);
   return 1;
 }
 
 int LuaLibGame::L_Game_SetAPlayerPosition(lua_State *pL) {
   /* event for this */
   bool bRight  = X_luaL_check_number(pL,3) > 0.0f;
-  int v_player = X_luaL_check_number(pL,4);
+  int v_player = (int)X_luaL_check_number(pL,4);
 
-  if(v_player < 0 || v_player >= m_exec_world->Players().size()) {
+  if(v_player < 0 || (unsigned int)v_player >= m_exec_world->Players().size()) {
     std::ostringstream v_txt_player;
     v_txt_player << v_player;
     printf("player is %i\n", v_player);
     //throw Exception("Invalid player " + v_txt_player.str());
   }
 
-  m_exec_world->createGameEvent(new vapp::MGE_SetPlayerPosition(m_exec_world->getTime(),
+  m_exec_world->createGameEvent(new MGE_SetPlayerPosition(m_exec_world->getTime(),
 								X_luaL_check_number(pL,1),
 								X_luaL_check_number(pL,2),
 								bRight,
@@ -675,9 +684,9 @@ int LuaLibGame::L_Game_GetAPlayerPosition(lua_State *pL) {
   float x = 0.0, y = 0.0;
   DriveDir v_direction = DD_RIGHT;
 
-  int v_player = X_luaL_check_number(pL,1);
+  int v_player = (int)X_luaL_check_number(pL,1);
 
-  if(v_player < 0 || v_player >= m_exec_world->Players().size()) {
+  if(v_player < 0 || (unsigned int)v_player >= m_exec_world->Players().size()) {
     std::ostringstream v_txt_player;
     v_txt_player << v_player;
     throw Exception("Invalid player " + v_txt_player.str());
@@ -695,22 +704,22 @@ int LuaLibGame::L_Game_GetAPlayerPosition(lua_State *pL) {
 }
 
 int LuaLibGame::L_Game_KillAPlayer(lua_State *pL) {
-  int v_player = X_luaL_check_number(pL,1);
+  int v_player = (int)X_luaL_check_number(pL,1);
 
-  if(v_player < 0 || v_player >= m_exec_world->Players().size()) {
+  if(v_player < 0 || (unsigned int)v_player >= m_exec_world->Players().size()) {
     std::ostringstream v_txt_player;
     v_txt_player << v_player;
     throw Exception("Invalid player " + v_txt_player.str());
   }
 
-  m_exec_world->createGameEvent(new vapp::MGE_PlayerDies(m_exec_world->getTime(), false, v_player));
+  m_exec_world->createGameEvent(new MGE_PlayerDies(m_exec_world->getTime(), false, v_player));
   return 0;
 }
 
 int LuaLibGame::L_Game_WinAPlayer(lua_State *pL) {
-  int v_player = X_luaL_check_number(pL,1);
+  int v_player = (int)X_luaL_check_number(pL,1);
 
-  if(v_player < 0 || v_player >= m_exec_world->Players().size()) {
+  if(v_player < 0 || (unsigned int)v_player >= m_exec_world->Players().size()) {
     std::ostringstream v_txt_player;
     v_txt_player << v_player;
     throw Exception("Invalid player " + v_txt_player.str());
@@ -727,22 +736,48 @@ int LuaLibGame::L_Game_NumberOfPlayers(lua_State *pL) {
 
 
 int LuaLibGame::L_Game_CameraRotate(lua_State *pL) {
-  m_exec_world->createGameEvent(new vapp::MGE_CameraRotate(m_exec_world->getTime(),
+  m_exec_world->createGameEvent(new MGE_CameraRotate(m_exec_world->getTime(),
 							   X_luaL_check_number(pL,1)));
   return 0;
 }
 
 int LuaLibGame::L_Game_CameraAdaptToGravity(lua_State *pL) {
-  m_exec_world->createGameEvent(new vapp::MGE_CameraAdaptToGravity(m_exec_world->getTime()));
+  m_exec_world->createGameEvent(new MGE_CameraAdaptToGravity(m_exec_world->getTime()));
   return 0;
 }
 
 int LuaLibGame::L_Game_AddForceToPlayer(lua_State *pL) {
   /* event for this */
-  m_exec_world->createGameEvent(new vapp::MGE_AddForceToPlayer(m_exec_world->getTime(),
-							       Vector2f(X_luaL_check_number(pL,1),
-									X_luaL_check_number(pL,2)),
-							       X_luaL_check_number(pL,3)
-							       ));
+  m_exec_world->createGameEvent(new MGE_AddForceToPlayer(m_exec_world->getTime(),
+							 Vector2f(X_luaL_check_number(pL,1),
+								  X_luaL_check_number(pL,2)),
+							 (int)X_luaL_check_number(pL,3),
+							 (int)X_luaL_check_number(pL,4),
+							 (int)X_luaL_check_number(pL,5)));
   return 0;
 }  
+
+int LuaLibGame::L_Game_SetCameraRotationSpeed(lua_State *pL) {
+  m_exec_world->createGameEvent(new MGE_SetCameraRotationSpeed(m_exec_world->getTime(),X_luaL_check_number(pL,1)));
+  return 0;
+}
+
+int LuaLibGame::L_Game_PlaySound(lua_State *pL) {
+  if(lua_gettop(pL) == 1) { // if there are 2 arguments, consider the 2nd one
+    m_exec_world->createGameEvent(new MGE_PlaySound(m_exec_world->getTime(),luaL_checkstring(pL,1)));
+  } else {
+    m_exec_world->createGameEvent(new MGE_PlaySound(m_exec_world->getTime(),luaL_checkstring(pL,1), X_luaL_check_number(pL,2)));
+  }
+
+  return 0;
+}
+
+int LuaLibGame::L_Game_PlayMusic(lua_State *pL) {
+  m_exec_world->createGameEvent(new MGE_PlayMusic(m_exec_world->getTime(),luaL_checkstring(pL,1)));
+  return 0;
+}
+
+int LuaLibGame::L_Game_StopMusic(lua_State *pL) {
+  m_exec_world->createGameEvent(new MGE_StopMusic(m_exec_world->getTime()));
+  return 0;
+}
