@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -36,7 +35,7 @@ if you want to be able to play levels besides your own...
 #define PHYS_WORLD_GRAV               -9.81f    /* Grav. acceleration */
 #define PHYS_SPEED                    0.6f      /* simulation speed factor */
 #define PHYS_QSTEP_ITERS              10
-#define PHYS_STEP_SIZE                0.01f
+#define PHYS_STEP_SIZE                1
 
 /* Bike geometrical settings */
 #define PHYS_WHEEL_RADIUS             0.35f
@@ -94,7 +93,7 @@ if you want to be able to play levels besides your own...
 #define PHYS_MAX_ROLL_VELOCITY        60
 
 /* Friction */
-#define DEFAULT_PHYS_WHEEL_GRIP       20
+#define DEFAULT_PHYS_WHEEL_GRIP       20.0
 #define PHYS_WHEEL_ERP                0.8
 #define PHYS_WHEEL_CFM                0.00001
 
