@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -34,16 +33,19 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include <iostream>
 //#include <locale> /* can this safely be removed? */
 
+#include "helpers/Log.h"
 #include "helpers/SwapEndian.h"
-
-namespace vapp {
+#include "GameEvents.h"
+#include "Game.h"
+#include "xmscene/Bike.h"
+#include "db/xmDatabase.h"
 
   bool Replay::m_bEnableCompression = true;
 
   Replay::Replay() {
     m_bFinished = false;
     m_bEndOfFile = false;
-    m_fFinishTime = 0.0f;
+    m_finishTime = 0;
     m_pcInputEventsData = NULL;
     m_nInputEventsDataSize = 0;
   }
@@ -55,14 +57,14 @@ namespace vapp {
   void Replay::_FreeReplay(void) {
 
     /* Get rid of replay events */
-    for(int i=0;i<m_ReplayEvents.size();i++) {
+    for(unsigned int i=0;i<m_ReplayEvents.size();i++) {
       delete m_ReplayEvents[i]->Event;
       delete m_ReplayEvents[i];
     }
     m_ReplayEvents.clear();
 
     /* Dealloc chunks */
-    for(int i=0;i<m_Chunks.size();i++) {
+    for(unsigned int i=0;i<m_Chunks.size();i++) {
       if(m_Chunks[i]->pcChunkData != NULL) {
         delete [] m_Chunks[i]->pcChunkData;
       }
@@ -76,13 +78,14 @@ namespace vapp {
     }
   }
   
-  void Replay::finishReplay(bool bFinished,float fFinishTime) {
-    m_fFinishTime = fFinishTime;
+  void Replay::finishReplay(bool bFinished, int finishTime) {
+    m_finishTime = finishTime;
     m_bFinished = bFinished;
     saveReplay();
   }
   
-  void Replay::createReplay(const std::string &FileName,const std::string &LevelID,const std::string &Player,float fFrameRate,int nStateSize) {
+  void Replay::createReplay(const std::string &FileName, const std::string &LevelID,
+			    const std::string &Player, float fFrameRate, unsigned int nStateSize) {
     m_FileName = FileName;
     m_LevelID = LevelID;
     m_PlayerName = Player;
@@ -96,7 +99,7 @@ namespace vapp {
     /* Save it */
     FileHandle *pfh = FS::openOFile(std::string("Replays/") + m_FileName);
     if(pfh == NULL) {
-      Log("** Warning ** : Failed to open replay file for output: %s",(std::string("Replays/") + m_FileName).c_str());
+      Logger::Log("** Warning ** : Failed to open replay file for output: %s",(std::string("Replays/") + m_FileName).c_str());
       return;
     }        
     
@@ -108,7 +111,7 @@ namespace vapp {
     FS::writeFloat_LE(pfh,m_fFrameRate);
     FS::writeInt_LE(pfh,m_nStateSize);
     FS::writeBool(pfh,m_bFinished);
-    FS::writeFloat_LE(pfh,m_fFinishTime);
+    FS::writeFloat_LE(pfh, GameApp::timeToFloat(m_finishTime));
     
     /* Events */
     const char *pcUncompressedEvents = convertOutputToInput();
@@ -145,7 +148,7 @@ namespace vapp {
     FS::writeInt_LE(pfh,m_Chunks.size());
     
     /* Write chunks */    
-    for(int i=0;i<m_Chunks.size();i++) {
+    for(unsigned int i=0;i<m_Chunks.size();i++) {
       FS::writeInt_LE(pfh,m_Chunks[i]->nNumStates);
       
       /* Compression enabled? */
@@ -186,7 +189,7 @@ namespace vapp {
         /* Try adding a .rpl extension */
         pfh = FS::openIFile(std::string("Replays/") + FileName + std::string(".rpl"));
         if(pfh == NULL) {    
-          Log("** Warning ** : Failed to open replay file for input: %s",(std::string("Replays/") + FileName).c_str());
+          Logger::Log("** Warning ** : Failed to open replay file for input: %s",(std::string("Replays/") + FileName).c_str());
           throw Exception("Unable to open the replay");
         }
       }
@@ -201,13 +204,13 @@ namespace vapp {
     /* Supported version? */
     if(nVersion != 0 && nVersion != 1) {
       FS::closeFile(pfh);
-      Log("** Warning ** : Unsupported replay file version (%d): %s",nVersion,(std::string("Replays/") + FileName).c_str());
+      Logger::Log("** Warning ** : Unsupported replay file version (%d): %s",nVersion,(std::string("Replays/") + FileName).c_str());
       throw Exception("Unable to open the replay");
     } else {
       /* Little/big endian safety check */
       if(FS::readInt_LE(pfh) != 0x12345678) {
         FS::closeFile(pfh);
-        Log("** Warning ** : Sorry, the replay you're trying to open are not endian-compatible with your computer!");
+        Logger::Log("** Warning ** : Sorry, the replay you're trying to open are not endian-compatible with your computer!");
         throw Exception("Unable to open the replay");        
       }
   
@@ -234,10 +237,10 @@ namespace vapp {
       
       /* Read finish time if any */
       m_bFinished = FS::readBool(pfh);
-      m_fFinishTime = FS::readFloat_LE(pfh);
+      m_finishTime = GameApp::floatToTime(FS::readFloat_LE(pfh));
       if(bDisplayInformation) {
 	if(m_bFinished) {
-	  printf("%-30s: %.2f (%f)\n", "Finish time", m_fFinishTime, m_fFinishTime);
+	  printf("%-30s: %.2f (%f)\n", "Finish time", m_finishTime / 100.0, m_finishTime / 100.0);
 	} else {
 	  printf("%-30s: %s\n", "Finish time", "unfinished");
 	}
@@ -272,7 +275,7 @@ namespace vapp {
             delete [] m_pcInputEventsData; m_pcInputEventsData = NULL;
             FS::closeFile(pfh);
             _FreeReplay();
-            Log("** Warning ** : Failed to uncompress events in replay: %s",FileName.c_str());
+            Logger::Log("** Warning ** : Failed to uncompress events in replay: %s",FileName.c_str());
             throw Exception("Unable to open the replay");
           }
           
@@ -289,18 +292,18 @@ namespace vapp {
       }
       
       /* Read chunks */
-      int nNumChunks = FS::readInt_LE(pfh);
+      unsigned int nNumChunks = FS::readInt_LE(pfh);
       if(bDisplayInformation) {
 	printf("%-30s: %i\n", "Number of chunks", nNumChunks);
       }
       if(nNumChunks == 0) {
 	FS::closeFile(pfh);
 	_FreeReplay();
-	Log("** Warning ** : try to open a replay with no chunk");
+	Logger::Log("** Warning ** : try to open a replay with no chunk");
 	throw Exception("Replay with no chunk !");
       }
 
-      for(int i=0;i<nNumChunks;i++) {
+      for(unsigned int i=0;i<nNumChunks;i++) {
 	if(bDisplayInformation) {
 	  printf("Chunk %02i\n", i);
 	}  
@@ -335,7 +338,7 @@ namespace vapp {
           uLongf nSrcLen = nCompressedSize;
           int nZRet = uncompress((Bytef *)Chunk->pcChunkData,&nDestLen,(Bytef *)pcCompressed,nSrcLen);
           if(nZRet != Z_OK || nDestLen != Chunk->nNumStates * m_nStateSize) {
-            Log("** Warning ** : Failed to uncompress chunk %d in replay: %s",i,FileName.c_str());
+            Logger::Log("** Warning ** : Failed to uncompress chunk %d in replay: %s",i,FileName.c_str());
             delete [] pcCompressed;
             Chunk->pcChunkData = NULL;
             FS::closeFile(pfh);
@@ -373,7 +376,7 @@ namespace vapp {
     /* unserialize events */
     MotoGame::unserializeGameEvents(this, &m_ReplayEvents, bDisplayInformation);
     initOutput(1024);
-    for(int i=0; i<m_ReplayEvents.size(); i++) {
+    for(unsigned int i=0; i<m_ReplayEvents.size(); i++) {
       m_ReplayEvents[i]->Event->serialize(*this);
     }
 
@@ -409,62 +412,62 @@ namespace vapp {
   }
   
   int Replay::CurrentFrame() const {
-    return m_nCurChunk * STATES_PER_CHUNK + m_nCurState + 1;
+    return (int)(m_nCurChunk * STATES_PER_CHUNK + m_nCurState + 1);
   }
 
   bool Replay::nextNormalState() {
     return nextState(1);
   }
 
-  bool Replay::nextState(float p_frames) {
-    m_bEndOfFile = false;
+bool Replay::nextState(int p_frames) {
+  m_bEndOfFile = false;
 
-    m_nCurState += p_frames;
+  m_nCurState += p_frames;
 
-    /* end or start of a chunk */
-    if(m_nCurState >= STATES_PER_CHUNK || m_nCurState < 0.0) {
+  /* end or start of a chunk */
+  if(m_nCurState >= STATES_PER_CHUNK || m_nCurState < 0.0) {
 
-      /* go on the following chunk */
-      if(m_nCurState >= STATES_PER_CHUNK) { /* end of a chunk */
-  if(m_nCurChunk < m_Chunks.size() -1) {
-    m_nCurState = m_nCurState - m_Chunks[m_nCurChunk]->nNumStates -1;
-    m_nCurChunk++;
-  }
-      } else {
-  if(m_nCurState < 0.0) { /* start of a chunk */
-    if(m_nCurChunk > 0) {
-      m_nCurState = m_nCurState + m_Chunks[m_nCurChunk-1]->nNumStates -1;
-      m_nCurChunk--;
+    /* go on the following chunk */
+    if(m_nCurState >= STATES_PER_CHUNK) { /* end of a chunk */
+      if(m_nCurChunk < m_Chunks.size() - 1) {
+	m_nCurState = m_nCurState - m_Chunks[m_nCurChunk]->nNumStates -1;
+	m_nCurChunk++;
+      }
+    } else {
+      if(m_nCurState < 0.0) { /* start of a chunk */
+	if(m_nCurChunk > 0) {
+	  m_nCurState = m_nCurState + m_Chunks[m_nCurChunk-1]->nNumStates -1;
+	  m_nCurChunk--;
+	}
+      }
     }
-  }
-      }
 
-      /* if that's the beginning */
-      if(m_nCurState < 0.0) {
-  m_nCurState = 0.0;
-      }
+    /* if that's the beginning */
+    if(m_nCurState < 0.0) {
+      m_nCurState = 0.0;
+    }
 
-      /* if that's end */
-      if(m_nCurState >= m_Chunks[m_nCurChunk]->nNumStates) {
-  m_nCurState = m_Chunks[m_nCurChunk]->nNumStates -1;
-  return false;
-      }
+    /* if that's end */
+    if(m_nCurState >= m_Chunks[m_nCurChunk]->nNumStates) {
+      m_nCurState = m_Chunks[m_nCurChunk]->nNumStates -1;
+      return false;
+    }
       
-    } else { /* that's not the end or the start of the chunk */
+  } else { /* that's not the end or the start of the chunk */
 
-      /* if that's the beginning, do nothing */
+    /* if that's the beginning, do nothing */
 
-      /* if that's end */
-      if(m_nCurState >= m_Chunks[m_nCurChunk]->nNumStates) {
-  m_nCurState = m_Chunks[m_nCurChunk]->nNumStates -1;
-  return false;
-      }
+    /* if that's end */
+    if(m_nCurState >= m_Chunks[m_nCurChunk]->nNumStates) {
+      m_nCurState = m_Chunks[m_nCurChunk]->nNumStates -1;
+      return false;
     }
-    
-    return true;
   }
+    
+  return true;
+}
 
-  void Replay::loadState(SerializedBikeState& state) {
+  void Replay::loadState(BikeState* state) {
     /* (11th july, 2006) rasmus: i've swapped the two following lines, it apparently fixes
        interpolation in replays, but i don't know if it break something else */  
     peekState(state);
@@ -477,12 +480,14 @@ namespace vapp {
     }
   }
   
-  void Replay::peekState(SerializedBikeState& state) {
+  void Replay::peekState(BikeState* state) {
+    SerializedBikeState v_bs;
+
     /* Like loadState() but this one does not advance the cursor... it just takes a peek */
-    memcpy((char *)&state,
-     &m_Chunks[m_nCurChunk]->pcChunkData[((int)m_nCurState)*m_nStateSize],
-     m_nStateSize);
-    SwapEndian::LittleSerializedBikeState(state);
+    memcpy((char *)&v_bs, &m_Chunks[m_nCurChunk]->pcChunkData[((int)m_nCurState)*m_nStateSize], m_nStateSize);
+    SwapEndian::LittleSerializedBikeState(v_bs);
+
+    BikeState::convertStateFromReplay(&v_bs, state);
   }
   
   std::string Replay::giveAutomaticName() {
@@ -502,7 +507,7 @@ namespace vapp {
     m_bEndOfFile = false;
 
     /* resetting events */
-    for(int i=0;i<m_ReplayEvents.size();i++) {
+    for(unsigned int i=0;i<m_ReplayEvents.size();i++) {
       m_ReplayEvents[i]->bPassed = false;
     }
   }
@@ -522,7 +527,10 @@ namespace vapp {
       /* Try opening it */
       FileHandle *pfh = FS::openIFile("Replays/" + p_ReplayName + ".rpl");
       if(pfh == NULL) {
-	return NULL;
+	pfh = FS::openIFile(p_ReplayName);
+	if(pfh == NULL) {
+	  return NULL;
+	}
       }
       
       int nVersion = FS::readByte(pfh);
@@ -538,10 +546,10 @@ namespace vapp {
   
       std::string LevelID = FS::readString(pfh);
       std::string Player  = FS::readString(pfh);
-      float fFrameRate    = FS::readFloat_LE(pfh);
-      int nStateSize      = FS::readInt_LE(pfh);
+      /*float fFrameRate    = */ FS::readFloat_LE(pfh);
+      /*int nStateSize      = */ FS::readInt_LE(pfh);
       bool bFinished      = FS::readBool(pfh);
-      float fFinishTime   = FS::readFloat_LE(pfh);
+      int finishTime   = GameApp::floatToTime(FS::readFloat_LE(pfh));
                 
       ReplayInfo *pRpl     = new ReplayInfo;
 
@@ -552,25 +560,52 @@ namespace vapp {
       pRpl->IsFinished = bFinished;
 
       if(bFinished) {
-	pRpl->fFinishTime = fFinishTime;
+	pRpl->finishTime = finishTime;
       } else {
-	pRpl->fFinishTime = -1;                
+	pRpl->finishTime = -1;                
       }
           
       FS::closeFile(pfh);
       return pRpl;
   }
 
-  void Replay::fastforward(float fSeconds) {
+  void Replay::fastforward(int i_time) {
     /* How many states should we move forward? */
-    float nNumStates = (fSeconds * m_fFrameRate);
+    int nNumStates = (int)((i_time * m_fFrameRate) / 100);
     nextState(nNumStates);
   }
 
-  void Replay::fastrewind(float fSeconds) {
+  void Replay::fastrewind(int i_time, int i_minimumNbFrame) {
     /* How many states should we move forward? */
-    float nNumStates = (fSeconds * m_fFrameRate);
-    nextState(-nNumStates);
+    int nNumStates = (int)( (i_time * m_fFrameRate) / 100);
+    nextState(nNumStates < i_minimumNbFrame ? -i_minimumNbFrame : -nNumStates);
   } 
 
+void Replay::cleanReplays(xmDatabase *i_db) {
+}
+
+int  Replay::cleanReplaysNb(xmDatabase *i_db) {
+  //char **v_result;
+  //unsigned int nrow;
+  int n;
+
+  /* SELECT replay of from replay_% and %-%-% %_% which are not best replays for the (id_level, id_room, id_profile) if id_profile is in profiles or (id_level, id_room) else */
+
+//  SELECT name
+//  FROM replays AS a
+//  LEFT OUTER JOIN webhighscores AS b ON (a.id_level = b.id_level AND b.fileUrl NOT LIKE '%/' + a.name + '.rpl')
+//  WHERE a.name LIKE 'replay_%'
+//  AND   
+// ;
+
+//  v_result = i_db->readDB("SELECT count(name) FROM replays;", nrow);
+//  if(nrow != 1) {
+//    i_db->read_DB_free(v_result);
+//    throw Exception("Unable to determine the number of replays to clean");
+//  }
+//  n = atoi(i_db->getResult(v_result, 1, 0, 0));
+//  i_db->read_DB_free(v_result);
+  n = 0;
+
+  return n;
 }
