@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -23,14 +22,13 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #define __REPLAY_H__
 
 #include "VCommon.h"
-#include "VApp.h"
 #include "VFileIO.h"
 #include "DBuffer.h"
 #include "xmscene/Scene.h"
 
 #define STATES_PER_CHUNK 512
 
-namespace vapp {
+class BikeState;
 
   /*===========================================================================
   Structs
@@ -42,7 +40,7 @@ namespace vapp {
     std::string Player;
     std::string Level;
     bool  IsFinished;
-    float fFinishTime;
+    int finishTime;
   };
   
   /* Replays states (frames) are grouped together in chunks for easy
@@ -63,25 +61,29 @@ namespace vapp {
       /* Methods */
       void storeState(const SerializedBikeState& state);
       /* go and get the next state */
-      void loadState(SerializedBikeState& state);  
-      void peekState(SerializedBikeState& state); /* get current state */
+      void loadState(BikeState* state);  
+      void peekState(BikeState* state); /* get current state */
       
-      void createReplay(const std::string &FileName,const std::string &LevelID,const std::string &Player,float fFrameRate,int nStateSize);
+      void createReplay(const std::string &FileName,const std::string &LevelID,const std::string &Player,float fFrameRate,unsigned int nStateSize);
       void saveReplay(void);
       std::string openReplay(const std::string &FileName, std::string &Player, bool bDisplayInformation = false);
+
       static void deleteReplay(std::string ReplayName);
+      static void cleanReplays(xmDatabase *i_db);
+      static int  cleanReplaysNb(xmDatabase *i_db); // nb replays that cleanReplays() would clean
+
       void reinitialize();
       std::string getLevelId();
 
-      void finishReplay(bool bFinished,float fFinishTime);
+      void finishReplay(bool bFinished,int finishTime);
       int CurrentFrame() const;
 
-      void fastforward(float fSeconds);
-      void fastrewind(float fSeconds);
+      void fastforward(int i_time);
+      void fastrewind(int i_time, int i_minimumNbFrame = 0); // i_minimumNbFrame, because sometimes, rewind do nothing if i_time it too small
 
       /* Data interface */
       bool didFinish(void) {return m_bFinished;}
-      float getFinishTime(void) {return m_fFinishTime;}     
+      int getFinishTime(void) {return m_finishTime;}     
       float getFrameRate(void) {return m_fFrameRate;} 
       const std::string &getPlayerName(void) {return m_PlayerName;}
       bool endOfFile(void) {return m_bEndOfFile;}
@@ -99,20 +101,20 @@ namespace vapp {
     private: 
       /* Data */ 
       std::vector<ReplayStateChunk*> m_Chunks;
-      int m_nCurChunk;
+      unsigned int m_nCurChunk;
       float m_nCurState; /* is a float so that manage slow */   
       std::string m_FileName,m_LevelID,m_PlayerName;
       float m_fFrameRate;
-      int m_nStateSize;
+      unsigned int m_nStateSize;
       bool m_bFinished;
       bool m_bEndOfFile;
-      float m_fFinishTime;
+      int m_finishTime;
       char *m_pcInputEventsData;
-      int m_nInputEventsDataSize;
+      unsigned int m_nInputEventsDataSize;
  
       /* Helpers */
       void _FreeReplay(void);
-      bool nextState(float p_frames); /* go to the next state */
+      bool nextState(int p_frames); /* go to the next state */
       bool nextNormalState(); /* go to the next state */
       
       /* Static data */
@@ -122,7 +124,5 @@ namespace vapp {
       std::vector<RecordedGameEvent *> m_ReplayEvents;
   };
 
-}
-
 #endif
 
