@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -23,25 +22,26 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #define __SYSMESSAGE_H__
 
 #include <string>
+#include "helpers/Singleton.h"
 
-namespace vapp {
-  class DrawLib;
-}
+class DrawLib;
 
-class SysMessage {
-  public:
+class SysMessage : public Singleton<SysMessage> {
+  friend class Singleton<SysMessage>;
 
+private:
   SysMessage();
   ~SysMessage();
 
-  void setDrawLib(vapp::DrawLib* i_drawLib);
+public:
+  void setDrawLib(DrawLib* i_drawLib);
   void displayText(std::string i_msg);
   void render();
 
-  private:
+private:
   std::string m_txt;
   float m_startDisplay;
-  vapp::DrawLib* m_drawLib;
+  DrawLib* m_drawLib;
 };
 
 #endif
