@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -22,17 +21,17 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "Theme.h"
 #include "helpers/VExcept.h"
 #include "VXml.h"
-#include "VApp.h"
+#include "Game.h"
 #include "md5sum/md5file.h"
 #include "db/xmDatabase.h"
-
-class vapp::App;
+#include "helpers/Log.h"
+#include "VFileIO.h"
 
 std::vector<Sprite*> Theme::getSpritesList() {
   return m_sprites;
 }
 
-std::vector<Sound*> Theme::getSoundsList() {
+std::vector<ThemeSound*> Theme::getSoundsList() {
   return m_sounds;
 }
 
@@ -82,22 +81,24 @@ std::string Theme::Name() const {
   return m_name;
 }
 
-vapp::Texture* Theme::loadTexture(std::string p_fileName, bool bSmall, bool bClamp, vapp::FilterMode eFilterMode) {
+Texture* Theme::loadTexture(std::string p_fileName, bool bSmall, bool bClamp, FilterMode eFilterMode) {
   return m_texMan.loadTexture(p_fileName.c_str(), bSmall, bClamp, eFilterMode);
 }
 
-std::vector<std::string>* Theme::getRequiredFiles() {
+std::vector<ThemeFile>* Theme::getRequiredFiles() {
   return &m_requiredFiles;
 }
 
 void Theme::load(std::string p_themeFile) {
-  vapp::Log(std::string("Loading theme from file " + p_themeFile).c_str());
+  Logger::Log(std::string("Loading theme from file " + p_themeFile).c_str());
+
+  m_requiredFiles.clear();
 
   cleanSprites(); /* removing existing sprites */
   cleanMusics();
   cleanSounds();
 
-  vapp::XMLDocument v_ThemeXml;
+  XMLDocument v_ThemeXml;
   TiXmlDocument *v_ThemeXmlData;
   TiXmlElement *v_ThemeXmlDataElement;
   const char *pc;
@@ -150,6 +151,7 @@ void Theme::loadSpritesFromXML(TiXmlElement *p_ThemeXmlDataElement) {
   std::string v_spriteType;
   bool v_isAnimation;
   const char *pc;
+  std::string v_sum;
   
   for(TiXmlElement *pVarElem = p_ThemeXmlDataElement->FirstChildElement("sprite");
       pVarElem!=NULL;
@@ -186,13 +188,14 @@ void Theme::loadSpritesFromXML(TiXmlElement *p_ThemeXmlDataElement) {
     } else if(v_spriteType == "EdgeEffect") {
       newEdgeEffectSpriteFromXML(pVarElem);
     } else {
-      vapp::Log("Warning: unknown type '%s' in theme file !", v_spriteType.c_str());
+      Logger::Log("Warning: unknown type '%s' in theme file !", v_spriteType.c_str());
     }
   }
 
   /* get musics */
   std::string v_musicName;
   std::string v_musicFile;
+  v_sum = "";
 
   for(TiXmlElement *pVarElem = p_ThemeXmlDataElement->FirstChildElement("music");
       pVarElem!=NULL;
@@ -207,15 +210,21 @@ void Theme::loadSpritesFromXML(TiXmlElement *p_ThemeXmlDataElement) {
     if(pc == NULL) { continue; }
     v_musicFile = pc;
 
+    pc = pVarElem->Attribute("sum");
+    if(pc != NULL) { v_sum = pc; };
+
     if(isAFileOutOfDate(THEME_MUSICS_FILE_DIR + std::string("/") + v_musicFile) == false) {
-      m_musics.push_back(new Music(this, v_musicName, v_musicFile));
-      m_requiredFiles.push_back(THEME_MUSICS_FILE_DIR + std::string("/") + v_musicFile);    
+      m_musics.push_back(new ThemeMusic(this, v_musicName, v_musicFile));
+
+      ThemeFile v_file = {THEME_MUSICS_FILE_DIR + std::string("/") + v_musicFile, v_sum};
+      m_requiredFiles.push_back(v_file);
     }
   }
 
   /* get sounds */
   std::string v_soundName;
   std::string v_soundFile;
+  v_sum = "";
 
   for(TiXmlElement *pVarElem = p_ThemeXmlDataElement->FirstChildElement("sound");
       pVarElem!=NULL;
@@ -230,9 +239,13 @@ void Theme::loadSpritesFromXML(TiXmlElement *p_ThemeXmlDataElement) {
     if(pc == NULL) { continue; }
     v_soundFile = pc;
 
+    pc = pVarElem->Attribute("sum");
+    if(pc != NULL) { v_sum = pc; };
+
     if(isAFileOutOfDate(THEME_SOUNDS_FILE_DIR + std::string("/") + v_soundFile) == false) {
-      m_sounds.push_back(new Sound(this, v_soundName, v_soundFile));
-      m_requiredFiles.push_back(THEME_SOUNDS_FILE_DIR + std::string("/") + v_soundFile);    
+      m_sounds.push_back(new ThemeSound(this, v_soundName, v_soundFile));
+      ThemeFile v_file = {THEME_SOUNDS_FILE_DIR + std::string("/") + v_soundFile, v_sum};
+      m_requiredFiles.push_back(v_file);
     }
   }
 
@@ -250,7 +263,7 @@ Sprite* Theme::getSprite(enum SpriteType pSpriteType, std::string pName) {
   return NULL;
 }
 
-Music* Theme::getMusic(std::string i_name) {
+ThemeMusic* Theme::getMusic(std::string i_name) {
   for(unsigned int i=0; i<m_musics.size(); i++) {
     if(m_musics[i]->Name() == i_name) {
       return m_musics[i];
@@ -259,7 +272,7 @@ Music* Theme::getMusic(std::string i_name) {
   throw Exception("Music " + i_name + " not found");
 }
 
-Sound* Theme::getSound(std::string i_name) {
+ThemeSound* Theme::getSound(std::string i_name) {
   for(unsigned int i=0; i<m_sounds.size(); i++) {
     if(m_sounds[i]->Name() == i_name) {
       return m_sounds[i];
@@ -303,15 +316,15 @@ void Theme::newAnimationSpriteFromXML(TiXmlElement *pVarElem) {
   float global_delay   = 0.1;
 
   pc = pVarElem->Attribute("name");
-  if(pc == NULL) {vapp::Log("** Animation with no name"); return;}
+  if(pc == NULL) {Logger::Log("** Animation with no name"); return;}
   v_name = pc;
   
   pc = pVarElem->Attribute("fileBase");
-  if(pc == NULL) {vapp::Log("** Animation with no fileBase"); return;}
+  if(pc == NULL) {Logger::Log("** Animation with no fileBase"); return;}
   v_fileBase = pc;
 
   pc = pVarElem->Attribute("fileExtension");
-  if(pc == NULL) {vapp::Log("** Animation with no fileExtension"); return;}
+  if(pc == NULL) {Logger::Log("** Animation with no fileExtension"); return;}
   v_fileExtension = pc;
 
   pc = pVarElem->Attribute("centerX");
@@ -343,6 +356,7 @@ void Theme::newAnimationSpriteFromXML(TiXmlElement *pVarElem) {
     float v_width;
     float v_height;
     float v_delay;
+    std::string v_sum;
 
     pc = pVarSubElem->Attribute("centerX");
     if(pc != NULL) {v_centerX = atof(pc);} else {v_centerX = global_centerX;}
@@ -359,14 +373,20 @@ void Theme::newAnimationSpriteFromXML(TiXmlElement *pVarElem) {
     pc = pVarSubElem->Attribute("delay");
     if(pc != NULL) {v_delay = atof(pc);} else {v_delay = global_delay;}
 
-    if(isAFileOutOfDate(THEME_ANIMATION_SPRITE_FILE_DIR + std::string("/") +
-			v_fileBase + std::string(buf) + std::string(".") + v_fileExtension) == false) {
-      v_anim->addFrame(v_centerX, v_centerY, v_width, v_height, v_delay);
+    pc = pVarSubElem->Attribute("sum");
+    if(pc != NULL) { v_sum = pc; };
 
-      if(n < 100) {
-	sprintf(buf, "%02i", n);
-	m_requiredFiles.push_back(THEME_ANIMATION_SPRITE_FILE_DIR + std::string("/") +
-				  v_fileBase + std::string(buf) + std::string(".") + v_fileExtension);
+    if(n < 100) {
+      sprintf(buf, "%02i", n);
+
+      if(isAFileOutOfDate(THEME_ANIMATION_SPRITE_FILE_DIR + std::string("/") +
+			  v_fileBase + std::string(buf) + std::string(".") + v_fileExtension) == false) {
+	v_anim->addFrame(v_centerX, v_centerY, v_width, v_height, v_delay);
+
+	ThemeFile v_file = {THEME_ANIMATION_SPRITE_FILE_DIR + std::string("/") +
+			    v_fileBase + std::string(buf) + std::string(".") + v_fileExtension,
+			    v_sum};
+	m_requiredFiles.push_back(v_file);
       }
       n++;
     }
@@ -377,18 +397,23 @@ void Theme::newBikerPartSpriteFromXML(TiXmlElement *pVarElem) {
   std::string v_name;
   std::string v_fileName;
   const char *pc;
+  std::string v_sum;
 
   pc = pVarElem->Attribute("name");
-  if(pc == NULL) {vapp::Log("** BikerPart with no name"); return;}
+  if(pc == NULL) {Logger::Log("** BikerPart with no name"); return;}
   v_name = pc;
 
   pc = pVarElem->Attribute("file");
-  if(pc == NULL) {vapp::Log("** BikerPart with no file"); return;}
+  if(pc == NULL) {Logger::Log("** BikerPart with no file"); return;}
   v_fileName = pc;
 
+  pc = pVarElem->Attribute("sum");
+  if(pc != NULL) { v_sum = pc; };
+
   if(isAFileOutOfDate(THEME_BIKERPART_SPRITE_FILE_DIR + std::string("/") + v_fileName) == false) {
     m_sprites.push_back(new BikerPartSprite(this, v_name, v_fileName));
-    m_requiredFiles.push_back(THEME_BIKERPART_SPRITE_FILE_DIR + std::string("/") + v_fileName);
+    ThemeFile v_file = {THEME_BIKERPART_SPRITE_FILE_DIR + std::string("/") + v_fileName, v_sum};
+    m_requiredFiles.push_back(v_file);
   }
 }
 
@@ -401,6 +426,7 @@ void Theme::newDecorationSpriteFromXML(TiXmlElement *pVarElem) {
   float v_centerY;
   std::string v_blendmode = "default";
   const char *pc;
+  std::string v_sum;
 
   float global_centerX = 0.5;
   float global_centerY = 0.5;
@@ -408,11 +434,11 @@ void Theme::newDecorationSpriteFromXML(TiXmlElement *pVarElem) {
   float global_height  = 1.0;
 
   pc = pVarElem->Attribute("name");
-  if(pc == NULL) {vapp::Log("** Sprite with no name"); return;}
+  if(pc == NULL) {Logger::Log("** Sprite with no name"); return;}
   v_name = pc;
 
   pc = pVarElem->Attribute("file");
-  if(pc == NULL) {vapp::Log("** Sprite with no name"); return;}
+  if(pc == NULL) {Logger::Log("** Sprite with no name"); return;}
   v_fileName = pc;
 
   pc = pVarElem->Attribute("width");
@@ -430,6 +456,9 @@ void Theme::newDecorationSpriteFromXML(TiXmlElement *pVarElem) {
   pc = pVarElem->Attribute("blendmode");
   if(pc != NULL) v_blendmode = pc;
 
+  pc = pVarElem->Attribute("sum");
+  if(pc != NULL) { v_sum = pc; };
+
   if(isAFileOutOfDate(THEME_DECORATION_SPRITE_FILE_DIR + std::string("/") + v_fileName) == false) {
     m_sprites.push_back(new DecorationSprite(this, v_name, v_fileName,
 					     v_width,
@@ -438,7 +467,8 @@ void Theme::newDecorationSpriteFromXML(TiXmlElement *pVarElem) {
 					     v_centerY,
 					     strToBlendMode(v_blendmode)
 					     ));
-    m_requiredFiles.push_back(THEME_DECORATION_SPRITE_FILE_DIR + std::string("/") + v_fileName);
+    ThemeFile v_file = {THEME_DECORATION_SPRITE_FILE_DIR + std::string("/") + v_fileName, v_sum};
+    m_requiredFiles.push_back(v_file);
   }
 }
 
@@ -446,18 +476,23 @@ void Theme::newEffectSpriteFromXML(TiXmlElement *pVarElem) {
   std::string v_name;
   std::string v_fileName;
   const char *pc;
+  std::string v_sum;
 
   pc = pVarElem->Attribute("name");
-  if(pc == NULL) {vapp::Log("** Effect with no name"); return;}
+  if(pc == NULL) {Logger::Log("** Effect with no name"); return;}
   v_name = pc;
 
   pc = pVarElem->Attribute("file");
-  if(pc == NULL) {vapp::Log("** Effect with no file"); return;}
+  if(pc == NULL) {Logger::Log("** Effect with no file"); return;}
   v_fileName = pc;
 
+  pc = pVarElem->Attribute("sum");
+  if(pc != NULL) { v_sum = pc; };
+
   if(isAFileOutOfDate(THEME_EFFECT_SPRITE_FILE_DIR + std::string("/") + v_fileName) == false) {
     m_sprites.push_back(new EffectSprite(this, v_name, v_fileName));
-    m_requiredFiles.push_back(THEME_EFFECT_SPRITE_FILE_DIR + std::string("/") + v_fileName);
+    ThemeFile v_file = {THEME_EFFECT_SPRITE_FILE_DIR + std::string("/") + v_fileName, v_sum};
+    m_requiredFiles.push_back(v_file);
   }
 }
 
@@ -467,28 +502,33 @@ void Theme::newEdgeEffectSpriteFromXML(TiXmlElement *pVarElem) {
   std::string v_scale;
   std::string v_depth;
   const char *pc;
+  std::string v_sum;
 
   pc = pVarElem->Attribute("name");
-  if(pc == NULL) {vapp::Log("** Edge with no name"); return;}
+  if(pc == NULL) {Logger::Log("** Edge with no name"); return;}
   v_name = pc;
 
   pc = pVarElem->Attribute("file");
-  if(pc == NULL) {vapp::Log("** Edge with no file"); return;}
+  if(pc == NULL) {Logger::Log("** Edge with no file"); return;}
   v_fileName = pc;
 
   pc = pVarElem->Attribute("scale");
-  if(pc == NULL) {vapp::Log("** Edge with no scale"); return;}
+  if(pc == NULL) {Logger::Log("** Edge with no scale"); return;}
   v_scale = pc;
 
   pc = pVarElem->Attribute("depth");
-  if(pc == NULL) {vapp::Log("Edge with no depth"); return;}
+  if(pc == NULL) {Logger::Log("Edge with no depth"); return;}
   v_depth = pc;
 
+  pc = pVarElem->Attribute("sum");
+  if(pc != NULL) { v_sum = pc; };
+
   if(isAFileOutOfDate(THEME_EDGEEFFECT_SPRITE_FILE_DIR + std::string("/") + v_fileName) == false) {
     m_sprites.push_back(new EdgeEffectSprite(this, v_name, v_fileName,
 					     atof(v_scale.c_str()),
 					     atof(v_depth.c_str())));
-    m_requiredFiles.push_back(THEME_EDGEEFFECT_SPRITE_FILE_DIR + std::string("/") + v_fileName);
+    ThemeFile v_file = {THEME_EDGEEFFECT_SPRITE_FILE_DIR + std::string("/") + v_fileName, v_sum};
+    m_requiredFiles.push_back(v_file);
   }
 }
 
@@ -496,18 +536,23 @@ void Theme::newFontSpriteFromXML(TiXmlElement *pVarElem) {
   std::string v_name;
   std::string v_fileName;
   const char *pc;
+  std::string v_sum;
 
   pc = pVarElem->Attribute("name");
-  if(pc == NULL) {vapp::Log("** Font with no name"); return;}
+  if(pc == NULL) {Logger::Log("** Font with no name"); return;}
   v_name = pc;
 
   pc = pVarElem->Attribute("file");
-  if(pc == NULL) {vapp::Log("Font with no file"); return;}
+  if(pc == NULL) {Logger::Log("Font with no file"); return;}
   v_fileName = pc;
 
+  pc = pVarElem->Attribute("sum");
+  if(pc != NULL) { v_sum = pc; };
+
   if(isAFileOutOfDate(THEME_FONT_SPRITE_FILE_DIR + std::string("/") + v_fileName) == false) {
     m_sprites.push_back(new FontSprite(this, v_name, v_fileName));
-    m_requiredFiles.push_back(THEME_FONT_SPRITE_FILE_DIR + std::string("/") + v_fileName);
+    ThemeFile v_file = {THEME_FONT_SPRITE_FILE_DIR + std::string("/") + v_fileName, v_sum};
+    m_requiredFiles.push_back(v_file);
   }
 }
 
@@ -515,18 +560,23 @@ void Theme::newMiscSpriteFromXML(TiXmlElement *pVarElem) {
   std::string v_name;
   std::string v_fileName;
   const char *pc;
+  std::string v_sum;
 
   pc = pVarElem->Attribute("name");
-  if(pc == NULL) {vapp::Log("** Misc with no name"); return;}
+  if(pc == NULL) {Logger::Log("** Misc with no name"); return;}
   v_name = pc;
 
   pc = pVarElem->Attribute("file");
-  if(pc == NULL) {vapp::Log("** Misc with no file"); return;}
+  if(pc == NULL) {Logger::Log("** Misc with no file"); return;}
   v_fileName = pc;
 
+  pc = pVarElem->Attribute("sum");
+  if(pc != NULL) { v_sum = pc; };
+
   if(isAFileOutOfDate(THEME_MISC_SPRITE_FILE_DIR + std::string("/") + v_fileName) == false) {
     m_sprites.push_back(new MiscSprite(this, v_name, v_fileName));
-    m_requiredFiles.push_back(THEME_MISC_SPRITE_FILE_DIR + std::string("/") + v_fileName);
+    ThemeFile v_file = {THEME_MISC_SPRITE_FILE_DIR + std::string("/") + v_fileName, v_sum};
+    m_requiredFiles.push_back(v_file);
   }
 }
 
@@ -534,18 +584,23 @@ void Theme::newUISpriteFromXML(TiXmlElement *pVarElem) {
   std::string v_name;
   std::string v_fileName;
   const char *pc;
+  std::string v_sum;
 
   pc = pVarElem->Attribute("name");
-  if(pc == NULL) {vapp::Log("** UI with no name"); return;}
+  if(pc == NULL) {Logger::Log("** UI with no name"); return;}
   v_name = pc;
 
   pc = pVarElem->Attribute("file");
-  if(pc == NULL) {vapp::Log("** UI with no file"); return;}
+  if(pc == NULL) {Logger::Log("** UI with no file"); return;}
   v_fileName = pc;
 
+  pc = pVarElem->Attribute("sum");
+  if(pc != NULL) { v_sum = pc; };
+
   if(isAFileOutOfDate(THEME_UI_SPRITE_FILE_DIR + std::string("/") + v_fileName) == false) {
     m_sprites.push_back(new UISprite(this, v_name, v_fileName));
-    m_requiredFiles.push_back(THEME_UI_SPRITE_FILE_DIR + std::string("/") + v_fileName);
+    ThemeFile v_file = {THEME_UI_SPRITE_FILE_DIR + std::string("/") + v_fileName, v_sum};
+    m_requiredFiles.push_back(v_file);
   }
 }
 
@@ -553,18 +608,23 @@ void Theme::newTextureSpriteFromXML(TiXmlElement *pVarElem) {
   std::string v_name;
   std::string v_fileName;
   const char *pc;
+  std::string v_sum;
 
   pc = pVarElem->Attribute("name");
-  if(pc == NULL) {vapp::Log("** Texture with no name"); return;}
+  if(pc == NULL) {Logger::Log("** Texture with no name"); return;}
   v_name = pc;
 
   pc = pVarElem->Attribute("file");
-  if(pc == NULL) {vapp::Log("** Texture with no file"); return;}
+  if(pc == NULL) {Logger::Log("** Texture with no file"); return;}
   v_fileName = pc;
 
+  pc = pVarElem->Attribute("sum");
+  if(pc != NULL) { v_sum = pc; };
+
   if(isAFileOutOfDate(THEME_TEXTURE_SPRITE_FILE_DIR + std::string("/") + v_fileName) == false) {
     m_sprites.push_back(new TextureSprite(this, v_name, v_fileName));
-    m_requiredFiles.push_back(THEME_TEXTURE_SPRITE_FILE_DIR + std::string("/") + v_fileName);
+    ThemeFile v_file = {THEME_TEXTURE_SPRITE_FILE_DIR + std::string("/") + v_fileName, v_sum};
+    m_requiredFiles.push_back(v_file);
   }
 }
 
@@ -579,13 +639,14 @@ BikerTheme* Theme::getGhostTheme() {
 Sprite::Sprite(Theme* p_associated_theme, std::string v_name) {
   m_associated_theme = p_associated_theme;
   m_name = v_name;
+  m_blendmode = SPRITE_BLENDMODE_DEFAULT;
 }
 
 Sprite::~Sprite() {
 }
 
-vapp::Texture* Sprite::getTexture(bool bSmall, bool bClamp, vapp::FilterMode eFilterMode) {
-  vapp::Texture* v_currentTexture;
+Texture* Sprite::getTexture(bool bSmall, bool bClamp, FilterMode eFilterMode) {
+  Texture* v_currentTexture;
 
   v_currentTexture = getCurrentTexture();
   if(v_currentTexture == NULL) {
@@ -627,7 +688,7 @@ std::string AnimationSprite::getFileDir() {
   return THEME_ANIMATION_SPRITE_FILE_DIR;
 }
 
-vapp::Texture* AnimationSprite::getCurrentTexture() {
+Texture* AnimationSprite::getCurrentTexture() {
   if(m_frames.size() == 0) {return NULL;}
   return m_frames[getCurrentFrame()]->getTexture();
 }
@@ -639,13 +700,13 @@ std::string AnimationSprite::getCurrentTextureFileName() {
   return getFileDir() + "/" + m_fileBase + std::string(v_num) + std::string(".") + m_fileExtension;
 }
 
-void AnimationSprite::setCurrentTexture(vapp::Texture *p_texture) {
+void AnimationSprite::setCurrentTexture(Texture *p_texture) {
   m_frames[getCurrentFrame()]->setTexture(p_texture);
 }
 
 int AnimationSprite::getCurrentFrame() {
   /* Next frame? */
-  float v_realTime = vapp::App::getRealTime();
+  float v_realTime = GameApp::getXMTime();
 
   while(v_realTime > m_fFrameTime + m_frames[m_current_frame]->getDelay()) {
     m_fFrameTime = v_realTime;
@@ -702,11 +763,11 @@ AnimationSpriteFrame::AnimationSpriteFrame(AnimationSprite *p_associatedAnimatio
 AnimationSpriteFrame::~AnimationSpriteFrame() {
 }
 
-vapp::Texture* AnimationSpriteFrame::getTexture() {
+Texture* AnimationSpriteFrame::getTexture() {
   return m_texture;
 }
 
-void  AnimationSpriteFrame::setTexture(vapp::Texture *p_texture) {
+void  AnimationSpriteFrame::setTexture(Texture *p_texture) {
   m_texture = p_texture;
 }
 
@@ -806,8 +867,8 @@ float EdgeEffectSprite::getDepth() const {
   return m_fDepth;
 }
 
-vapp::Texture* EdgeEffectSprite::getTexture(bool bSmall, bool bClamp, vapp::FilterMode eFilterMode) {
-  Sprite::getTexture(bSmall, bClamp, eFilterMode);
+Texture* EdgeEffectSprite::getTexture(bool bSmall, bool bClamp, FilterMode eFilterMode) {
+  return Sprite::getTexture(bSmall, bClamp, eFilterMode);
 }
 
 FontSprite::FontSprite(Theme* p_associated_theme, std::string p_name, std::string p_fileName) : SimpleFrameSprite(p_associated_theme, p_name, p_fileName) {
@@ -862,7 +923,7 @@ SimpleFrameSprite::SimpleFrameSprite(Theme* p_associated_theme, std::string p_na
 SimpleFrameSprite::~SimpleFrameSprite() {
 }
 
-vapp::Texture* SimpleFrameSprite::getCurrentTexture() {
+Texture* SimpleFrameSprite::getCurrentTexture() {
   return m_texture;
 }
 
@@ -870,7 +931,7 @@ std::string SimpleFrameSprite::getCurrentTextureFileName() {
   return getFileDir() + "/" + m_fileName;
 }
 
-void SimpleFrameSprite::setCurrentTexture(vapp::Texture *p_texture) {
+void SimpleFrameSprite::setCurrentTexture(Texture *p_texture) {
   m_texture = p_texture;
 }
 
@@ -884,8 +945,8 @@ BikerTheme::BikerTheme(Theme* p_associated_theme,
            std::string p_Torso,
            std::string p_UpperArm,
            std::string p_UpperLeg,
-           vapp::Color p_UglyRiderColor,
-           vapp::Color p_UglyWheelColor
+           Color p_UglyRiderColor,
+           Color p_UglyWheelColor
            ) {
   m_associated_theme = p_associated_theme;
   m_Body           = p_Body;
@@ -941,33 +1002,16 @@ Sprite* BikerTheme::getUpperLeg() {
   return m_associated_theme->getSprite(SPRITE_TYPE_BIKERPART, m_UpperLeg);
 }
 
-vapp::Color BikerTheme::getUglyRiderColor() {
+Color BikerTheme::getUglyRiderColor() {
   return m_UglyRiderColor;
 }
 
-vapp::Color BikerTheme::getUglyWheelColor() {
+Color BikerTheme::getUglyWheelColor() {
   return m_UglyWheelColor;
 }
 
-ThemeChoicer::ThemeChoicer(vapp::WWWAppInterface *p_WebApp,
-			   const ProxySettings *p_proxy_settings) {                    
-  m_webThemes = new WebThemes(p_WebApp, p_proxy_settings);
-}
-
-ThemeChoicer::~ThemeChoicer() {
-  delete m_webThemes;
-}
-
- void ThemeChoicer::setURL(const std::string &p_url) {
-   m_webThemes->setURL(p_url);
- }
-
- void ThemeChoicer::setURLBase(const std::string &p_urlBase) {
-   m_webThemes->setURLBase(p_urlBase);
- }
-
 void ThemeChoicer::initThemesFromDir(xmDatabase *i_db) {
-  std::vector<std::string> v_themesFiles = vapp::FS::findPhysFiles(std::string(THEMES_DIRECTORY)
+  std::vector<std::string> v_themesFiles = FS::findPhysFiles(std::string(THEMES_DIRECTORY)
 								   + std::string("/*.xml"), true);
   std::string v_name;
 
@@ -978,7 +1022,7 @@ void ThemeChoicer::initThemesFromDir(xmDatabase *i_db) {
       if(i_db->themes_exists(v_name) == false) {
 	i_db->themes_add(v_name, v_themesFiles[i]);
       } else {
-	vapp::Log(std::string("Theme " + v_name + " is present several times").c_str());
+	Logger::Log(std::string("Theme " + v_name + " is present several times").c_str());
       }
     } catch(Exception &e) {
       /* anyway, give up this theme */
@@ -988,7 +1032,7 @@ void ThemeChoicer::initThemesFromDir(xmDatabase *i_db) {
 }
 
 std::string ThemeChoicer::getThemeNameFromFile(std::string p_themeFile) {
-  vapp::XMLDocument v_ThemeXml;
+  XMLDocument v_ThemeXml;
   TiXmlDocument *v_ThemeXmlData;
   TiXmlElement *v_ThemeXmlDataElement;
   const char *pc;
@@ -1016,14 +1060,6 @@ std::string ThemeChoicer::getThemeNameFromFile(std::string p_themeFile) {
   return m_name;
 }
 
-void ThemeChoicer::updateFromWWW(xmDatabase *i_db) {
-  m_webThemes->update(i_db);
-}
-
-void ThemeChoicer::updateThemeFromWWW(xmDatabase *i_db, const std::string& i_id_file) {
-  m_webThemes->upgrade(i_db, i_id_file);
-}
-
 SpriteBlendMode Theme::strToBlendMode(const std::string &s) {
   if(s == "add") return SPRITE_BLENDMODE_ADDITIVE;
   return SPRITE_BLENDMODE_DEFAULT;
@@ -1034,44 +1070,44 @@ std::string Theme::blendModeToStr(SpriteBlendMode Mode) {
   return "default";
 }
 
-Music::Music(Theme* p_associated_theme, std::string i_name, std::string i_fileName) {
+ThemeMusic::ThemeMusic(Theme* p_associated_theme, std::string i_name, std::string i_fileName) {
   m_associated_theme = p_associated_theme;
   m_name     	      = i_name;
   m_fileName 	      = i_fileName;
 }
  
-Music::~Music() {
+ThemeMusic::~ThemeMusic() {
 }
 
-std::string Music::Name() const {
+std::string ThemeMusic::Name() const {
   return m_name;
 }
 
-std::string Music::FileName() const {
+std::string ThemeMusic::FileName() const {
   return m_fileName;
 }
  
-std::string Music::FilePath() const {
-  return vapp::FS::FullPath(THEME_MUSICS_FILE_DIR + std::string("/") + m_fileName);
+std::string ThemeMusic::FilePath() const {
+  return FS::FullPath(THEME_MUSICS_FILE_DIR + std::string("/") + m_fileName);
 }
 
-Sound::Sound(Theme* p_associated_theme, std::string i_name, std::string i_fileName) {
+ThemeSound::ThemeSound(Theme* p_associated_theme, std::string i_name, std::string i_fileName) {
   m_associated_theme = p_associated_theme;
   m_name     	      = i_name;
   m_fileName 	      = i_fileName;
 }
  
-Sound::~Sound() {
+ThemeSound::~ThemeSound() {
 }
 
-std::string Sound::Name() const {
+std::string ThemeSound::Name() const {
   return m_name;
 }
 
-std::string Sound::FileName() const {
+std::string ThemeSound::FileName() const {
   return m_fileName;
 }
  
-std::string Sound::FilePath() const {
+std::string ThemeSound::FilePath() const {
   return THEME_SOUNDS_FILE_DIR + std::string("/") + m_fileName;
 }
