@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -25,11 +24,12 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include <string>
 #include <vector>
 
-#include "BuildConfig.h"
 #include "VTexture.h"
-#include "VFileIO.h"
-#include "WWW.h"
+#include "helpers/Singleton.h"
 
+class Texture;
+class WWWAppInterface;
+class TiXmlElement;
 class ProxySettings;
 class WebThemes;
 class xmDatabase;
@@ -72,8 +72,6 @@ class xmDatabase;
 #define THEME_GHOST_UGLYRIDERCOLOR MAKE_COLOR(100,100,128,255)
 #define THEME_GHOST_UGLYWHEELCOLOR MAKE_COLOR(100,100,128,255)
 
-#define THEME_DEFAULT_THEMENAME "Classic"
-
   enum SpriteType {
     SPRITE_TYPE_ANIMATION,
     SPRITE_TYPE_BIKERPART,
@@ -94,10 +92,10 @@ class xmDatabase;
 class Theme;
 class BikerTheme;
 
-class Music {
+class ThemeMusic {
  public:
-  Music(Theme* p_associated_theme, std::string i_name, std::string i_fileName);
-  ~Music();
+  ThemeMusic(Theme* p_associated_theme, std::string i_name, std::string i_fileName);
+  ~ThemeMusic();
 
   std::string Name() const;
   std::string FileName() const;
@@ -109,10 +107,10 @@ class Music {
   std::string m_fileName;
 };
 
-class Sound {
+class ThemeSound {
  public:
-  Sound(Theme* p_associated_theme, std::string i_name, std::string i_fileName);
-  ~Sound();
+  ThemeSound(Theme* p_associated_theme, std::string i_name, std::string i_fileName);
+  ~ThemeSound();
 
   std::string Name() const;
   std::string FileName() const;
@@ -145,12 +143,12 @@ class Sprite {
      the bSmall, bClamp, bFilter parameters are considerated 
      only the first time that getTexture is called for a given sprite
   */
-  vapp::Texture* getTexture(bool bSmall=false, bool bClamp=false, vapp::FilterMode eFilterMode = vapp::FM_MIPMAP);
+  Texture* getTexture(bool bSmall=false, bool bClamp=false, FilterMode eFilterMode = FM_MIPMAP);
 
  protected:
-  virtual vapp::Texture* getCurrentTexture() = 0;
+  virtual Texture* getCurrentTexture() = 0;
   virtual std::string getCurrentTextureFileName() = 0;
-  virtual void setCurrentTexture(vapp::Texture *p_texture) = 0;
+  virtual void setCurrentTexture(Texture *p_texture) = 0;
   virtual std::string getFileDir();
   enum SpriteType m_type;
 
@@ -166,13 +164,13 @@ class SimpleFrameSprite : public Sprite {
   virtual ~SimpleFrameSprite();
 
  protected:
-  vapp::Texture* getCurrentTexture();
+  Texture* getCurrentTexture();
   std::string getCurrentTextureFileName();
-  void setCurrentTexture(vapp::Texture *p_texture);
+  void setCurrentTexture(Texture *p_texture);
 
  private:
   std::string m_fileName;
-  vapp::Texture* m_texture;
+  Texture* m_texture;
 };
 
 class TextureSprite : public SimpleFrameSprite {
@@ -209,8 +207,8 @@ class AnimationSpriteFrame {
 		       float p_delay
 		       );
   virtual ~AnimationSpriteFrame();
-  vapp::Texture *getTexture();
-  void  setTexture(vapp::Texture *p_texture);
+  Texture *getTexture();
+  void  setTexture(Texture *p_texture);
   float getCenterX() const;
   float getCenterY() const;
   float getWidth() const;
@@ -220,7 +218,7 @@ class AnimationSpriteFrame {
  private:
   AnimationSprite *m_associatedAnimationSprite;
 
-  vapp::Texture* m_texture;
+  Texture* m_texture;
   float m_centerX;
   float m_centerY;
   float m_width;
@@ -239,9 +237,9 @@ class AnimationSprite : public Sprite {
   void  addFrame(float p_centerX, float p_centerY, float p_width, float p_height, float p_delay);
 
  protected:
-  vapp::Texture* getCurrentTexture();
+  Texture* getCurrentTexture();
   std::string getCurrentTextureFileName();
-  void setCurrentTexture(vapp::Texture *p_texture);
+  void setCurrentTexture(Texture *p_texture);
   std::string getFileDir();
 
  private:
@@ -270,7 +268,7 @@ class EdgeEffectSprite : public SimpleFrameSprite {
  public:
   EdgeEffectSprite(Theme* p_associated_theme, std::string p_name, std::string p_filename, float fScale, float fDepth);
   virtual ~EdgeEffectSprite();
-  vapp::Texture* getTexture(bool bSmall=false, bool bClamp=false, vapp::FilterMode eFilterMode = vapp::FM_LINEAR);
+  Texture* getTexture(bool bSmall=false, bool bClamp=false, FilterMode eFilterMode = FM_LINEAR);
 
   float getScale() const;
   float getDepth() const;
@@ -337,36 +335,44 @@ class DecorationSprite : public SimpleFrameSprite {
 
 };
 
-class Theme {
-  public:
+struct ThemeFile {
+  std::string filepath;
+  std::string filemd5;
+};
+
+class Theme : public Singleton<Theme> {
+  friend class Singleton<Theme>;
+
+private:
   Theme();
   ~Theme();
  
+public:
   void load(std::string p_themeFile);
 
   std::string Name() const;
   Sprite* getSprite(enum SpriteType pSpriteType, std::string pName);
-  Music* getMusic(std::string i_name);
-  Sound* getSound(std::string i_name);
-  vapp::Texture* loadTexture(std::string p_fileName,
+  ThemeMusic* getMusic(std::string i_name);
+  ThemeSound* getSound(std::string i_name);
+  Texture* loadTexture(std::string p_fileName,
 			     bool bSmall=false,
 			     bool bClamp=false,
-			     vapp::FilterMode eFilterMode = vapp::FM_MIPMAP);
+			     FilterMode eFilterMode = FM_MIPMAP);
 
   std::vector<Sprite*> getSpritesList();
-  std::vector<Sound*> getSoundsList();
-  std::vector<std::string>* getRequiredFiles();
+  std::vector<ThemeSound*> getSoundsList();
+  std::vector<ThemeFile>* getRequiredFiles();
 
   BikerTheme* getPlayerTheme();
   BikerTheme* getGhostTheme();
 
   private:
-  vapp::TextureManager m_texMan;
+  TextureManager m_texMan;
   std::string m_name;
   std::vector<Sprite*> m_sprites;
-  std::vector<Music*> m_musics;
-  std::vector<Sound*> m_sounds;
-  std::vector<std::string> m_requiredFiles;
+  std::vector<ThemeMusic*> m_musics;
+  std::vector<ThemeSound*> m_sounds;
+  std::vector<ThemeFile> m_requiredFiles;
 
   bool isAFileOutOfDate(const std::string& i_file); // to not download old files for compatibilities
 
@@ -405,8 +411,8 @@ class BikerTheme {
 	     std::string p_Torso,
 	     std::string p_UpperArm,
 	     std::string p_UpperLeg,
-	     vapp::Color p_UglyRiderColor,
-	     vapp::Color p_UglyWheelColor
+	     Color p_UglyRiderColor,
+	     Color p_UglyWheelColor
 	     );
   ~BikerTheme();
 
@@ -420,14 +426,14 @@ class BikerTheme {
   Sprite* getUpperArm();
   Sprite* getUpperLeg();
 
-  vapp::Color getUglyRiderColor();
-  vapp::Color getUglyWheelColor();
+  Color getUglyRiderColor();
+  Color getUglyWheelColor();
 
  private:
   Theme* m_associated_theme;
 
-  vapp::Color m_UglyRiderColor;
-  vapp::Color m_UglyWheelColor;
+  Color m_UglyRiderColor;
+  Color m_UglyWheelColor;
   
   std::string m_Body;
   std::string m_Front;
@@ -442,21 +448,10 @@ class BikerTheme {
 
 class ThemeChoicer {
  public:
-
-  ThemeChoicer(vapp::WWWAppInterface *p_WebApp = NULL,
-	       const ProxySettings *p_proxy_settings = NULL);	       
-  ~ThemeChoicer();
-
-  void updateFromWWW(xmDatabase *i_db);
-  void updateThemeFromWWW(xmDatabase *i_db, const std::string& i_id_theme);
-
-  void setURL(const std::string &p_url);
-  void setURLBase(const std::string &p_urlBase);
-  void initThemesFromDir(xmDatabase *i_db);
+  static void initThemesFromDir(xmDatabase *i_db);
 
  private:
-  WebThemes *m_webThemes;
-  std::string getThemeNameFromFile(std::string p_themeFile);
+  static std::string getThemeNameFromFile(std::string p_themeFile);
 };
 
 #endif /* __THEME_H__ */
