@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -25,9 +24,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "VFileIO.h"
 #include "VXml.h"
 #include "UserConfig.h"
-#include "VApp.h"
+#include "helpers/Log.h"
 
-namespace vapp {
 
   /*===========================================================================
   Load from XML
@@ -53,10 +51,10 @@ namespace vapp {
 	      }
 	    }
 	    else 
-	      Log("** Warning ** : no configuration in 'config.dat'");
+	      Logger::Log("** Warning ** : no configuration in 'config.dat'");
 	  }
 	  else
-	    Log("** Warning ** : failed to load or parse user configuration 'config.dat'");
+	    Logger::Log("** Warning ** : failed to load or parse user configuration 'config.dat'");
 	}
 
   /*===========================================================================
@@ -70,7 +68,7 @@ namespace vapp {
 	    FS::writeLine(pfh,"");
 	    FS::writeLine(pfh,"<userconfig>");
 	    
-	    for(int i=0;i<m_Vars.size();i++) {
+	    for(unsigned int i=0;i<m_Vars.size();i++) {
 	      char cBuf[256];
 	      sprintf(cBuf,"\t<var name=\"%s\" value=\"%s\"/>",XML::str2xmlstr(m_Vars[i]->Name).c_str(),XML::str2xmlstr(m_Vars[i]->Value).c_str());
 	      FS::writeLine(pfh,cBuf);
@@ -81,7 +79,7 @@ namespace vapp {
 	    FS::closeFile(pfh);
 	  }
 	  else
-	    Log("** Warning ** : failed to save user configuration 'config.dat'");
+	    Logger::Log("** Warning ** : failed to save user configuration 'config.dat'");
 	}
 
   /*===========================================================================
@@ -142,7 +140,7 @@ namespace vapp {
 	std::string UserConfig::getDefaultValue(std::string Name) {
 	  UserConfigVar *pVar = _FindVarByName(Name);
 	  if(pVar == NULL) {
-	    Log("** Warning ** : impossible to get default value of unknown configuration variable '%s'",Name.c_str());
+	    Logger::Log("** Warning ** : impossible to get default value of unknown configuration variable '%s'",Name.c_str());
 	    return "";
 	  }
 	  return pVar->DefaultValue;
@@ -151,7 +149,7 @@ namespace vapp {
 	std::string UserConfig::getValue(std::string Name) {
 	  UserConfigVar *pVar = _FindVarByName(Name);
 	  if(pVar == NULL) {
-	    Log("** Warning ** : impossible to get value of unknown configuration variable '%s'",Name.c_str());
+	    Logger::Log("** Warning ** : impossible to get value of unknown configuration variable '%s'",Name.c_str());
 	    return "";
 	  }
 	  return pVar->Value;
@@ -160,7 +158,7 @@ namespace vapp {
 	void UserConfig::setValue(std::string Name,std::string Value) {
 	  UserConfigVar *pVar = _FindVarByName(Name);
 	  if(pVar == NULL) {
-	    Log("** Warning ** : impossible to set value of unknown configuration variable '%s'",Name.c_str());
+	    Logger::Log("** Warning ** : impossible to set value of unknown configuration variable '%s'",Name.c_str());
 	    return;
 	  }
 	  
@@ -175,17 +173,16 @@ namespace vapp {
   Free config
   ===========================================================================*/
   void UserConfig::_FreeUserConfig(void) {
-    for(int i=0;i<m_Vars.size();i++) delete m_Vars[i];
+    for(unsigned int i=0;i<m_Vars.size();i++) delete m_Vars[i];
   }
 	    
   /*===========================================================================
   Misc helpers
   ===========================================================================*/
 	UserConfigVar *UserConfig::_FindVarByName(std::string Name) {
-	  for(int i=0;i<m_Vars.size();i++) {
+	  for(unsigned int i=0;i<m_Vars.size();i++) {
 	    if(m_Vars[i]->Name == Name) return m_Vars[i];
 	  }
 	  return NULL;
 	}
-	
-}
+
