@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -35,10 +34,14 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #ifdef HAVE_SDL_FRAMEWORK
   #include <SDL.h>
   #include <SDL_mixer.h>
+  #include <SDL_thread.h>
+  #include <SDL_mutex.h>
 #else
   #define USE_RWOPS
   #include <SDL/SDL.h>
   #include <SDL/SDL_mixer.h>
+  #include <SDL/SDL_thread.h>
+  #include <SDL/SDL_mutex.h>
 #endif
 
 // Some places #define _T, which we want for a template parameter
@@ -77,7 +80,11 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include <math.h>
 
 #if !defined(WIN32) && !defined(__APPLE__) && !defined(__MACH__)
-  #include <endian.h>
+  #if defined(__FreeBSD__) || defined(__OpenBSD__)
+    #include <sys/endian.h>
+  #else
+    #include <endian.h>
+  #endif
 #endif
 
 #if !defined(XMOTO_LITTLE_ENDIAN) && !defined(XMOTO_BIG_ENDIAN)
@@ -85,50 +92,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
   #define XMOTO_LITTLE_ENDIAN 1
 #endif
 
-extern "C" {
-  #if defined(WIN32) 
-    #include "lua.h"
-    #include "lauxlib.h"
-    #include "lualib.h"
-  #else
-    #if defined(HAVE_LUA51_LUA_H)
-      #include <lua5.1/lua.h>
-    #elif defined(HAVE_LUA50_LUA_H)
-      #include <lua50/lua.h>
-    #elif defined(HAVE_LUA_LUA_H)
-      #include <lua/lua.h>
-    #elif defined(HAVE_LUA_H)
-      #include <lua.h>
-    #else
-      #error Missing lua.h
-    #endif
-
-    #if defined(HAVE_LUA51_LAUXLIB_H)
-      #include <lua5.1/lauxlib.h>
-    #elif defined(HAVE_LUA50_LAUXLIB_H)
-      #include <lua50/lauxlib.h>
-    #elif defined(HAVE_LUA_LAUXLIB_H)
-      #include <lua/lauxlib.h>
-    #elif defined(HAVE_LAUXLIB_H)
-      #include <lauxlib.h>
-    #else
-      #error Missing lauxlib.h
-    #endif
-    
-    #if defined(HAVE_LUA51_LUALIB_H)
-      #include <lua5.1/lualib.h>
-    #elif defined(HAVE_LUA50_LUALIB_H)
-      #include <lua50/lualib.h>
-    #elif defined(HAVE_LUA_LUALIB_H)
-      #include <lua/lualib.h>
-    #elif defined(HAVE_LUALIB_H)
-      #include <lualib.h>
-    #else
-      #error Missing lualib.h    
-    #endif
-  #endif
-}
-
 #if defined(WIN32)
   #include "ode/ode.h"
 #else
@@ -148,42 +111,36 @@ extern "C" {
 Macros
 ===========================================================================*/
 #define MAKE_COLOR(red,green,blue,alpha) \
-	((vapp::Color)(alpha|(((vapp::Color)blue)<<8)|(((vapp::Color)green)<<16)|(((vapp::Color)red)<<24)))
+	((Color)(alpha|(((Color)blue)<<8)|(((Color)green)<<16)|(((Color)red)<<24)))
 #define GET_ALPHA(color) \
-	((vapp::Color)(color&0xff))
+	((Color)(color&0xff))
 #define GET_BLUE(color) \
-	((vapp::Color)((color&0xff00)>>8))
+	((Color)((color&0xff00)>>8))
 #define GET_GREEN(color) \
-	((vapp::Color)((color&0xff0000)>>16))
+	((Color)((color&0xff0000)>>16))
 #define GET_RED(color) \
-	((vapp::Color)((color&0xff000000)>>24))
+	((Color)((color&0xff000000)>>24))
 #define GETF_ALPHA(color) \
-	(((vapp::Color)(color&0xff))/255.0f)
+	(((Color)(color&0xff))/255.0f)
 #define GETF_BLUE(color) \
-	(((vapp::Color)((color&0xff00)>>8))/255.0f)
+	(((Color)((color&0xff00)>>8))/255.0f)
 #define GETF_GREEN(color) \
-	(((vapp::Color)((color&0xff0000)>>16))/255.0f)
+	(((Color)((color&0xff0000)>>16))/255.0f)
 #define GETF_RED(color) \
-	(((vapp::Color)((color&0xff000000)>>24))/255.0f)
+	(((Color)((color&0xff000000)>>24))/255.0f)
 #define INVERT_COLOR(color) \
-	MAKE_COLOR(255-GET_RED(color),255-GET_GREEN(color),255-GET_BLUE(color),255)
+	MAKE_COLOR(255-GET_RED(color),255-GET_GREEN(color),255-GET_BLUE(color),GET_ALPHA(color))
 
-namespace vapp {
-
-  /*===========================================================================
+/*===========================================================================
   Types
   ===========================================================================*/
   typedef unsigned int Color;
 
-  //used a comparator in sdt::map
-  struct ltstr {
-    bool operator()(const char* s1, const char* s2) const {
-      return strcmp(s1, s2) < 0;
-    }
-  };
-
-
-
-}
+//used a comparator in sdt::map
+struct ltstr {
+  bool operator()(const char* s1, const char* s2) const {
+    return strcmp(s1, s2) < 0;
+  }
+};
 
 #endif
