@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -22,12 +21,10 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 /* 
  *  Handling of textures.
  */
-#include "VApp.h"
 #include "VTexture.h"
 #include "Image.h"
 #include "VFileIO.h"
-
-namespace vapp {
+#include "helpers/Log.h"
 
   /*===========================================================================
   Create texture from memory
@@ -35,7 +32,7 @@ namespace vapp {
   Texture *TextureManager::createTexture(std::string Name,unsigned char *pcData,int nWidth,int nHeight,bool bAlpha,bool bClamp, FilterMode eFilterMode) {
     /* Name free? */
     if(getTexture(Name) != NULL) {
-      Log("** Warning ** : TextureManager::createTexture() : Name '%s' already in use",Name.c_str());
+      Logger::Log("** Warning ** : TextureManager::createTexture() : Name '%s' already in use",Name.c_str());
       throw TextureError("texture naming conflict");
     }
 
@@ -46,12 +43,10 @@ namespace vapp {
     pTexture->nHeight = nHeight;
     pTexture->Tag = "";
     pTexture->isAlpha = bAlpha;
-    pTexture->pcData = pcData;
+
 #ifdef ENABLE_OPENGL
     pTexture->nID = 0;
-#endif
-    
-#ifdef ENABLE_OPENGL
+
     /* OpenGL magic */
     GLuint N;
     glEnable(GL_TEXTURE_2D);
@@ -86,24 +81,39 @@ namespace vapp {
       glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_WRAP_T,GL_REPEAT);
     }
 
-    if(bAlpha) {
-      /* Got alpha channel */
-      if(eFilterMode == FM_MIPMAP){
-	gluBuild2DMipmaps(GL_TEXTURE_2D,4,nWidth,nHeight,GL_RGBA,GL_UNSIGNED_BYTE,pcData);
-      }else{
-	glTexImage2D(GL_TEXTURE_2D,0,4,nWidth,nHeight,0,GL_RGBA,GL_UNSIGNED_BYTE,pcData);
+    /* Adapted from Extreme Tuxracer by Antti Harri and Lasse Collin */
+    GLint max_texture_size;
+    int depth = bAlpha?4:3;
+    /* Check if we need to scale image */
+    glGetIntegerv( GL_MAX_TEXTURE_SIZE, &max_texture_size );
+    if ( nWidth > max_texture_size || nHeight > max_texture_size ) {
+
+      Logger::Log("** Warning ** : TextureManager::createTexture() : Texture '%s' too large -- scaling to %i x %i",Name.c_str(), max_texture_size, max_texture_size );
+
+      unsigned char *newdata = new unsigned char[max_texture_size * max_texture_size * depth];
+
+      /*
+       * In the case of large- or small-aspect ratio textures, this
+       * could end up using *more* space... oh well.
+       */
+      GLint retval;
+      retval = gluScaleImage(bAlpha?GL_RGBA:GL_RGB,nWidth,nHeight,GL_UNSIGNED_BYTE,pcData,max_texture_size,max_texture_size,GL_UNSIGNED_BYTE,newdata );
+
+      if (retval!=0) {
+        throw TextureError("Failed to scale image in TextureManagerc::createTexture()");
       }
-      pTexture->nSize = nWidth * nHeight * 4;
+      delete[] pcData;
+      pcData = newdata;
+
+      pTexture->nWidth = nWidth = max_texture_size;
+      pTexture->nHeight = nHeight = max_texture_size;
     }
-    else {
-      /* Plain RGB */
+
       if(eFilterMode == FM_MIPMAP){
-	gluBuild2DMipmaps(GL_TEXTURE_2D,3,nWidth,nHeight,GL_RGB,GL_UNSIGNED_BYTE,pcData);
+        gluBuild2DMipmaps(GL_TEXTURE_2D,depth,nWidth,nHeight,bAlpha?GL_RGBA:GL_RGB,GL_UNSIGNED_BYTE,pcData);
       }else{
-	glTexImage2D(GL_TEXTURE_2D,0,3,nWidth,nHeight,0,GL_RGB,GL_UNSIGNED_BYTE,pcData);
+      glTexImage2D(GL_TEXTURE_2D,0,depth,nWidth,nHeight,0,bAlpha?GL_RGBA :GL_RGB,GL_UNSIGNED_BYTE,pcData);
       }
-      pTexture->nSize = nWidth * nHeight * 3;
-    }
 
     glDisable(GL_TEXTURE_2D);
     
@@ -130,13 +140,17 @@ namespace vapp {
         pTexture->surface  = SDL_CreateRGBSurfaceFrom(pcData,nWidth,nHeight,24 /*bitsPerPixel */, nWidth * 3 /*pitch*/,rmask,gmask,bmask,0);
 
       }
+
+      pTexture->pcData = pcData;
 #else
   pTexture->surface = NULL;
+  pTexture->pcData = NULL;
+  delete[] pcData;
 #endif
   
     /* Do it captain */
     m_Textures.push_back( pTexture );
-    
+
     return pTexture;
   }
   
@@ -147,17 +161,19 @@ namespace vapp {
     if(pTexture != NULL) {
       for(unsigned int i=0;i<m_Textures.size();i++) {
         if(m_Textures[i] == pTexture) {
+#ifdef ENABLE_SDLGFX
 	  SDL_FreeSurface(pTexture->surface);
+#endif
 #ifdef ENABLE_OPENGL
           glDeleteTextures(1,(GLuint *)&pTexture->nID);
 #endif
       
-	  //#ifdef ENABLE_SDLGFX
 	  //keesj:todo when using SDL surface we cannot delete the image data
 	  //this is a problem.
 	  //delete [] pc; => it's why i keep pTexture->pcData
+#ifdef ENABLE_SDLGFX
 	  delete [] pTexture->pcData;
-	  //#endif
+#endif
           m_nTexSpaceUsage -= pTexture->nSize;
           delete pTexture;
           m_Textures.erase(m_Textures.begin() + i);
@@ -190,7 +206,7 @@ namespace vapp {
     if(TextureImage.checkFile( Path,&ii )) {
       /* Valid texture size? */
       if(ii.nWidth != ii.nHeight) {
-        Log("** Warning ** : TextureManager::loadTexture() : texture '%s' is not square",Path.c_str());
+        Logger::Log("** Warning ** : TextureManager::loadTexture() : texture '%s' is not square",Path.c_str());
         throw TextureError("texture not square");
       }
       if(!(ii.nWidth == 1 ||
@@ -204,7 +220,7 @@ namespace vapp {
          ii.nWidth == 256 ||
          ii.nWidth == 512 ||
          ii.nWidth == 1024)) {
-        Log("** Warning ** : TextureManager::loadTexture() : texture '%s' size is not power of two",Path.c_str());
+        Logger::Log("** Warning ** : TextureManager::loadTexture() : texture '%s' size is not power of two",Path.c_str());
         throw TextureError("texture size not power of two");
       }
          
@@ -223,7 +239,7 @@ namespace vapp {
       pTexture = createTexture(TexName,pc,TextureImage.getWidth(),TextureImage.getHeight(),bAlpha,bClamp, eFilterMode);
     }
     else {
-      Log("** Warning ** : TextureManager::loadTexture() : texture '%s' not found or invalid",Path.c_str());
+      Logger::Log("** Warning ** : TextureManager::loadTexture() : texture '%s' not found or invalid",Path.c_str());
       throw TextureError(std::string("invalid or missing texture file (" + Path + ")").c_str());
     }    
     
@@ -258,130 +274,3 @@ namespace vapp {
     while(!m_Textures.empty())
       destroyTexture(m_Textures[0]);
   }
-  
-}
-
-//
-//  /*===========================================================================
-//  Default texture loader
-//  ===========================================================================*/
-//  void Texture::load(std::string FilePath,bool bSmall) {
-//    /* Load file as image */
-//    Img TextureImage;
-//    image_info_t ii;
-//    bool bLoadDummyTexture = false;
-//    //printf("[%s]\n",FilePath.c_str());
-//    if(TextureImage.checkFile( FilePath,&ii )) {
-//    //  printf("   [%d %d]\n",ii.nWidth,ii.nHeight);
-//      /* Seems ok, let's load! */
-//      TextureImage.loadFile( FilePath,bSmall );
-//      
-////      printf("OK %d %d %d\n",TextureImage.getWidth(),TextureImage.getHeight(),TextureImage.isAlpha());
-//
-//      /* Obtain RGBA format */
-//      unsigned char *pcData = TextureImage.convertToRGBA32();
-//
-//  //    printf("...\n");
-//
-//      /* Pass it to GL */
-//      GLuint N;
-//      glEnable(GL_TEXTURE_2D);
-//      glGenTextures(1,&N);    
-//      glBindTexture(GL_TEXTURE_2D,N);
-//      glTexImage2D(GL_TEXTURE_2D,0,4,TextureImage.getWidth(),TextureImage.getHeight(),
-//                   0,GL_RGBA,GL_UNSIGNED_BYTE,pcData);
-//      glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_NEAREST);
-//      glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_NEAREST);
-//      glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_WRAP_S,GL_REPEAT);
-//      glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_WRAP_T,GL_REPEAT);
-//      glDisable(GL_TEXTURE_2D);
-//            
-//      m_TI.nID = N;            
-//      delete [] pcData;
-//    }
-//    else {
-//      Log("** Warning ** : Texture::load() - invalid file: %s",FilePath.c_str());
-//      bLoadDummyTexture = true;
-//    }
-//    
-//    /* Should we load a dummy checkerboard pattern? */
-//    if(bLoadDummyTexture) {
-//      /* TODO: create checkerboard pattern */
-//    }
-//  }
-//
-//  /*===========================================================================
-//  Default texture unloader
-//  ===========================================================================*/
-//  void Texture::unload(void) {
-//    /* Delete GL name */
-//    glDeleteTextures(1,(GLuint *)&m_TI.nID);
-//  }
-//
-//  /*===========================================================================
-//  Texture loader 
-//  ===========================================================================*/
-//  Texture *TextureManager::loadTexture(Texture *pTexture,std::string FilePath,bool bSmall) {   
-//    /* Determine the "name" */
-//    std::string TexName = FS::getFileBaseName(FilePath);
-//    pTexture->m_TI.Name = TexName;
-//
-//    /* Load and manage texture */
-//    pTexture->load(FilePath,bSmall);  /* TODO:  FIX DET HER!! MSKE SKRIV EN NY TEXTUREMANAGER :( */
-//    //printf("%x  %x  L!! %s\n",this,pTexture,FilePath.c_str());
-//    m_Textures.push_back( pTexture );
-//    return pTexture;
-//  }
-//
-//  /*===========================================================================
-//  Unload texture
-//  ===========================================================================*/
-//  void TextureManager::_Unmanage(Texture *pTexture) {
-//    /* Find texture in list */
-//    for(int i=0;i<m_Textures.size();i++) {
-//      if(m_Textures[i] == pTexture) {
-//        delete m_Textures[i];
-//        m_Textures.erase(m_Textures.begin() + i);
-//        return;
-//      }
-//    }    
-//    
-//    /* Not found */
-//    throw TextureError("texture not found");
-//  }
-//  
-//  /*===========================================================================
-//  Unload all textures and stuff
-//  ===========================================================================*/
-//  Texture *TextureManager::getTexture(std::string Name) {
-//    /* Look up this texture */
-//    if(Name == "default") return getTexture( m_DefaultTextureName );
-//    
-//    for(int i=0;i<m_Textures.size();i++) {
-//      if(m_Textures[i]->getName() == Name) return m_Textures[i];
-//    }
-//    return NULL;
-//  }
-//
-//  /*===========================================================================
-//  Unload all textures and stuff
-//  ===========================================================================*/
-//  void TextureManager::_Shutdown(void) {
-//    for(int i=0;i<m_Textures.size();i++) {
-//      delete m_Textures[i];
-//    }
-//  }
-//  
-//  /*===========================================================================
-//  Fetch all textures with the given tag 
-//  ===========================================================================*/
-//  std::vector<Texture *> TextureManager::fetchTaggedTextures(std::string Tag) {
-//    std::vector<Texture *> Ret;
-//    
-//    for(int i=0;i<m_Textures.size();i++) {
-//      if(m_Textures[i]->getTag() == Tag) Ret.push_back(m_Textures[i]);
-//    }
-//    return Ret;
-//  }
-//  
-//};
