@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -22,12 +21,10 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 /* 
  *  XML support through the tinyxml library.
  */
-#include "VApp.h"
 #include "VXml.h"
 #include "VFileIO.h"
 #include "CRCHash.h"
-
-namespace vapp {
+#include "helpers/Log.h"
 
   /*===========================================================================
   Load XML document from disk
@@ -60,7 +57,7 @@ namespace vapp {
       /* Parse XML */
       m_pXML->Parse(Doc.c_str());
       if(m_pXML->Error()) {
-        Log("** Warning ** : XML-parsing error in '%s' : %s",File.c_str(),m_pXML->ErrorDesc());
+        Logger::Log("** Warning ** : XML-parsing error in '%s' : %s",File.c_str(),m_pXML->ErrorDesc());
       }
     }
   }
@@ -79,7 +76,7 @@ namespace vapp {
 
   std::string XML::str2xmlstr(std::string str) {
     std::string v_res = "";
-    for(int i=0; i<str.length(); i++) {
+    for(unsigned int i=0; i<str.length(); i++) {
       switch(str[i]) {
       case '&':
   v_res.append("&amp;");
@@ -211,4 +208,4 @@ namespace vapp {
       i++;
     }
   }  
-}
+
