@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -25,8 +24,6 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "VCommon.h"
 #include "tinyxml/tinyxml.h"
 
-namespace vapp {
-
   /*===========================================================================
   XML document
   ===========================================================================*/
@@ -58,7 +55,6 @@ namespace vapp {
     static std::string getElementText(XMLDocument& i_source, TiXmlElement *pRoot,std::string Name);
     static void appendText(std::string &Text,const std::string &Append);
   };
-}
 
 #endif
 
