@@ -2,22 +2,11 @@
 
 #include "BuildConfig.h"
 
-/* I (rasmus) made these (among others) changes to the files:  
-    - File names changed to WWW.cpp and WWW.h
-    - vapp::FS::getReplaysDir(), not vapp::FS::getReplayDir()
-    - vapp::FS::getLevelsDir(), not vapp::FS::getLevelDir()
-    - Interface class in WWWAppInterface.h (also renamed class to WWWAppInterface
-    - USE_HASH_MAP specifies whether hash_map or (stupid) vector should be used. 
-      Still too lazy to implement hash_map on windows :)
-    - no mkdir() in vs.net
-    - remove() also a bit different in vs.net
-    - added cleanHash() to WebRoom destructor
- */
-
 #include "WWW.h"
-#include "VApp.h"
+#include "Game.h"
 #include "VFileIO.h"
 #include "helpers/VExcept.h"
+#include "helpers/Log.h"
 #include "VXml.h"
 #include <curl/curl.h>
 #include "GameText.h"
@@ -32,139 +21,83 @@
 #include <sys/stat.h>
 #include <vector>
 #include "helpers/FileCompression.h"
-#include "md5sum/md5file.h"
 #include "db/xmDatabase.h"
-
-struct f_curl_download_data {
-  vapp::WWWAppInterface *v_WebApp;
-  int v_nb_files_to_download;
-  int v_nb_files_performed;
-};
-
-struct f_curl_upload_data {
-  vapp::WWWAppInterface *v_WebApp;
-};
-
-ProxySettings::ProxySettings() {
-  m_server       = "";
-  m_port         = -1;
-  m_type         = CURLPROXY_HTTP;
-  m_authUser     = "";
-  m_authPassword = "";
-}
-
-void ProxySettings::setServer(std::string p_server) {
-  m_server = p_server;
-}
-
-void ProxySettings::setPort(long p_port) {
-  m_port = p_port;
-}
-
-void ProxySettings::setType(long p_type) {
-  m_type = p_type;
-}
-
-void ProxySettings::setAuthentification(std::string p_user, std::string p_password) {
-  m_authUser     = p_user;
-  m_authPassword = p_password;
-}
-
-void ProxySettings::setDefaultServer() {
-  m_server = "";
-}
-
-void ProxySettings::setDefaultPort() {
-  m_port = -1;
-}
-
-void ProxySettings::setDefaultType() {
-  m_type = CURLPROXY_HTTP;
-}
-
-void ProxySettings::setDefaultAuthentification() {
-  m_authUser     = "";
-  m_authPassword = "";
-}
-
-std::string ProxySettings::getServer() const {
-  return m_server;
-}
-
-long ProxySettings::getPort() const {
-  return m_port;
-}
-
-long ProxySettings::getType() const {
-  return m_type;
-}
-
-std::string ProxySettings::getAuthentificationUser() const {
-  return m_authUser;
-}
-
-std::string ProxySettings::getAuthentificationPassword() const {
-  return m_authPassword;
-}
-
-bool ProxySettings::useDefaultServer() const {
-  return m_server == "";
-}
-
-bool ProxySettings::useDefaultPort() const {
-  return m_port == -1;
-}
-
-bool ProxySettings::useDefaultAuthentification() const {
-  return m_authUser == "";
-}
+#include "md5sum/md5file.h"
 
 void WebRoom::downloadReplay(const std::string& i_url) {
-  std::string i_rplFilename = vapp::FS::getReplaysDir()
+  std::string i_rplFilename = FS::getReplaysDir()
     + "/" 
-    + vapp::FS::getFileBaseName(i_url) 
+    + FS::getFileBaseName(i_url) 
     + ".rpl";
 
-  FSWeb::downloadFile(i_rplFilename, i_url, NULL, NULL, m_proxy_settings);
+  /* download xml file */
+  f_curl_download_data v_data;
+
+  v_data.v_WebApp               = m_WebRoomApp;
+  v_data.v_nb_files_performed   = 0;
+  v_data.v_nb_files_to_download = 1;
+
+  FSWeb::downloadFile(i_rplFilename, i_url,
+		      FSWeb::f_curl_progress_callback_download,
+		      &v_data, m_proxy_settings);
 }
 
-WebRoom::WebRoom(const ProxySettings *p_proxy_settings) {
-  std::string v_userDir;
-  v_userDir = vapp::FS::getUserDir();
-  m_userFilename =  v_userDir 
+WebRoom::WebRoom(WWWAppInterface* p_WebRoomApp)
+{
+  m_userFilename_prefix = FS::getUserDir()
     + "/" 
-    + DEFAULT_WEBHIGHSCORES_FILENAME;
+    + DEFAULT_WEBHIGHSCORES_FILENAME_PREFIX;
   m_webhighscores_url = DEFAULT_WEBHIGHSCORES_URL;
-
-  m_proxy_settings = p_proxy_settings;
+  m_WebRoomApp        = p_WebRoomApp;
+  m_proxy_settings    = NULL;
 }
 
-WebRoom::~WebRoom() {
+WebRoom::~WebRoom()
+{
 }
 
-std::string WebRoom::getRoomId() const {
+std::string WebRoom::getRoomId() const
+{
   return m_roomId;
 }
 
-void WebRoom::setWebsiteInfos(const std::string& i_id_room, const std::string& i_webhighscores_url) {
+void WebRoom::setWebsiteInfos(const std::string& i_id_room,
+			      const std::string& i_webhighscores_url,
+			      const ProxySettings* pProxySettings)
+{
   m_webhighscores_url = i_webhighscores_url;
-  m_roomId = i_id_room;
+  m_roomId            = i_id_room;
+  m_proxy_settings    = pProxySettings;
 }
 
-void WebRoom::update() {
+void WebRoom::update(unsigned int i_number)
+{
   /* download xml file */
-  FSWeb::downloadFileBz2UsingMd5(m_userFilename,
-         m_webhighscores_url,
-         NULL,
-         NULL,
-         m_proxy_settings);
+  f_curl_download_data v_data;
+  std::ostringstream v_strRoom;
+  v_strRoom << i_number;
+
+  v_data.v_WebApp               = m_WebRoomApp;
+  v_data.v_nb_files_performed   = 0;
+  v_data.v_nb_files_to_download = 1;
+
+  FSWeb::downloadFileBz2UsingMd5(m_userFilename_prefix + v_strRoom.str() + ".xml",
+				 m_webhighscores_url,
+				 FSWeb::f_curl_progress_callback_download,
+				 &v_data,
+				 m_proxy_settings);
 }
 
-void WebRoom::upgrade(xmDatabase *i_db) {
-  i_db->webhighscores_updateDB(m_userFilename, m_webhighscores_url);
+void WebRoom::upgrade(unsigned int i_number, xmDatabase *i_db)
+{
+  std::ostringstream v_strRoom;
+  v_strRoom << i_number;
+
+  i_db->webhighscores_updateDB(m_userFilename_prefix + v_strRoom.str() + ".xml", m_webhighscores_url);
 }
 
-size_t FSWeb::writeData(void *ptr, size_t size, size_t nmemb, FILE *stream) {
+size_t FSWeb::writeData(void *ptr, size_t size, size_t nmemb, FILE *stream)
+{
   return fwrite (ptr, size, nmemb, stream);
 }
 
@@ -209,31 +142,31 @@ void FSWeb::downloadFileBz2UsingMd5(const std::string &p_local_file,
   bool require_dwd = true;
 
   try {
-    if(vapp::FS::isFileReadable(p_local_file) == true) {
-      std::string v_md5Local  = md5file(p_local_file);
+    if(FS::isFileReadable(p_local_file) == true) {
+      std::string v_md5Local  = FS::md5sum(p_local_file);
       if(v_md5Local != "") {
-  std::string v_md5File = p_local_file + ".md5";
+	std::string v_md5File = p_local_file + ".md5";
   
-  /* remove in case it already exists */
-  remove(v_md5File.c_str());
-  downloadFile(v_md5File,
-         p_web_file + ".md5",
-         NULL, /* nothing for this */
-         NULL,
-         p_proxy_settings
-         );
-
-  std::string v_md5Web = md5Contents(v_md5File);
-  remove(v_md5File.c_str());
-  if(v_md5Web != "") {
-    require_dwd = v_md5Web != v_md5Local;
-  }
+	/* remove in case it already exists */
+	remove(v_md5File.c_str());
+	downloadFile(v_md5File,
+		     p_web_file + ".md5",
+		     NULL, /* nothing for this */
+		     NULL,
+		     p_proxy_settings
+		     );
+	
+	std::string v_md5Web = md5Contents(v_md5File);
+	remove(v_md5File.c_str());
+	if(v_md5Web != "") {
+	  require_dwd = v_md5Web != v_md5Local;
+	}
       }
     }
   } catch(Exception &e) {
     /* no pb, just dwd */
   }
-    
+
   if(require_dwd) {
     FSWeb::downloadFileBz2(p_local_file,
          p_web_file,
@@ -244,23 +177,23 @@ void FSWeb::downloadFileBz2UsingMd5(const std::string &p_local_file,
 }
 
 void FSWeb::downloadFile(const std::string &p_local_file,
-       const std::string &p_web_file,
-       int (*curl_progress_callback_download)(void *clientp,
-                double dltotal,
-                double dlnow,
-                double ultotal,
-                double ulnow),
-       void *p_data,
-       const ProxySettings *p_proxy_settings
-       ) {
-
-  vapp::Verbose(std::string("downloading " + 
-          p_web_file     +
-          " to "         +
-          p_local_file
-          ).c_str()
-    );
-
+			 const std::string &p_web_file,
+			 int (*curl_progress_callback_download)(void *clientp,
+								double dltotal,
+								double dlnow,
+								double ultotal,
+								double ulnow),
+			 void *p_data,
+			 const ProxySettings *p_proxy_settings
+			 ) {
+  
+  Logger::Log(std::string("downloading " + 
+			  p_web_file     +
+			  " to "         +
+			  p_local_file
+			  ).c_str()
+	      );
+  
   CURL *v_curl;
   CURLcode res;
   FILE *v_destinationFile;
@@ -279,7 +212,7 @@ void FSWeb::downloadFile(const std::string &p_local_file,
 
   /* download the file */
   v_curl = curl_easy_init();
-  if(v_curl == false) {
+  if(v_curl == NULL) {
     fclose(v_destinationFile);
     throw Exception("error : unable to init curl"); 
   }
@@ -290,11 +223,12 @@ void FSWeb::downloadFile(const std::string &p_local_file,
   curl_easy_setopt(v_curl, CURLOPT_TIMEOUT, DEFAULT_TRANSFERT_TIMEOUT);
   curl_easy_setopt(v_curl, CURLOPT_CONNECTTIMEOUT, DEFAULT_TRANSFERT_CONNECT_TIMEOUT);
   curl_easy_setopt(v_curl, CURLOPT_USERAGENT,  v_www_agent.c_str());
+  curl_easy_setopt(v_curl, CURLOPT_NOSIGNAL, 1);
   curl_easy_setopt(v_curl, CURLOPT_FAILONERROR, 1);
   curl_easy_setopt(v_curl, CURLOPT_FOLLOWLOCATION, 1);
 
   /* set proxy settings */
-  if(p_proxy_settings != NULL) {
+  if(p_proxy_settings != NULL && p_proxy_settings->getTypeStr() != "") {
     /* v_proxy_server because 
        after call to 
        curl_easy_setopt(v_curl, CURLOPT_PROXY, p_proxy_settings->getServer().c_str());
@@ -307,7 +241,6 @@ void FSWeb::downloadFile(const std::string &p_local_file,
       + p_proxy_settings->getAuthentificationPassword();
 
     if(p_proxy_settings->useDefaultServer() == false) {
-      vapp::Verbose(std::string("set proxy ->" + v_proxy_server).c_str());
       curl_easy_setopt(v_curl, CURLOPT_PROXY, v_proxy_server.c_str());
     }
     
@@ -318,7 +251,6 @@ void FSWeb::downloadFile(const std::string &p_local_file,
     curl_easy_setopt(v_curl, CURLOPT_PROXYTYPE, p_proxy_settings->getType());
    
     if(p_proxy_settings->useDefaultAuthentification() == false) {
-      vapp::Verbose(std::string("set proxy authentification ->" + v_proxy_auth_str).c_str());
       curl_easy_setopt(v_curl, CURLOPT_PROXYUSERPWD,
            v_proxy_auth_str.c_str());
     }
@@ -363,7 +295,7 @@ void FSWeb::uploadReplay(std::string p_replayFilename,
        std::string p_login,
        std::string p_password,
        std::string p_url_to_transfert,
-       vapp::WWWAppInterface *p_WebApp,
+       WWWAppInterface *p_WebApp,
        const ProxySettings *p_proxy_settings,
        bool &p_msg_status,
        std::string &p_msg) {
@@ -378,13 +310,11 @@ void FSWeb::uploadReplay(std::string p_replayFilename,
 
   FILE *v_destinationFile;
   std::string v_local_file;
-  v_local_file = vapp::FS::getUserDir() + "/" + DEFAULT_REPLAYUPLOAD_MSGFILE;
-
-  //printf("%s\n", v_local_file.c_str());
+  v_local_file = FS::getUserDir() + "/" + DEFAULT_REPLAYUPLOAD_MSGFILE;
 
   struct curl_httppost *v_post, *v_last;
 
-  vapp::Verbose(std::string("Uploading replay " + p_replayFilename).c_str());
+  Logger::Log(std::string("Uploading replay " + p_replayFilename).c_str());
 
   /* open the file */
   if( (v_destinationFile = fopen(v_local_file.c_str(), "wb")) == false) {
@@ -392,7 +322,7 @@ void FSWeb::uploadReplay(std::string p_replayFilename,
   }
       
   v_curl = curl_easy_init();
-  if(v_curl == false) {
+  if(v_curl == NULL) {
     fclose(v_destinationFile);
     remove(v_local_file.c_str());
     throw Exception("error : unable to init curl"); 
@@ -422,6 +352,7 @@ void FSWeb::uploadReplay(std::string p_replayFilename,
   curl_easy_setopt(v_curl, CURLOPT_WRITEDATA, v_destinationFile);
   curl_easy_setopt(v_curl, CURLOPT_WRITEFUNCTION, FSWeb::writeData);
   curl_easy_setopt(v_curl, CURLOPT_USERAGENT,  v_www_agent.c_str());
+  curl_easy_setopt(v_curl, CURLOPT_NOSIGNAL, 1);
   curl_easy_setopt(v_curl, CURLOPT_FAILONERROR, 1);
   curl_easy_setopt(v_curl, CURLOPT_FOLLOWLOCATION, 1);
   curl_easy_setopt(v_curl, CURLOPT_ENCODING, "gzip,deflate");
@@ -432,7 +363,7 @@ void FSWeb::uploadReplay(std::string p_replayFilename,
   curl_easy_setopt(v_curl, CURLOPT_HTTPHEADER, v_headers);
 
   /* set proxy settings */
-  if(p_proxy_settings != NULL) {
+  if(p_proxy_settings != NULL && p_proxy_settings->getTypeStr() != "") {
     /* v_proxy_server because 
        after call to 
        curl_easy_setopt(v_curl, CURLOPT_PROXY, p_proxy_settings->getServer().c_str());
@@ -445,7 +376,6 @@ void FSWeb::uploadReplay(std::string p_replayFilename,
       + p_proxy_settings->getAuthentificationPassword();
 
     if(p_proxy_settings->useDefaultServer() == false) {
-      vapp::Verbose(std::string("set proxy ->" + v_proxy_server).c_str());
       curl_easy_setopt(v_curl, CURLOPT_PROXY, v_proxy_server.c_str());
     }
     
@@ -456,7 +386,6 @@ void FSWeb::uploadReplay(std::string p_replayFilename,
     curl_easy_setopt(v_curl, CURLOPT_PROXYTYPE, p_proxy_settings->getType());
    
     if(p_proxy_settings->useDefaultAuthentification() == false) {
-      vapp::Verbose(std::string("set proxy authentification ->" + v_proxy_auth_str).c_str());
       curl_easy_setopt(v_curl, CURLOPT_PROXYUSERPWD,
            v_proxy_auth_str.c_str());
     }
@@ -503,7 +432,7 @@ void FSWeb::uploadReplay(std::string p_replayFilename,
 void FSWeb::uploadReplayAnalyseMsg(std::string p_filename,
            bool &p_msg_status_ok,
            std::string &p_msg) {
-  vapp::XMLDocument v_Xml;
+  XMLDocument v_Xml;
   TiXmlDocument *v_XmlData;
   TiXmlElement *v_XmlDataElement;
   TiXmlElement *v_XmlDataElementMsg;
@@ -553,43 +482,55 @@ void FSWeb::uploadReplayAnalyseMsg(std::string p_filename,
   p_msg = pc;
 }
 
-WebLevels::WebLevels(vapp::WWWAppInterface *p_WebLevelApp,
-         const ProxySettings *p_proxy_settings) {
+WebLevels::WebLevels(WWWAppInterface *p_WebLevelApp) {
   m_WebLevelApp    = p_WebLevelApp;
-  m_proxy_settings = p_proxy_settings;
+  m_proxy_settings = NULL;
   m_levels_url     = DEFAULT_WEBLEVELS_URL;
 }
 
 WebLevels::~WebLevels() {
 }
 
-std::string WebLevels::getXmlFileName() {
-  return vapp::FS::getUserDir() + "/" + DEFAULT_WEBLEVELS_FILENAME;
+void WebLevels::setWebsiteInfos(const std::string &p_url, const ProxySettings* p_proxy_settings)
+{
+  m_levels_url     = p_url;
+  m_proxy_settings = p_proxy_settings;
 }
 
-void WebLevels::downloadXml() {
+std::string WebLevels::getXmlFileName() {
+  return FS::getUserDir() + "/" + DEFAULT_WEBLEVELS_FILENAME;
+}
+
+void WebLevels::downloadXml()
+{
+  f_curl_download_data v_data;
+
+  v_data.v_WebApp               = m_WebLevelApp;
+  v_data.v_nb_files_performed   = 0;
+  v_data.v_nb_files_to_download = 1;
+
   FSWeb::downloadFileBz2UsingMd5(getXmlFileName(),
-         m_levels_url,
-         NULL,
-         NULL,
-         m_proxy_settings);
+				 m_levels_url,
+				 FSWeb::f_curl_progress_callback_download,
+				 &v_data,
+				 m_proxy_settings);
 }
 
 std::string WebLevels::getDestinationDir() {
-  return vapp::FS::getLevelsDir() + "/" + DEFAULT_WEBLEVELS_DIR;
+  return FS::getLevelsDir() + "/" + DEFAULT_WEBLEVELS_DIR;
 }
 
 void WebLevels::createDestinationDirIfRequired() {
   std::string v_destination_dir = getDestinationDir();
 
-  if(vapp::FS::isDir(v_destination_dir) == false) {
+  if(FS::isDir(v_destination_dir) == false) {
     /* no mkdir() with microsoft C */
-    vapp::FS::mkArborescence(v_destination_dir + "/file");
+    FS::mkArborescence(v_destination_dir + "/file");
   }
 }
 
 std::string WebLevels::getDestinationFile(std::string p_url) {
-  return getDestinationDir() + "/" + vapp::FS::getFileBaseName(p_url) + ".lvl";
+  return getDestinationDir() + "/" + FS::getFileBaseName(p_url) + ".lvl";
 }
 
 void WebLevels::update(xmDatabase *i_db) {
@@ -633,8 +574,10 @@ int FSWeb::f_curl_progress_callback_download(void *clientp,
   float real_percentage_of_current_file;
 
   /* cancel if it's wanted */
-  if(data->v_WebApp->isCancelAsSoonAsPossible()) {
-    return 1;
+  if(data->v_WebApp != NULL) {
+    if(data->v_WebApp->isCancelAsSoonAsPossible()) {
+      return 1;
+    }
   }
 
   real_percentage_already_done = 
@@ -651,25 +594,20 @@ int FSWeb::f_curl_progress_callback_download(void *clientp,
     }
   }
 
-  data->v_WebApp->setTaskProgress(real_percentage_already_done + real_percentage_of_current_file);
+  if(data->v_WebApp != NULL) {
+    data->v_WebApp->setTaskProgress(real_percentage_already_done + real_percentage_of_current_file);
+  }
 
   return 0;
 }
 
 int WebLevels::nbLevelsToGet(xmDatabase *i_db) const {
-  char **v_result;
-  int nrow;
-  v_result = i_db->readDB("SELECT a.name FROM weblevels AS a "
-			  "LEFT OUTER JOIN levels AS b ON a.id_level=b.id_level "
-			  "WHERE b.id_level IS NULL OR a.checkSum <> b.checkSum;",
-			  nrow);
-  i_db->read_DB_free(v_result);
-  return nrow;
+  return i_db->levels_nbLevelsToDownload();
 }
 
 void WebLevels::upgrade(xmDatabase *i_db) {
-  char **v_result;
-  int nrow;
+  char **v_result = NULL;
+  unsigned int nrow;
   std::string v_levelId;
   std::string v_levelName;
   std::string v_urlFile;
@@ -699,7 +637,11 @@ void WebLevels::upgrade(xmDatabase *i_db) {
   try {
     /* download levels */
     for(unsigned int i=0; i<nrow; i++) {
-      if(m_WebLevelApp->isCancelAsSoonAsPossible()) break;
+      if(m_WebLevelApp != NULL) {
+	if(m_WebLevelApp->isCancelAsSoonAsPossible()) {
+	  break;
+	}
+      }
 
       v_levelId    = i_db->getResult(v_result, 4, i, 0);
       v_levelName  = i_db->getResult(v_result, 4, i, 1);
@@ -725,7 +667,7 @@ void WebLevels::upgrade(xmDatabase *i_db) {
 	std::string v_destFile;
 	
 	if(v_isAnUpdate) {
-	  if(vapp::FS::isInUserDir(v_filePath)) {
+	  if(FS::isInUserDir(v_filePath)) {
 	    v_destFile = v_filePath;
 	  } else {
 	    v_destFile = WebLevels::getDestinationFile(v_urlFile);
@@ -745,13 +687,19 @@ void WebLevels::upgrade(xmDatabase *i_db) {
 	} else {
 	  m_webLevelsNewDownloadedOK.push_back(v_destFile);
 	}
-      }    
+      }  
       
       v_nb_levels_performed++;
-      m_WebLevelApp->readEvents(); 
     }
   } catch(Exception &e) {
     i_db->read_DB_free(v_result);
+
+    if(m_WebLevelApp != NULL) { // this is not an error in this case
+      if(m_WebLevelApp->isCancelAsSoonAsPossible()) {
+	return;
+      }
+    }
+
     throw e;
   }
   m_WebLevelApp->setTaskProgress(100.0);
@@ -766,163 +714,211 @@ const std::vector<std::string> &WebLevels::getUpdatedDownloadedLevels(void) {
   return m_webLevelsUpdatedDownloadedOK;
 }
 
-WebThemes::WebThemes(vapp::WWWAppInterface *p_WebApp,
-         const ProxySettings *p_proxy_settings) {
-  m_proxy_settings = p_proxy_settings;
-  m_themes_url     = DEFAULT_WEBTHEMES_URL;
-  m_themes_urlBase = DEFAULT_WEBTHEMES_SPRITESURLBASE;
-  m_WebApp = p_WebApp;
-}
+void WebThemes::updateTheme(xmDatabase* i_pDb, const std::string& i_id_theme, WWWAppInterface* i_WebLevelApp) {
+  bool i_askThreadToEnd = false;
 
-WebThemes::~WebThemes() {
-}
-
-void WebThemes::update(xmDatabase *i_db) {
-  FSWeb::downloadFileBz2UsingMd5(getXmlFileName(),
-         m_themes_url,
-         NULL,
-         NULL,
-         m_proxy_settings);
-  i_db->webthemes_updateDB(getXmlFileName());
-}
-
-std::string WebThemes::getXmlFileName() {
-  return vapp::FS::getUserDir() + "/" + DEFAULT_WEBTHEMES_FILENAME;
-}
-
-void WebThemes::upgrade(xmDatabase *i_db, const std::string& i_id_theme) {
-  std::string v_destinationFile;
-  std::string v_sourceFile;
-  f_curl_download_data v_data;
-  char **v_result;
-  int nrow;
-  std::string v_fileUrl;
-  std::string v_filePath;
-  std::string v_themeFile;
-  bool v_onDisk = false;
-
-  /* download even if the the theme is uptodate
-     it give a possibility to download file removed by mistake
-  */
-  v_result = i_db->readDB("SELECT a.fileUrl, b.filepath "
-			  "FROM webthemes AS a LEFT OUTER JOIN themes AS b "
-			  "ON a.id_theme = b.id_theme "
-			  "WHERE a.id_theme=\"" + xmDatabase::protectString(i_id_theme) + "\";",
-			  nrow);
-  if(nrow != 1) {
-    i_db->read_DB_free(v_result);
-    throw Exception("error : unable to find this theme on the web");
-  }
-
-  v_fileUrl = i_db->getResult(v_result, 2, 0, 0);
-  if(i_db->getResult(v_result, 2, 0, 1) != NULL) {
-    v_filePath = i_db->getResult(v_result, 2, 0, 1);
-    v_onDisk = true;
-  }  
-  i_db->read_DB_free(v_result);
-
-  // theme avaible on the web get it
-
-  /* the destination file must be in the user dir */
-  if(v_filePath != "") {
-    if(vapp::FS::isInUserDir(v_filePath)) {
-      v_destinationFile = v_filePath;
+  if(i_WebLevelApp != NULL) {
+    if(i_WebLevelApp->isCancelAsSoonAsPossible()) {
+      return;
     }
   }
 
-  if(v_destinationFile == "") {
-    /* determine destination file */
-    v_destinationFile = 
-      vapp::FS::getUserDir() + "/" + THEMES_DIRECTORY + "/" + 
-      vapp::FS::getFileBaseName(v_fileUrl) + ".xml";
-  } 
-  
-  v_themeFile = v_destinationFile;
+  try {
+    Logger::Log("WWW: Downloading a theme...");
+    
+    std::string v_destinationFile, v_destinationFileXML, v_destinationFileXML_tmp;
+    std::string v_sourceFile;
+    f_curl_download_data v_data;
+    char **v_result;
+    unsigned int nrow;
+    std::string v_fileUrl;
+    std::string v_filePath;
+    std::string v_themeFile;
+    bool v_onDisk = false;
+    std::string v_md5Local;
+    std::string v_md5Dist;
+    bool v_all_downloaded = false;
 
-  /* download the theme file */
-  vapp::FS::mkArborescence(v_destinationFile);
-  FSWeb::downloadFileBz2(v_destinationFile,
-			 v_fileUrl,
-			 NULL,
-			 NULL,
-			 m_proxy_settings);
-
-  /* download all the files required */
-  Theme *v_theme = new Theme();
-  std::vector<std::string> *v_required_files;
-  v_theme->load(v_destinationFile);
-  v_required_files = v_theme->getRequiredFiles();
-
-  int v_nb_files_to_download = 0;
-  for(unsigned int i=0; i<v_required_files->size(); i++) {
-    if(vapp::FS::fileExists((*v_required_files)[i]) == false) {
-      v_nb_files_to_download++;
+    v_data.v_WebApp = i_WebLevelApp;
+    
+    /* download even if the the theme is uptodate
+       it give a possibility to download file removed by mistake
+    */
+    v_result = i_pDb->readDB("SELECT a.fileUrl, b.filepath "
+			     "FROM webthemes AS a LEFT OUTER JOIN themes AS b "
+			     "ON a.id_theme = b.id_theme "
+			     "WHERE a.id_theme=\"" + xmDatabase::protectString(i_id_theme) + "\";",
+			     nrow);
+    if(nrow != 1) {
+      i_pDb->read_DB_free(v_result);
+      throw Exception("Unable to found the theme on the website");
     }
-  }
-  if(v_nb_files_to_download != 0) {
-    int v_nb_files_performed  = 0;
-
-    v_data.v_WebApp = m_WebApp;
-    v_data.v_nb_files_to_download = v_nb_files_to_download;
-
-    unsigned int i = 0;
-    while(i<v_required_files->size() && m_WebApp->isCancelAsSoonAsPossible() == false) {
-      // download v_required_files[i]     
-      v_destinationFile = vapp::FS::getUserDir() + std::string("/") + (*v_required_files)[i];
-      v_sourceFile = m_themes_urlBase + 
-	std::string("/") + (*v_required_files)[i];
-
-      if(vapp::FS::fileExists((*v_required_files)[i]) == false) {
-	v_data.v_nb_files_performed = v_nb_files_performed;
-  
-	float v_percentage = (((float)v_nb_files_performed) * 100.0) / ((float)v_nb_files_to_download);
-	m_WebApp->setTaskProgress(v_percentage);
-	m_WebApp->setBeingDownloadedInformation((*v_required_files)[i], true);
-
-	vapp::FS::mkArborescence(v_destinationFile);
-
-	FSWeb::downloadFile(v_destinationFile,
-			    v_sourceFile,
-			    FSWeb::f_curl_progress_callback_download,
-			    &v_data,
-			    m_proxy_settings);
-  
-	v_nb_files_performed++;
+    
+    v_fileUrl = i_pDb->getResult(v_result, 2, 0, 0);
+    if(i_pDb->getResult(v_result, 2, 0, 1) != NULL) {
+      v_filePath = i_pDb->getResult(v_result, 2, 0, 1);
+      v_onDisk = true;
+    }  
+    i_pDb->read_DB_free(v_result);
+    
+    // theme avaible on the web get it
+    
+    /* the destination file must be in the user dir */
+    if(v_filePath != "") {
+      if(FS::isInUserDir(v_filePath)) {
+	v_destinationFileXML = v_filePath;
       }
-      m_WebApp->readEvents();
-      i++;
     }
-    m_WebApp->setTaskProgress(100.0);
+
+    if(v_destinationFileXML == "") {
+      /* determine destination file */
+      v_destinationFileXML = 
+	FS::getUserDir() + "/" + THEMES_DIRECTORY + "/" + 
+	FS::getFileBaseName(v_fileUrl) + ".xml";
+    }
+  
+    v_themeFile = v_destinationFileXML;
+    
+    /* download the theme file */
+    v_data.v_nb_files_performed   = 0;
+    v_data.v_nb_files_to_download = 1;
+    FS::mkArborescence(v_destinationFileXML);
+    v_destinationFileXML_tmp = v_destinationFileXML + ".tmp";
+    FSWeb::downloadFileBz2(v_destinationFileXML_tmp, v_fileUrl, FSWeb::f_curl_progress_callback_download, &v_data, XMSession::instance()->proxySettings());
+    
+    if(i_WebLevelApp != NULL) {
+      if(i_WebLevelApp->isCancelAsSoonAsPossible()) {
+	remove(v_destinationFileXML_tmp.c_str());
+	return;
+      }
+    }
+
+    /* download all the files required */
+    Theme *v_theme = Theme::instance();
+    std::vector<ThemeFile> *v_required_files;
+    v_theme->load(v_destinationFileXML_tmp);
+    v_required_files = v_theme->getRequiredFiles();
+
+    // all files must be checked for md5sum
+    int v_nb_files_to_download = 0;
+    for(unsigned int i=0; i<v_required_files->size(); i++) {
+      if(FS::fileExists((*v_required_files)[i].filepath) == false) {
+	v_nb_files_to_download++;
+      } else {
+	v_md5Local = FS::md5sum((*v_required_files)[i].filepath);
+	v_md5Dist  = (*v_required_files)[i].filemd5;
+	if(v_md5Local != v_md5Dist && v_md5Dist != "") {
+	  v_nb_files_to_download++;
+	}
+      }
+    }
+    
+    if(v_nb_files_to_download != 0) {
+      int v_nb_files_performed  = 0;
+      
+      v_data.v_nb_files_performed   = 0;
+      v_data.v_nb_files_to_download = v_nb_files_to_download;
+      
+      unsigned int i = 0;
+      if(i_WebLevelApp != NULL) {
+	if(i_WebLevelApp->isCancelAsSoonAsPossible()) {
+	  i_askThreadToEnd = true;
+	}
+      }
+
+      while(i<v_required_files->size() && i_askThreadToEnd == false) {
+	// download v_required_files[i]     
+	v_destinationFile = FS::getUserDir() + std::string("/") + (*v_required_files)[i].filepath;
+	v_sourceFile = XMSession::instance()->webThemesURLBase() + std::string("/") + (*v_required_files)[i].filepath;
+	
+	/* check md5 sums */
+	v_md5Local = v_md5Dist = "";
+	if(FS::fileExists((*v_required_files)[i].filepath) == true) {
+	  v_md5Local = FS::md5sum((*v_required_files)[i].filepath);
+	  v_md5Dist  = (*v_required_files)[i].filemd5;
+	}
+	
+	/* if v_md5Dist == "", don't download ; it's a manually adding */
+	if(FS::fileExists((*v_required_files)[i].filepath) == false || (v_md5Local != v_md5Dist && v_md5Dist != "")) {
+	  v_data.v_nb_files_performed = v_nb_files_performed;
+	  
+	  float v_percentage = (((float)v_nb_files_performed) * 100.0) / ((float)v_nb_files_to_download);
+	  if(i_WebLevelApp != NULL) {
+	    i_WebLevelApp->setTaskProgress(v_percentage);
+	    i_WebLevelApp->setBeingDownloadedInformation((*v_required_files)[i].filepath);
+	  }
+
+	  FS::mkArborescence(v_destinationFile);
+	  
+	  FSWeb::downloadFile(v_destinationFile, v_sourceFile, FSWeb::f_curl_progress_callback_download, &v_data,
+			      XMSession::instance()->proxySettings());
+	  
+	  v_nb_files_performed++;
+	}
+	i++;
+
+	if(i_WebLevelApp != NULL) {
+	  if(i_WebLevelApp->isCancelAsSoonAsPossible()) {
+	    i_askThreadToEnd = true;
+	  }
+	}
+      }
+      v_all_downloaded = i == v_required_files->size();
+
+      if(i_WebLevelApp != NULL) {
+	i_WebLevelApp->setTaskProgress(100);
+      }
+    } else {
+      v_all_downloaded = true;
+    }
+
+    /* full downloading, put the xml */
+    if(v_all_downloaded) {
+      remove(v_destinationFileXML.c_str());
+      if(rename(v_destinationFileXML_tmp.c_str(), v_destinationFileXML.c_str()) != 0) {
+	remove(v_destinationFileXML_tmp.c_str());
+	throw Exception("Failed to update the theme");
+	return;
+      } else {
+	if(v_onDisk) {
+	  i_pDb->themes_update(i_id_theme, v_themeFile);
+	} else {
+	  i_pDb->themes_add(i_id_theme, v_themeFile);
+	}
+      }
+    } else {
+      remove(v_destinationFileXML_tmp.c_str());
+    }
+
+  } catch(Exception &e) {
+    if(i_WebLevelApp != NULL) {
+      if(i_WebLevelApp->isCancelAsSoonAsPossible()) {
+	return;
+      }
+    }
+    
+    Logger::Log("** Warning ** : Failed to update theme %s (%s)", i_id_theme.c_str(), e.getMsg().c_str());
+    throw Exception("Failed to update the theme");
+    return;
   }
   
-  delete v_theme;
+}
 
-  if(v_onDisk) {
-    i_db->themes_update(i_id_theme, v_themeFile);
-  } else {
-    i_db->themes_add(i_id_theme, v_themeFile);
+void WebThemes::updateThemeList(xmDatabase* i_pDb, WWWAppInterface* i_WebLevelApp) {
+  std::string v_destinationFile = FS::getUserDir() + "/" + DEFAULT_WEBTHEMES_FILENAME;
+  f_curl_download_data v_data;
+  
+  if(i_WebLevelApp != NULL) {
+    if(i_WebLevelApp->isCancelAsSoonAsPossible()) {
+      return;
+    }
   }
-}
 
-WebRooms::WebRooms(const ProxySettings *p_proxy_settings) {
-  m_proxy_settings = p_proxy_settings;
-}
-
-WebRooms::~WebRooms() {
-}
-
-void WebRooms::update() {
-  FSWeb::downloadFileBz2UsingMd5(getXmlFileName(),
-         m_rooms_url,
-         NULL,
-         NULL,
-         m_proxy_settings);
-}
-
-std::string WebRooms::getXmlFileName() {
-  return vapp::FS::getUserDir() + "/" + DEFAULT_WEBROOMS_FILENAME;
-}
-
-void WebRooms::upgrade(xmDatabase *i_db) {
-  i_db->webrooms_updateDB(getXmlFileName());
+  Logger::Log("WWW: Checking for new or updated themes...");
+  v_data.v_WebApp = i_WebLevelApp;
+  v_data.v_nb_files_performed   = 0;
+  v_data.v_nb_files_to_download = 1;
+  FSWeb::downloadFileBz2UsingMd5(v_destinationFile, XMSession::instance()->webThemesURL(),
+				 FSWeb::f_curl_progress_callback_download, &v_data, XMSession::instance()->proxySettings());
+  i_pDb->webthemes_updateDB(v_destinationFile);
 }
