@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -36,10 +35,12 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include "WWWAppInterface.h"
 #include "Theme.h"
+#include "XMSession.h"
+#include "XMBuild.h"
 class ThemeChoice;
 
 #define DEFAULT_WEBHIGHSCORES_URL         "http://xmoto.tuxfamily.org/highscores.xml"
-#define DEFAULT_WEBHIGHSCORES_FILENAME    "webhighscores.xml"
+#define DEFAULT_WEBHIGHSCORES_FILENAME_PREFIX    "webhighscores"
 #define DEFAULT_TRANSFERT_TIMEOUT         240
 #define DEFAULT_TRANSFERT_CONNECT_TIMEOUT 15
 #define DEFAULT_WEBLEVELS_URL             "http://xmoto.tuxfamily.org/levels.xml"
@@ -52,10 +53,9 @@ class ThemeChoice;
 #define DEFAULT_REPLAYUPLOAD_MSGFILE      "UploadReplayMsg.xml"
 #define DEFAULT_WEBROOMS_URL              "http://xmoto.tuxfamily.org/rooms.xml"
 #define DEFAULT_WEBROOMS_FILENAME         "webrooms.xml"
-#define DEFAULT_WEBROOM_ID                "1"
 #define DEFAULT_WEBROOM_NAME              "WR"
 
-#define WWW_AGENT ("xmoto-" + vapp::App::getVersionString())
+#define WWW_AGENT ("xmoto-" + XMBuild::getVersionString(true))
 
 #if defined(USE_HASH_MAP)
   #ifdef __GNUC__
@@ -78,41 +78,20 @@ class ThemeChoice;
   };
 #endif
 
+struct f_curl_download_data {
+  WWWAppInterface *v_WebApp;
+  int v_nb_files_to_download;
+  int v_nb_files_performed;
+};
+
+struct f_curl_upload_data {
+  WWWAppInterface *v_WebApp;
+};
+
+
 class WebRoom;
 class xmDatabase;
 
-class ProxySettings {
- public:
-  ProxySettings();
-  void setServer(std::string p_server);
-  void setPort(long p_port);
-  void setType(long p_type); /* CURLPROXY_HTTP OR CURLPROXY_SOCKS5 */
-  void setAuthentification(std::string p_user, std::string p_password);
-
-  void setDefaultServer();
-  void setDefaultPort();
-  void setDefaultType();
-  void setDefaultAuthentification();
-
-  std::string getServer() const;
-  long getPort() const;
-  long getType() const; /* CURLPROXY_HTTP OR CURLPROXY_SOCKS5 */
-  std::string getAuthentificationUser() const;
-  std::string getAuthentificationPassword() const;
-
-  /* default means : curl try to find default values (no proxy, or environment vars) */
-  bool useDefaultServer() const;
-  bool useDefaultPort() const;
-  bool useDefaultAuthentification() const;
-
- private:
-  std::string m_server;
-  long m_port;
-  long m_type;
-  std::string m_authUser;
-  std::string m_authPassword;
-};
-
 class FSWeb {
  public:
   static void downloadFile(const std::string &p_local_file,
@@ -150,7 +129,7 @@ class FSWeb {
 			   std::string p_login,
 			   std::string p_password,
 			   std::string p_url_to_transfert,
-			   vapp::WWWAppInterface *p_WebApp,
+			   WWWAppInterface *p_WebApp,
 			   const ProxySettings *p_proxy_settings,
 			   bool &p_msg_status,
 			   std::string &p_msg);
@@ -176,56 +155,38 @@ class FSWeb {
 
 class WebRoom {
  public:
-  WebRoom(const ProxySettings *p_proxy_settings);
+  WebRoom(WWWAppInterface* p_WebRoomApp);
   ~WebRoom();
 
-  void update(); /* throws exceptions */
-  void upgrade(xmDatabase *i_db); /* throws exceptions */
+  void update(unsigned int i_number); /* throws exceptions */
+  void upgrade(unsigned int i_number, xmDatabase* i_db); /* throws exceptions */
 
   /* return NULL if no data found */
-  void setWebsiteInfos(const std::string& i_id_room, const std::string& i_webhighscores_url);
+  void setWebsiteInfos(const std::string& i_id_room,
+		       const std::string& i_webhighscores_url,
+		       const ProxySettings* pProxySettings);
   std::string getRoomId() const;
 
   void downloadReplay(const std::string& i_url);
 
  private:
-  std::string m_userFilename;
+  WWWAppInterface* m_WebRoomApp;
+  std::string m_userFilename_prefix;
   std::string m_webhighscores_url;
   std::string m_roomId;
-  const ProxySettings *m_proxy_settings;
-};
-
-class WebRooms {
- public:
-  WebRooms(const ProxySettings *p_proxy_settings);
-  ~WebRooms();
-
-  /* check for new rooms */
-  void update(); /* throws exceptions */
-
-  /* fill the list of avaible rooms ; does not required an internet connexion */
-  void upgrade(xmDatabase *i_db);
-
-  void setURL(const std::string &p_url) {m_rooms_url = p_url;}
-
- private:
-  const ProxySettings *m_proxy_settings;
-  std::string m_rooms_url;
-
-  std::string getXmlFileName();
+  const ProxySettings* m_proxy_settings;
 };
 
 class WebLevels {
  public:
-  WebLevels(vapp::WWWAppInterface *p_WebLevelApp,
-	    const ProxySettings *p_proxy_settings);
+  WebLevels(WWWAppInterface* p_WebLevelApp);
   ~WebLevels();
 
   /* check for new levels to download */
-  void update(xmDatabase *i_db); /* throws exceptions */
+  void update(xmDatabase* i_db); /* throws exceptions */
 
   /* download new levels */
-  void upgrade(xmDatabase *i_db); /* throws exceptions */
+  void upgrade(xmDatabase* i_db); /* throws exceptions */
   
   /* Get names of new files downloaded OK */
   const std::vector<std::string> &getNewDownloadedLevels();
@@ -234,7 +195,7 @@ class WebLevels {
   const std::vector<std::string> &getUpdatedDownloadedLevels();
   
   /* Set URL */
-  void setURL(const std::string &p_url) {m_levels_url = p_url;}
+  void setWebsiteInfos(const std::string &p_url, const ProxySettings* p_proxy_settings);
 
   static std::string getDestinationFile(std::string p_url);
 
@@ -242,7 +203,7 @@ class WebLevels {
   int nbLevelsToGet(xmDatabase *i_db) const;
 
  private:
-  vapp::WWWAppInterface *m_WebLevelApp;
+  WWWAppInterface* m_WebLevelApp;
 
   std::vector<std::string> m_webLevelsNewDownloadedOK; /* file names of those levels 
            which where downloaded OK (so we can load them right away) and which are new */
@@ -260,26 +221,9 @@ class WebLevels {
 
 class WebThemes {
  public:
-  WebThemes(vapp::WWWAppInterface *p_WebApp,
-	    const ProxySettings *p_proxy_settings);
-  ~WebThemes();
-
-  /* check for new themes to download */
-  void update(xmDatabase *i_db); /* throws exceptions */
-
-  /* download a theme or just update it */
-  void upgrade(xmDatabase *i_db, const std::string& i_id_theme);
-
-  void setURL(const std::string &p_url) {m_themes_url = p_url;}
-  void setURLBase(const std::string &p_urlBase) {m_themes_urlBase = p_urlBase;}
-
- private:
-  std::string getXmlFileName();
-
-  vapp::WWWAppInterface *m_WebApp;
-  std::string m_themes_url;
-  std::string m_themes_urlBase;
-  const ProxySettings *m_proxy_settings;
+  static void updateTheme(xmDatabase* i_pDb, const std::string& i_id_theme, WWWAppInterface* i_WebLevelApp);
+  static void updateThemeList(xmDatabase* i_pDb, WWWAppInterface* i_WebLevelApp);
+  
 };
 
 #endif /* WEBSTUFFS */
