@@ -21,18 +21,25 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "xmDatabase.h"
 #include "helpers/VExcept.h"
 #include "GameText.h"
-#include "VApp.h"
+#include "WWW.h"
+#include "helpers/Log.h"
+#include "XMSession.h"
+#include "VFileIO.h"
 
-#define XMDB_VERSION 13
+#define XMDB_VERSION 20
 
 bool xmDatabase::Trace = false;
 
-xmDatabase::xmDatabase(const std::string& i_dbFile,
-		       const std::string& i_profile,
-		       const std::string& i_gameDir,
-		       const std::string& i_userDir,
-		       const std::string& i_binPackCheckSum,
-		       XmDatabaseUpdateInterface *i_interface) {
+xmDatabase::xmDatabase()
+{
+}
+
+void xmDatabase::init(const std::string& i_dbFile,
+		      const std::string& i_profile,
+		      const std::string& i_gameDir,
+		      const std::string& i_userDir,
+		      const std::string& i_binPackCheckSum,
+		      XmDatabaseUpdateInterface *i_interface) {
   int v_version;
 
   m_requiredLevelsUpdateAfterInit  = false;
@@ -47,15 +54,21 @@ xmDatabase::xmDatabase(const std::string& i_dbFile,
   sqlite3_trace(m_db, sqlTrace, NULL);
   createUserFunctions();
 
+//  if(sqlite3_threadsafe() == 0) {
+//    Logger::Log("** Warning ** Sqlite is not threadSafe !!!");
+//  } else {
+//    Logger::Log("Sqlite is threadSafe");
+//  }
+
   v_version = getXmDbVersion();
-  vapp::Log("XmDb version is %i", v_version);
+  Logger::Log("XmDb version is %i", v_version);
 
   if(v_version > XMDB_VERSION) {
     throw Exception("Your XM database required a newer version of xmoto");
   }
 
   if(v_version < XMDB_VERSION) {
-    vapp::Log("Update XmDb version from %i to %i", v_version, XMDB_VERSION);
+    Logger::Log("Update XmDb version from %i to %i", v_version, XMDB_VERSION);
 
     if(i_interface != NULL) {
       i_interface->updatingDatabase(GAMETEXT_DB_UPGRADING);
@@ -64,16 +77,34 @@ xmDatabase::xmDatabase(const std::string& i_dbFile,
   }
 
   /* check if gameDir and userDir are the same - otherwise, the computer probably changed */
-  if(i_gameDir != getXmDbGameDir() || i_userDir != getXmDbUserDir()
-     || i_binPackCheckSum != getXmDbBinPackCheckSum()) {
+  if(FS::areSamePath(i_gameDir, getXmDbGameDir()) == false ||
+     FS::areSamePath(i_userDir, getXmDbUserDir()) == false ||
+     i_binPackCheckSum != getXmDbBinPackCheckSum()
+     ) {
     m_requiredLevelsUpdateAfterInit  = true;
     m_requiredReplaysUpdateAfterInit = true;
     m_requiredThemesUpdateAfterInit  = true;
     setXmDbGameDir(i_gameDir);
     setXmDbUserDir(i_userDir);
     setXmDbBinPackCheckSum(i_binPackCheckSum);
+
+    /* -- first initialisation or xmoto.bin/userdir update -- */
+    webLoadDataFirstTime();
   }
 }
+
+void xmDatabase::init(const std::string& i_dbFile)
+{
+  if(sqlite3_open(i_dbFile.c_str(), &m_db) != 0){
+    throw Exception("Unable to open the database ("
+		    + i_dbFile
+		    + ") : "
+		    + sqlite3_errmsg(m_db));
+  }
+
+  sqlite3_trace(m_db, sqlTrace, NULL);
+  createUserFunctions();
+}
  
 xmDatabase::~xmDatabase() {
   sqlite3_close(m_db);
@@ -91,7 +122,7 @@ void xmDatabase::sqlTrace(void* arg1, const char* sql) {
 
 std::string xmDatabase::getXmDbGameDir() {
   char **v_result;
-  int nrow;
+  unsigned int nrow;
   std::string v_dir;
 
   v_result = readDB("SELECT value FROM xm_parameters WHERE param=\"gameDir\";", nrow);
@@ -108,7 +139,7 @@ std::string xmDatabase::getXmDbGameDir() {
 
 std::string xmDatabase::getXmDbUserDir() {
   char **v_result;
-  int nrow;
+  unsigned int nrow;
   std::string v_dir;
 
   v_result = readDB("SELECT value FROM xm_parameters WHERE param=\"userDir\";", nrow);
@@ -125,7 +156,7 @@ std::string xmDatabase::getXmDbUserDir() {
 
 void xmDatabase::setXmDbGameDir(const std::string& i_gameDir) {
   char **v_result;
-  int nrow;
+  unsigned int nrow;
 
   v_result = readDB("SELECT value FROM xm_parameters WHERE param=\"gameDir\";", nrow);
   read_DB_free(v_result);
@@ -141,7 +172,7 @@ void xmDatabase::setXmDbGameDir(const std::string& i_gameDir) {
 
 void xmDatabase::setXmDbUserDir(const std::string& i_userDir) {
   char **v_result;
-  int nrow;
+  unsigned int nrow;
 
   v_result = readDB("SELECT value FROM xm_parameters WHERE param=\"userDir\";", nrow);
   read_DB_free(v_result);
@@ -157,7 +188,7 @@ void xmDatabase::setXmDbUserDir(const std::string& i_userDir) {
 
 std::string xmDatabase::getXmDbBinPackCheckSum() {
   char **v_result;
-  int nrow;
+  unsigned int nrow;
   std::string v_dir;
 
   v_result = readDB("SELECT value FROM xm_parameters WHERE param=\"binPackCkSum\";", nrow);
@@ -174,7 +205,7 @@ std::string xmDatabase::getXmDbBinPackCheckSum() {
 
 void xmDatabase::setXmDbBinPackCheckSum(const std::string& i_binPackChecksum) {
   char **v_result;
-  int nrow;
+  unsigned int nrow;
 
   v_result = readDB("SELECT value FROM xm_parameters WHERE param=\"binPackCkSum\";", nrow);
   read_DB_free(v_result);
@@ -190,7 +221,8 @@ void xmDatabase::setXmDbBinPackCheckSum(const std::string& i_binPackChecksum) {
 
 int xmDatabase::getXmDbVersion() {
   char **v_result;
-  int nrow, ncolumn;
+  int nrow;
+  int ncolumn;
   char *errMsg;
   std::string v_errMsg;
   int v_version;
@@ -223,7 +255,6 @@ int xmDatabase::getXmDbVersion() {
 
 void xmDatabase::updateXmDbVersion(int i_newVersion) {
   std::ostringstream v_newVersion;
-  char *errMsg;
   std::string v_errMsg;
 
   v_newVersion << i_newVersion;
@@ -235,7 +266,6 @@ void xmDatabase::updateXmDbVersion(int i_newVersion) {
 void xmDatabase::upgradeXmDbToVersion(int i_fromVersion,
 				      const std::string& i_profile,
 				      XmDatabaseUpdateInterface *i_interface) {
-  char *errMsg;
   std::string v_errMsg;
 
   /* no break in this swicth ! */
@@ -263,7 +293,7 @@ void xmDatabase::upgradeXmDbToVersion(int i_fromVersion,
     try {
       updateDB_stats(i_interface);
     } catch(Exception &e) {
-      vapp::Log(std::string("Oups, updateDB_stats() failed: " + e.getMsg()).c_str());
+      Logger::Log(std::string("Oups, updateDB_stats() failed: " + e.getMsg()).c_str());
     }
 
   case 2:
@@ -284,7 +314,7 @@ void xmDatabase::upgradeXmDbToVersion(int i_fromVersion,
       try {
 	updateDB_favorite(i_profile, i_interface);
       } catch(Exception &e) {
-	vapp::Log(std::string("Oups, updateDB_favorite() failed: " + e.getMsg()).c_str());
+	Logger::Log(std::string("Oups, updateDB_favorite() failed: " + e.getMsg()).c_str());
       }
       updateXmDbVersion(4);
     } catch(Exception &e) {
@@ -300,7 +330,7 @@ void xmDatabase::upgradeXmDbToVersion(int i_fromVersion,
       try {
 	updateDB_profiles(i_interface);
       } catch(Exception &e) {
-	vapp::Log(std::string("Oups, updateDB_profiles() failed: " + e.getMsg()).c_str());
+	Logger::Log(std::string("Oups, updateDB_profiles() failed: " + e.getMsg()).c_str());
       }
       updateXmDbVersion(5);
     } catch(Exception &e) {
@@ -386,6 +416,68 @@ void xmDatabase::upgradeXmDbToVersion(int i_fromVersion,
       throw Exception("Unable to update xmDb from 12: " + e.getMsg());
     }
 
+  case 13:
+    try {
+      simpleSql("ALTER TABLE weblevels ADD COLUMN crappy DEFAULT 0;");
+      simpleSql("CREATE INDEX weblevels_crappy_idx1 ON weblevels(crappy);");
+      updateXmDbVersion(14);
+    } catch(Exception &e) {
+      throw Exception("Unable to update xmDb from 13: " + e.getMsg());
+    }
+
+  case 14:
+    try {
+      simpleSql("CREATE INDEX webhighscores_finishTime_idx1 ON webhighscores(finishTime);");
+      updateXmDbVersion(15);
+    } catch(Exception &e) {
+      throw Exception("Unable to update xmDb from 14: " + e.getMsg());
+    }
+
+  case 15:
+    try {
+      simpleSql("CREATE TABLE levels_blacklist(id_profile, id_level, PRIMARY KEY(id_profile, id_level));");
+      updateXmDbVersion(16);
+    } catch(Exception &e) {
+      throw Exception("Unable to update xmDb from 15: " + e.getMsg());
+    }
+
+  case 16:
+    try {
+      simpleSql("CREATE INDEX webhighscores_id_level_idx1 ON webhighscores(id_level);");
+      updateXmDbVersion(17);
+    } catch(Exception &e) {
+      throw Exception("Unable to update xmDb from 16: " + e.getMsg());
+    }
+
+  case 17:
+    try {
+      // fix stats_profiles_levels due to old old old xmoto versions
+      fixStatsProfilesLevelsNbCompleted();
+      updateXmDbVersion(18);
+    } catch(Exception &e) {
+      throw Exception("Unable to update xmDb from 17: " + e.getMsg());
+    }
+
+  case 18: // from float to int storage for time
+    try {
+      m_requiredReplaysUpdateAfterInit = true;
+      simpleSql("DELETE from webhighscores;");
+      simpleSql("UPDATE profile_completedLevels SET finishTime=finishTime*100;");
+      simpleSql("UPDATE stats_profiles_levels   SET playedTime=playedTime*100;");
+      updateXmDbVersion(19);
+    } catch(Exception &e) {
+      throw Exception("Unable to update xmDb from 18: " + e.getMsg());
+    }
+
+  case 19:
+    try {
+      simpleSql("ALTER TABLE weblevels ADD COLUMN children_compliant DEFAULT 1;");
+      simpleSql("CREATE INDEX weblevels_children_compliant_idx1 ON weblevels(children_compliant);");
+      updateXmDbVersion(20);
+    } catch(Exception &e) {
+      throw Exception("Unable to update xmDb from 19: " + e.getMsg());
+    }
+
     // next
   }
 }
@@ -416,7 +508,7 @@ void xmDatabase::simpleSql(const std::string& i_sql) {
   char *errMsg;
   std::string v_errMsg;
 
-  //vapp::Log(i_sql.c_str());
+  //Logger::Log(i_sql.c_str());
   //printf("%s\n", i_sql.c_str());
 
   if(sqlite3_exec(m_db,
@@ -429,32 +521,35 @@ void xmDatabase::simpleSql(const std::string& i_sql) {
   }
 }
 
-void xmDatabase::debugResult(char **i_result, int ncolumn, int nrow) {
-  for(int i=0; i<ncolumn*(nrow+1); i++) {
+void xmDatabase::debugResult(char **i_result, int ncolumn, unsigned int nrow) {
+  for(unsigned int i=0; i<ncolumn*(nrow+1); i++) {
     printf("result[%i] = %s\n", i, i_result[i]);
   }
 }
 
-char* xmDatabase::getResult(char **i_result, int ncolumn, int i_row, int i_column) {
+char* xmDatabase::getResult(char **i_result, int ncolumn, unsigned int i_row, int i_column) {
   return i_result[ncolumn*(i_row+1) + i_column];
 }
 
-char** xmDatabase::readDB(const std::string& i_sql, int &i_nrow) {
+char** xmDatabase::readDB(const std::string& i_sql, unsigned int &i_nrow) {
   char **v_result;
   int ncolumn;
   char *errMsg;
   std::string v_errMsg;
-  
+  int v_nrow;
+
   //printf("%s\n", i_sql.c_str());
 
   if(sqlite3_get_table(m_db,
 		       i_sql.c_str(),
-		       &v_result, &i_nrow, &ncolumn, &errMsg)
+		       &v_result, &v_nrow, &ncolumn, &errMsg)
      != SQLITE_OK) {
     v_errMsg = errMsg;
     sqlite3_free(errMsg);
     throw Exception("xmDb: " + v_errMsg);
   }
+  i_nrow = (unsigned int) v_nrow;
+
   return v_result;
 }
 
@@ -465,7 +560,7 @@ void xmDatabase::read_DB_free(char **i_result) {
 std::string xmDatabase::protectString(const std::string& i_str) {
   std::string v_res;
 
-  for(int i=0; i<i_str.length(); i++) {
+  for(unsigned int i=0; i<i_str.length(); i++) {
     switch(i_str[i]) {
     case '"':
       v_res.append("\"\"");
@@ -488,6 +583,16 @@ void xmDatabase::createUserFunctions() {
 			     user_xm_lvlUpdatedToTxt, NULL, NULL) != SQLITE_OK) {
     throw Exception("xmDatabase::createUserFunctions() failed !");
   }
+
+  if(sqlite3_create_function(m_db, "xm_userCrappy", 1, SQLITE_ANY, NULL,
+			     user_xm_userCrappy, NULL, NULL) != SQLITE_OK) {
+    throw Exception("xmDatabase::createUserFunctions() failed !");
+  }
+
+  if(sqlite3_create_function(m_db, "xm_userChildrenCompliant", 1, SQLITE_ANY, NULL,
+			     user_xm_userChildrenCompliant, NULL, NULL) != SQLITE_OK) {
+    throw Exception("xmDatabase::createUserFunctions() failed !");
+  }
 }
 
 void xmDatabase::user_xm_floord(sqlite3_context* i_context, int i_nArgs, sqlite3_value** i_values) {
@@ -511,3 +616,25 @@ void xmDatabase::user_xm_lvlUpdatedToTxt(sqlite3_context* i_context, int i_nArgs
   v_value = sqlite3_value_int(i_values[0]);
   sqlite3_result_text(i_context, v_value == 0 ? GAMETEXT_NEW : GAMETEXT_UPDATED, -1, SQLITE_TRANSIENT);
 }
+
+void xmDatabase::user_xm_userCrappy(sqlite3_context* i_context, int i_nArgs, sqlite3_value** i_values) {
+  int v_value;
+
+  if(i_nArgs != 1) {
+    throw Exception("user_xm_userCrappy failed !");
+  }
+
+  v_value = sqlite3_value_int(i_values[0]);
+  sqlite3_result_int(i_context, XMSession::instance()->useCrappyPack() ? v_value : 0);
+}
+
+void xmDatabase::user_xm_userChildrenCompliant(sqlite3_context* i_context, int i_nArgs, sqlite3_value** i_values) {
+  int v_value;
+
+  if(i_nArgs != 1) {
+    throw Exception("user_xm_userChildrenCompliant failed !");
+  }
+
+  v_value = sqlite3_value_int(i_values[0]);
+  sqlite3_result_int(i_context, XMSession::instance()->useChildrenCompliant() ? v_value : 1);
+}
