@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -169,17 +168,20 @@ int intersectLineCircle2f(const Vector2f &Cp,float Cr,const Vector2f &A0,
   if(A1.almostEqual(A0))
     return 0;
 
-  float rl = rd.normalize();
+	/*
+		IMPORTANT: keep double for precision !!! otherwise it sucks on some levels
+	*/
+  double rl = rd.normalize();
   Vector2f v = A0 - Cp;
-  float b = -v.dot(rd);
-  float det = (b * b) - v.dot(v) + Cr*Cr;
+  double b = -v.dot(rd);
+  double det = (b * b) - v.dot(v) + Cr*Cr;
   if(det<0 && det>-0.0001f)
     det=0;
 
   if(det >= 0) {
     det = sqrt(det);
-    float i1 = b - det;
-    float i2 = b + det;
+    double i1 = b - det;
+    double i2 = b + det;
       
     if(i1>-0.0001f && i1<rl+0.0001f && i2>-0.0001f && i2<rl+0.0001f) {
       Res1 = A0 + rd*i1;
@@ -287,4 +289,58 @@ bool circleTouchCircle2f(const Vector2f &Cp1,float Cr1,const Vector2f &Cp2,float
   return (d < Cr1+Cr2);
 }
 
+void intersectLineLine2fCramer(Vector2f& A1, Vector2f& A2, Vector2f& B1, Vector2f& B2, Vector2f& contactPoint)
+{
+  // equations of lines (A1, A2) and (B1, B2)
+  // a*x + b*y = e
+  // c*x + d*y = f
+  float a,b,c, d,e,f;
+  a = A1.y - A2.y;
+  b = A2.x - A1.x;
+  e = a*A1.x + b*A1.y;
 
+  c = B1.y - B2.y;
+  d = B2.x - B1.x;
+  f = c*B2.x + d*B2.y;
+
+  // calculate intersection point with Cramer's formula
+  float divider = a*d - b*c;
+  contactPoint = Vector2f((e*d - b*f) / divider, (a*f - e*c) / divider);
+}
+
+void calculatePointOnNormal(Vector2f& A1, Vector2f& B1, float length, bool inside, Vector2f& A2, Vector2f& B2)
+{
+  Vector2f N(-B1.y+A1.y, B1.x-A1.x);
+  float t = length / sqrt(N.x*N.x + N.y*N.y);
+  if(inside == true){
+    t = -t;
+  }
+  A2 = Vector2f(A1.x + t * N.x, A1.y + t * N.y);
+  B2 = Vector2f(B1.x + t * N.x, B1.y + t * N.y);
+}
+
+void calculatePointOnVector(Vector2f& A1, Vector2f& A2, float length, Vector2f& newA2)
+{
+  Vector2f A(A2.x-A1.x, A2.y-A1.y);
+  float t = length / sqrt(A.x*A.x + A.y*A.y);
+  newA2 = Vector2f(A1.x + t * A.x, A1.y + t * A.y);
+}
+
+float interpolation_cubic(float i_a, float i_b, float i_c, float i_d, float t) {
+  double t2 = t*t;
+  double x0,x1,x2,x3;
+  float v_res;
+
+  x0 = i_d - i_c - i_a + i_b;
+  x1 = i_a - i_b - x0;
+  x2 = i_c - i_a;
+  x3 = i_b;
+  v_res = x0*t*t2 + x1*t2 + x2*t + x3;
+
+  return v_res;
+}
+
+Vector2f interpolation_cubic(Vector2f i_a, Vector2f i_b, Vector2f i_c, Vector2f i_d, float t) {
+  return Vector2f(interpolation_cubic(i_a.x, i_b.x, i_c.x, i_d.x, t),
+		  interpolation_cubic(i_a.y, i_b.y, i_c.y, i_d.y, t));
+}
