@@ -29,7 +29,8 @@ class utf8 {
   static int byte_size_from_utf8_first(unsigned char ch);
   static std::vector<std::string> split_utf8_string(const std::string &src);
   static std::string txt2vertical(const std::string& i_str);
-  static std::string getNextChar(const std::string &src, int& io_pos);
+  static std::string getNextChar(const std::string &src, unsigned int& io_pos);
+  static void getNextChar(const std::string &src, unsigned int& io_pos, std::string& o_char);
 };
 
 #endif
