@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -126,9 +125,11 @@ int tim_png_load(tim_session_t *pSession,tim_image_t **ppImage,tim_image_info_t
   if(setjmp(png_jmpbuf(PngPtr))) {
     png_destroy_read_struct(&PngPtr,&InfoPtr,&EndInfo);
     tim_close(pSession,Env.pvFile);
-    if(*ppImage) tim_destroy_image(*ppImage);
-    *ppImage=NULL;
-    if(pRowPointers) tim_free(pSession,pRowPointers);
+    if(ppImage != NULL && *ppImage != NULL) {
+      tim_destroy_image(*ppImage);
+      *ppImage=NULL;
+    }
+    if(pRowPointers != NULL) tim_free(pSession,pRowPointers);
     return TIM_RV_ERR_LIBRARY;
   }
 	
