@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -21,10 +20,18 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include "BikeController.h"
 
+BikeController::BikeController()
+{
+  m_brokenBreaks = false;
+  stopContols();
+}
+
 void BikeController::stopContols() {
-  m_drive     = 0.0;      
-  m_pull      = 0.0;  
-  m_changeDir = false;
+  m_drive      = 0.0;      
+  m_pull       = 0.0;  
+  m_changeDir  = false;
+  m_throttle   = 0.0;
+  m_break      = 0.0;
 }
 
 float BikeController::Drive() const {
@@ -39,10 +46,45 @@ bool BikeController::ChangeDir() const {
   return m_changeDir;
 }
 
-void BikeController::setDrive(float i_drive) {
+void BikeController::setDrive(float i_drive)
+{
   m_drive = i_drive;
 }
 
+void BikeController::setThrottle(float i_throttle)
+{
+  m_throttle = i_throttle;
+  if(m_throttle > 0.0f){
+    m_drive = m_throttle;
+  }
+  else if(m_throttle == 0.0f){
+    if(m_break != 0.0f){
+      m_drive = -m_break;
+    } else {
+      m_drive = 0.0f;
+    }
+  }
+}
+
+void BikeController::setBreak(float i_break)
+{
+  if(m_brokenBreaks) {
+    return;
+  }
+
+  m_break = i_break;
+  if(m_break > 0.0f){
+    m_drive = -m_break;
+  }
+  else if(m_break == 0.0f){
+    if(m_throttle != 0.0f){
+      m_drive = m_throttle;
+    } else {
+      m_drive = 0.0f;
+    }
+  }
+}
+
 void BikeController::setPull(float i_pull) {
   m_pull = i_pull;
 }
@@ -50,3 +92,8 @@ void BikeController::setPull(float i_pull) {
 void BikeController::setChangeDir(bool i_changeDir) {
   m_changeDir = i_changeDir;
 }
+
+void BikeController::breakBreaks() {
+  m_break = 0.0;
+  m_brokenBreaks = true;
+}
