@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -20,9 +19,19 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 =============================================================================*/
 
 #include "Entity.h"
+#include "VXml.h"
+#include "PhysSettings.h"
+#include "VFileIO.h"
 
-#include "../VXml.h"
-#include "../PhysSettings.h"
+// don't excceed this number of particles to not reduce significantly the fps
+#define PARTICLESSOURCE_TOTAL_MAX_PARTICLES 5000
+#define ENTITY_DEFAULT_SPRITE_NAME ""
+#define ENTITY_DEFAULT_SIZE        1.0
+#define ENTITY_DEFAULT_Z           -1.0
+#define PARTICLES_SOURCE_SMOKE_TIME_INCREMENT  5
+#define PARTICLES_SOURCE_STAR_TIME_INCREMENT   2
+#define PARTICLES_SOURCE_FIRE_TIME_INCREMENT   4
+#define PARTICLES_SOURCE_DEBRIS_TIME_INCREMENT 2
 
 Entity::Entity(const std::string& i_id) {
   m_id          = i_id;
@@ -171,7 +180,7 @@ void Entity::setAlive(bool alive) {
 }
 
 
-bool Entity::updateToTime(float i_time, Vector2f i_gravity) {
+bool Entity::updateToTime(int i_time, Vector2f i_gravity) {
   return false;
 }
 
@@ -191,10 +200,17 @@ AABB& Entity::getAABB()
   return m_BBox;
 }
 
+/* static members */
+int ParticlesSource::m_totalOfParticles = 0;
+bool ParticlesSource::m_allowParticleGeneration = true;
 
-ParticlesSource::ParticlesSource(const std::string& i_id, float i_particleTime_increment)
+void ParticlesSource::setAllowParticleGeneration(bool i_value) {
+  m_allowParticleGeneration = i_value;
+}
+
+ParticlesSource::ParticlesSource(const std::string& i_id, int i_particleTime_increment)
   : Entity(i_id) {
-  m_lastParticleTime       = 0.0;
+  m_lastParticleTime       = 0;
   m_particleTime_increment = i_particleTime_increment;
 }
 
@@ -204,7 +220,7 @@ ParticlesSource::~ParticlesSource() {
 
 void ParticlesSource::loadToPlay() {
   Entity::loadToPlay();
-  m_lastParticleTime = 0.0;
+  m_lastParticleTime = 0;
 } 
 
 void ParticlesSource::unloadToPlay() {
@@ -213,7 +229,7 @@ void ParticlesSource::unloadToPlay() {
   deleteParticles();
 }
 
-bool ParticlesSource::updateToTime(float i_time, Vector2f i_gravity) {
+bool ParticlesSource::updateToTime(int i_time, Vector2f i_gravity) {
   unsigned int i;
 
   if(i_time > m_lastParticleTime + m_particleTime_increment) {  
@@ -222,6 +238,7 @@ bool ParticlesSource::updateToTime(float i_time, Vector2f i_gravity) {
       if(i_time > m_particles[i]->KillTime()) {
 	delete m_particles[i];
 	m_particles.erase(m_particles.begin() + i);
+	m_totalOfParticles--;
       } else {
 	m_particles[i]->updateToTime(i_time, i_gravity);
 	i++;
@@ -270,14 +287,14 @@ ParticlesSourceDebris::ParticlesSourceDebris(const std::string& i_id)
 ParticlesSourceDebris::~ParticlesSourceDebris() {
 }
 
-bool ParticlesSourceSmoke::updateToTime(float i_time, Vector2f i_gravity) {
+bool ParticlesSourceSmoke::updateToTime(int i_time, Vector2f i_gravity) {
   if(ParticlesSource::updateToTime(i_time, i_gravity)) {
     /* Generate smoke */
     if(randomNum(0,5) < 1) {
       if(randomNum(0,1) < 0.5) {
-	      addParticle(Vector2f(randomNum(-0.6,0.6), randomNum(0.2,0.6)), i_time + 10.0, "Smoke1");
+	addParticle(Vector2f(randomNum(-0.6,0.6), randomNum(0.2,0.6)), i_time + 1000, "Smoke1");
       } else {
-	      addParticle(Vector2f(randomNum(-0.6,0.6), randomNum(0.2,0.6)), i_time + 10.0, "Smoke2");
+	addParticle(Vector2f(randomNum(-0.6,0.6), randomNum(0.2,0.6)), i_time + 1000, "Smoke2");
       }
     }
     return true;
@@ -285,7 +302,7 @@ bool ParticlesSourceSmoke::updateToTime(float i_time, Vector2f i_gravity) {
   return false;
 }
 
-bool SmokeParticle::updateToTime(float i_time, Vector2f i_gravity) {
+bool SmokeParticle::updateToTime(int i_time, Vector2f i_gravity) {
   EntityParticle::updateToTime(i_time, i_gravity);
 
   float v_timeStep = 0.025;
@@ -310,10 +327,10 @@ bool SmokeParticle::updateToTime(float i_time, Vector2f i_gravity) {
   return false;
 }
 
-bool FireParticle::updateToTime(float i_time, Vector2f i_gravity) {
+bool FireParticle::updateToTime(int i_time, Vector2f i_gravity) {
   EntityParticle::updateToTime(i_time, i_gravity);
 
-  float v_timeStep = 0.035;
+  float v_timeStep = 0.040;
   TColor v_color(Color());
 
   int v_g = Color().Green() - (int)(randomNum(190,210) * v_timeStep);
@@ -330,31 +347,29 @@ bool FireParticle::updateToTime(float i_time, Vector2f i_gravity) {
     m_killTime = i_time;
   }
       
-  m_velocity.x = sin((i_time + m_fireSeed) * randomNum(5,15)) * 0.8f
+  m_velocity.x = sin((i_time + m_fireSeed) * randomNum(5,15)) * 0.004f
     +
-    sin((i_time - m_fireSeed) * 10) * 0.3;
-  m_acceleration.y = 2.0;
+    sin((i_time - m_fireSeed) * 0.1) * 0.3;
+  m_acceleration.y = 3.0;
 
   return false;
 }
 
-bool ParticlesSourceFire::updateToTime(float i_time, Vector2f i_gravity) {
+bool ParticlesSourceFire::updateToTime(int i_time, Vector2f i_gravity) {
   if(ParticlesSource::updateToTime(i_time, i_gravity)) {
     /* Generate fire */
-    for(int k=0;k<3;k++) {
-      /* maximum 10s for a fire particule, but it can be destroyed before */
-      ParticlesSource::addParticle(Vector2f(randomNum(-1,1),randomNum(0.1,0.3)), i_time + 10.0);
-    }
+    /* maximum 5s for a fire particule, but it can be destroyed before */
+    ParticlesSource::addParticle(Vector2f(randomNum(-1,1),randomNum(0.1,0.3)), i_time + 500);
     return true;
   }
   return false;
 }
 
-bool ParticlesSourceDebris::updateToTime(float i_time, Vector2f i_gravity) {
+bool ParticlesSourceDebris::updateToTime(int i_time, Vector2f i_gravity) {
   return ParticlesSource::updateToTime(i_time, i_gravity);
 }
 
-bool EntityParticle::updateToTime(float i_time, Vector2f i_gravity) {
+bool EntityParticle::updateToTime(int i_time, Vector2f i_gravity) {
   float v_timeStep = 0.025;
 
   m_velocity += m_acceleration * v_timeStep;
@@ -365,7 +380,7 @@ bool EntityParticle::updateToTime(float i_time, Vector2f i_gravity) {
   return true;
 }
 
-float EntityParticle::KillTime() const {
+int EntityParticle::KillTime() const {
   return m_killTime;
 }
 
@@ -374,7 +389,7 @@ void Entity::setDynamicPosition(const Vector2f& i_dynamicPosition) {
   m_isBBoxDirty = true;
 }
 
-EntityParticle::EntityParticle(const Vector2f& i_position, const Vector2f i_velocity, float i_killTime)
+EntityParticle::EntityParticle(const Vector2f& i_position, const Vector2f i_velocity, int i_killTime)
 : Entity("") {
   setDynamicPosition(i_position);
   m_velocity 	 = i_velocity;
@@ -390,25 +405,25 @@ EntityParticle::EntityParticle(const Vector2f& i_position, const Vector2f i_velo
 EntityParticle::~EntityParticle() {
 }
 
-void Entity::saveXml(vapp::FileHandle *i_pfh) {
-  vapp::FS::writeLineF(i_pfh,"\t<entity id=\"%s\" typeid=\"%s\">", Id().c_str(), Entity::SpecialityToStr(Speciality()).c_str());
-  vapp::FS::writeLineF(i_pfh,"\t\t<size r=\"%f\"/>",Size());
-  vapp::FS::writeLineF(i_pfh,"\t\t<position x=\"%f\" y=\"%f\"/>", InitialPosition().x, InitialPosition().y);      
+void Entity::saveXml(FileHandle *i_pfh) {
+  FS::writeLineF(i_pfh,"\t<entity id=\"%s\" typeid=\"%s\">", Id().c_str(), Entity::SpecialityToStr(Speciality()).c_str());
+  FS::writeLineF(i_pfh,"\t\t<size r=\"%f\"/>",Size());
+  FS::writeLineF(i_pfh,"\t\t<position x=\"%f\" y=\"%f\"/>", InitialPosition().x, InitialPosition().y);      
 
-  vapp::FS::writeLineF(i_pfh,"\t\t<param name=\"%s\" value=\"%.2f\"/>",
+  FS::writeLineF(i_pfh,"\t\t<param name=\"%s\" value=\"%.2f\"/>",
                        "z", Z());
 
   if(Speciality() == ET_NONE) {
-    vapp::FS::writeLineF(i_pfh,"\t\t<param name=\"%s\" value=\"%.2f\"/>",
+    FS::writeLineF(i_pfh,"\t\t<param name=\"%s\" value=\"%.2f\"/>",
 			 "name", SpriteName().c_str());
   }
 
   if(Speciality() == ET_PARTICLES_SOURCE) {
-    vapp::FS::writeLineF(i_pfh,"\t\t<param name=\"%s\" value=\"%.2f\"/>",
+    FS::writeLineF(i_pfh,"\t\t<param name=\"%s\" value=\"%.2f\"/>",
 			 "type", SpriteName().c_str());
   }
 
-  vapp::FS::writeLineF(i_pfh,"\t</entity>");
+  FS::writeLineF(i_pfh,"\t</entity>");
 }
 
 EntitySpeciality Entity::SpecialityFromStr(std::string i_typeStr) {
@@ -458,29 +473,29 @@ Entity* Entity::readFromXml(TiXmlElement *pElem) {
   std::string v_typeName;
 
   /* read xml information */
-  v_id         = vapp::XML::getOption(pElem,"id");
-  v_typeId     = vapp::XML::getOption(pElem,"typeid");
+  v_id         = XML::getOption(pElem,"id");
+  v_typeId     = XML::getOption(pElem,"typeid");
   v_speciality = Entity::SpecialityFromStr(v_typeId);
   TiXmlElement *pPosElem = pElem->FirstChildElement("position");
   if(pPosElem != NULL) {
-    v_position.x = atof(vapp::XML::getOption(pPosElem,"x","0").c_str());
-    v_position.y = atof(vapp::XML::getOption(pPosElem,"y","0").c_str());
-    v_angle      = atof(vapp::XML::getOption(pPosElem,"angle","-1.0").c_str());
-    v_reversed   = vapp::XML::getOption(pPosElem,"reversed","false") == "true";
+    v_position.x = atof(XML::getOption(pPosElem,"x","0").c_str());
+    v_position.y = atof(XML::getOption(pPosElem,"y","0").c_str());
+    v_angle      = atof(XML::getOption(pPosElem,"angle","-1.0").c_str());
+    v_reversed   = XML::getOption(pPosElem,"reversed","false") == "true";
   }
   TiXmlElement *pSizeElem = pElem->FirstChildElement("size");
   if(pSizeElem != NULL) {
-    v_size = (atof(vapp::XML::getOption(pSizeElem,"r","0.2").c_str()));
-    v_width = atof(vapp::XML::getOption(pSizeElem,"width","-1.0").c_str());
-    v_height = atof(vapp::XML::getOption(pSizeElem,"height","-1.0").c_str());
+    v_size = (atof(XML::getOption(pSizeElem,"r","0.2").c_str()));
+    v_width = atof(XML::getOption(pSizeElem,"width","-1.0").c_str());
+    v_height = atof(XML::getOption(pSizeElem,"height","-1.0").c_str());
   }
   /* Get parameters */
   std::string v_paramName;
   std::string v_paramValue;
   for(TiXmlElement *pParamElem = pElem->FirstChildElement("param"); pParamElem!=NULL;
       pParamElem=pParamElem->NextSiblingElement("param")) {   
-    v_paramName  = vapp::XML::getOption(pParamElem,"name");
-    v_paramValue = vapp::XML::getOption(pParamElem,"value");
+    v_paramName  = XML::getOption(pParamElem,"name");
+    v_paramValue = XML::getOption(pParamElem,"value");
     if(v_paramName == "z") {
       v_z = (atof(v_paramValue.c_str()));
     } else if(v_paramName == "name") {
@@ -537,43 +552,43 @@ Entity* Entity::readFromXml(TiXmlElement *pElem) {
   return v_entity;
 }
 
-void Entity::saveBinary(vapp::FileHandle *i_pfh) {
-  vapp::FS::writeString(i_pfh,   Id());
-  vapp::FS::writeString(i_pfh,   Entity::SpecialityToStr(Speciality()));
-  vapp::FS::writeFloat_LE(i_pfh, Size());
-  vapp::FS::writeFloat_LE(i_pfh, Width());       
-  vapp::FS::writeFloat_LE(i_pfh, Height()); 
-  vapp::FS::writeFloat_LE(i_pfh, InitialPosition().x);
-  vapp::FS::writeFloat_LE(i_pfh, InitialPosition().y);
-  vapp::FS::writeFloat_LE(i_pfh, DrawAngle());
-  vapp::FS::writeBool(i_pfh,  DrawReversed());
+void Entity::saveBinary(FileHandle *i_pfh) {
+  FS::writeString(i_pfh,   Id());
+  FS::writeString(i_pfh,   Entity::SpecialityToStr(Speciality()));
+  FS::writeFloat_LE(i_pfh, Size());
+  FS::writeFloat_LE(i_pfh, Width());       
+  FS::writeFloat_LE(i_pfh, Height()); 
+  FS::writeFloat_LE(i_pfh, InitialPosition().x);
+  FS::writeFloat_LE(i_pfh, InitialPosition().y);
+  FS::writeFloat_LE(i_pfh, DrawAngle());
+  FS::writeBool(i_pfh,  DrawReversed());
   
   switch(Speciality()) {
   case ET_NONE:
   case ET_PARTICLES_SOURCE:
-    vapp::FS::writeByte(i_pfh, 0x02);
+    FS::writeByte(i_pfh, 0x02);
     break;
   default:
-    vapp::FS::writeByte(i_pfh, 0x01);
+    FS::writeByte(i_pfh, 0x01);
   }
 
   std::ostringstream v_z;
   v_z << Z();
-  vapp::FS::writeString(i_pfh, "z");
-  vapp::FS::writeString(i_pfh, v_z.str());
+  FS::writeString(i_pfh, "z");
+  FS::writeString(i_pfh, v_z.str());
 
   if(Speciality() == ET_NONE) {
-    vapp::FS::writeString(i_pfh, "name");
-    vapp::FS::writeString(i_pfh, SpriteName());
+    FS::writeString(i_pfh, "name");
+    FS::writeString(i_pfh, SpriteName());
   }
 
   if(Speciality() == ET_PARTICLES_SOURCE) {
-    vapp::FS::writeString(i_pfh, "type");
-    vapp::FS::writeString(i_pfh, SpriteName());
+    FS::writeString(i_pfh, "type");
+    FS::writeString(i_pfh, SpriteName());
   }
 }
 
-Entity* Entity::readFromBinary(vapp::FileHandle *i_pfh) {
+Entity* Entity::readFromBinary(FileHandle *i_pfh) {
   std::string v_id;
   std::string v_typeId;
   EntitySpeciality  v_speciality;
@@ -588,22 +603,22 @@ Entity* Entity::readFromBinary(vapp::FileHandle *i_pfh) {
   std::string v_typeName;
 
   /* read values */
-  v_id         = vapp::FS::readString(i_pfh);
-  v_typeId     = vapp::FS::readString(i_pfh);
+  v_id         = FS::readString(i_pfh);
+  v_typeId     = FS::readString(i_pfh);
   v_speciality = Entity::SpecialityFromStr(v_typeId);
-  v_size       = vapp::FS::readFloat_LE(i_pfh);
-  v_width      = vapp::FS::readFloat_LE(i_pfh);
-  v_height     = vapp::FS::readFloat_LE(i_pfh);
-  v_position.x = vapp::FS::readFloat_LE(i_pfh);
-  v_position.y = vapp::FS::readFloat_LE(i_pfh);
-  v_angle      = vapp::FS::readFloat_LE(i_pfh);
-  v_reversed   = vapp::FS::readBool(i_pfh);
+  v_size       = FS::readFloat_LE(i_pfh);
+  v_width      = FS::readFloat_LE(i_pfh);
+  v_height     = FS::readFloat_LE(i_pfh);
+  v_position.x = FS::readFloat_LE(i_pfh);
+  v_position.y = FS::readFloat_LE(i_pfh);
+  v_angle      = FS::readFloat_LE(i_pfh);
+  v_reversed   = FS::readBool(i_pfh);
   std::string v_paramName;
   std::string v_paramValue;
-  int nNumParams = vapp::FS::readByte(i_pfh);
+  int nNumParams = FS::readByte(i_pfh);
   for(int j=0;j<nNumParams;j++) {
-    v_paramName  = vapp::FS::readString(i_pfh);
-    v_paramValue = vapp::FS::readString(i_pfh);
+    v_paramName  = FS::readString(i_pfh);
+    v_paramValue = FS::readString(i_pfh);
 
     if(v_paramName == "z") {
       v_z = atof(v_paramValue.c_str());
@@ -666,6 +681,7 @@ void ParticlesSource::deleteParticles() {
   for(unsigned int i=0; i<m_particles.size(); i++) {
     delete m_particles[i];
   }
+  m_totalOfParticles -= m_particles.size();
   m_particles.clear();
 }
 
@@ -681,15 +697,18 @@ float EntityParticle::Angle() const {
   return m_ang;
 }
 
-void ParticlesSource::addParticle(Vector2f i_velocity, float i_killTime) {
+void ParticlesSource::addParticle(Vector2f i_velocity, int i_killTime) {
   addParticle(i_velocity, i_killTime, SpriteName());
 }
 
-void ParticlesSourceStar::addParticle(Vector2f i_velocity, float i_killTime, std::string i_spriteName) {
+void ParticlesSourceStar::addParticle(Vector2f i_velocity, int i_killTime, std::string i_spriteName) {
+  if(hasReachedMaxParticles()) return;
+
   m_particles.push_back(new StarParticle(DynamicPosition(), i_killTime, SpriteName()));
+  m_totalOfParticles++;
 }
 
-StarParticle::StarParticle(const Vector2f& i_position, float i_killTime, std::string i_spriteName)
+StarParticle::StarParticle(const Vector2f& i_position, int i_killTime, std::string i_spriteName)
   : EntityParticle(i_position, Vector2f(randomNum(-2,2),randomNum(0,2)), i_killTime) {
   m_angVel       = randomNum(-60,60);
   m_acceleration = Vector2f(0,-4);
@@ -699,7 +718,7 @@ StarParticle::StarParticle(const Vector2f& i_position, float i_killTime, std::st
 StarParticle::~StarParticle() {
 }
 
-DebrisParticle::DebrisParticle(const Vector2f& i_position, const Vector2f i_velocity, float i_killTime, std::string i_spriteName)
+DebrisParticle::DebrisParticle(const Vector2f& i_position, const Vector2f i_velocity, int i_killTime, std::string i_spriteName)
   : EntityParticle(i_position, Vector2f(randomNum(-2,2),randomNum(0,2)), i_killTime) {
   m_angVel       = randomNum(-60,60);
   m_acceleration = Vector2f(0,-4);
@@ -714,7 +733,7 @@ DebrisParticle::DebrisParticle(const Vector2f& i_position, const Vector2f i_velo
 DebrisParticle::~DebrisParticle() {
 }
 
-bool DebrisParticle::updateToTime(float i_time, Vector2f i_gravity) {
+bool DebrisParticle::updateToTime(int i_time, Vector2f i_gravity) {
   EntityParticle::updateToTime(i_time, i_gravity);
 
   float v_timeStep = 0.025;
@@ -733,7 +752,7 @@ bool DebrisParticle::updateToTime(float i_time, Vector2f i_gravity) {
   return true;
 }
 
-FireParticle::FireParticle(const Vector2f& i_position, const Vector2f i_velocity, float i_killTime, std::string i_spriteName)
+FireParticle::FireParticle(const Vector2f& i_position, const Vector2f i_velocity, int i_killTime, std::string i_spriteName)
   : EntityParticle(i_position, i_velocity, i_killTime) {
   m_fireSeed = randomNum(0,100);
   setSize(0.17);
@@ -744,7 +763,7 @@ FireParticle::FireParticle(const Vector2f& i_position, const Vector2f i_velocity
 FireParticle::~FireParticle() {
 }
 
-SmokeParticle::SmokeParticle(const Vector2f& i_position, const Vector2f i_velocity, float i_killTime, std::string i_spriteName) 
+SmokeParticle::SmokeParticle(const Vector2f& i_position, const Vector2f i_velocity, int i_killTime, std::string i_spriteName) 
   : EntityParticle(i_position, i_velocity, i_killTime) {
   int cc   = (int) randomNum(0, 50);
   setColor(TColor(cc, cc, cc, 255));
@@ -757,14 +776,27 @@ SmokeParticle::~SmokeParticle() {
 }
 
 
-void ParticlesSourceSmoke::addParticle(Vector2f i_velocity, float i_killTime, std::string i_spriteName) {
+void ParticlesSourceSmoke::addParticle(Vector2f i_velocity, int i_killTime, std::string i_spriteName) {
+  if(hasReachedMaxParticles()) return;
+
   m_particles.push_back(new SmokeParticle(DynamicPosition(), i_velocity, i_killTime, i_spriteName));
+  m_totalOfParticles++;
 }
 
-void ParticlesSourceFire::addParticle(Vector2f i_velocity, float i_killTime, std::string i_spriteName) {
+void ParticlesSourceFire::addParticle(Vector2f i_velocity, int i_killTime, std::string i_spriteName) {
+  if(hasReachedMaxParticles()) return;
+
   m_particles.push_back(new FireParticle(DynamicPosition(), i_velocity, i_killTime, i_spriteName));
+  m_totalOfParticles++;
 }
 
-void ParticlesSourceDebris::addParticle(Vector2f i_velocity, float i_killTime, std::string i_spriteName) {
+void ParticlesSourceDebris::addParticle(Vector2f i_velocity, int i_killTime, std::string i_spriteName) {
+  if(hasReachedMaxParticles()) return;
+
   m_particles.push_back(new DebrisParticle(DynamicPosition(), i_velocity, i_killTime, i_spriteName));
+  m_totalOfParticles++;
+}
+
+bool ParticlesSource::hasReachedMaxParticles() {
+  return m_totalOfParticles >= PARTICLESSOURCE_TOTAL_MAX_PARTICLES || m_allowParticleGeneration == false;
 }
