@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -22,20 +21,14 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #ifndef __ENTITY_H__
 #define __ENTITY_H__
 
-#include "../helpers/VMath.h"
-#include "../helpers/Color.h"
+#include <string>
+#include "helpers/Color.h"
+#include "helpers/VMath.h"
 #include "BasicSceneStructs.h"
-#include "../VFileIO.h"
-
-#define ENTITY_DEFAULT_SPRITE_NAME ""
-#define ENTITY_DEFAULT_SIZE        1.0
-#define ENTITY_DEFAULT_Z           -1.0
-#define PARTICLES_SOURCE_SMOKE_TIME_INCREMENT  0.050
-#define PARTICLES_SOURCE_STAR_TIME_INCREMENT   0.025
-#define PARTICLES_SOURCE_FIRE_TIME_INCREMENT   0.040
-#define PARTICLES_SOURCE_DEBRIS_TIME_INCREMENT 0.025
 
 class EntityParticle;
+class TiXmlElement;
+class FileHandle;
 
 /**
   An entity is an object that the biker can found on his way
@@ -76,17 +69,17 @@ class Entity {
   void setColor(const TColor& i_color);
   void setAlive(bool alive);
 
-  void saveXml(vapp::FileHandle *i_pfh);
-  void saveBinary(vapp::FileHandle *i_pfh);
+  void saveXml(FileHandle *i_pfh);
+  void saveBinary(FileHandle *i_pfh);
   static Entity* readFromXml(TiXmlElement *pElem);
-  static Entity* readFromBinary(vapp::FileHandle *i_pfh);
+  static Entity* readFromBinary(FileHandle *i_pfh);
 
   static EntitySpeciality  SpecialityFromStr(std::string i_typeStr);
   static std::string       SpecialityToStr(EntitySpeciality i_type);
   virtual EntitySpeciality Speciality() const; /* replays only store one property per entity, this is this one */
   void setSpeciality(EntitySpeciality i_speciality);
 
-  virtual bool updateToTime(float i_time, Vector2f i_gravity);
+  virtual bool updateToTime(int i_time, Vector2f i_gravity);
 
   AABB& getAABB();
 
@@ -113,23 +106,29 @@ class Entity {
 
 class ParticlesSource : public Entity {
  public:
-  ParticlesSource(const std::string& i_id, float i_particleTime_increment);
+  ParticlesSource(const std::string& i_id, int i_particleTime_increment);
   virtual ~ParticlesSource();
 
   virtual void loadToPlay();
   virtual void unloadToPlay();
-  virtual bool updateToTime(float i_time, Vector2f i_gravity);
-  void addParticle(Vector2f i_velocity, float i_killTime);
-  virtual void addParticle(Vector2f i_velocity, float i_killTime, std::string i_spriteName) = 0;
+  virtual bool updateToTime(int i_time, Vector2f i_gravity);
+  void addParticle(Vector2f i_velocity, int i_killTime);
+  virtual void addParticle(Vector2f i_velocity, int i_killTime, std::string i_spriteName) = 0;
   std::vector<EntityParticle *> &Particles();
   virtual EntitySpeciality Speciality() const;
 
+  static void setAllowParticleGeneration(bool i_value);
+
  protected:
   std::vector<EntityParticle *> m_particles;
 
+  static int m_totalOfParticles;
+  static bool hasReachedMaxParticles();
+
  private:
-  float       m_lastParticleTime;
-  float       m_particleTime_increment;
+  int       m_lastParticleTime;
+  int       m_particleTime_increment;
+  static bool m_allowParticleGeneration;
 
   void deleteParticles();
 };
@@ -139,8 +138,8 @@ class ParticlesSourceSmoke : public ParticlesSource {
   ParticlesSourceSmoke(const std::string& i_id);
   virtual ~ParticlesSourceSmoke();
 
-  bool updateToTime(float i_time, Vector2f i_gravity);
-  void addParticle(Vector2f i_velocity, float i_killTime, std::string i_spriteName);
+  bool updateToTime(int i_time, Vector2f i_gravity);
+  void addParticle(Vector2f i_velocity, int i_killTime, std::string i_spriteName);
 
  private:
 };
@@ -150,8 +149,8 @@ class ParticlesSourceFire : public ParticlesSource {
   ParticlesSourceFire(const std::string& i_id);
   virtual ~ParticlesSourceFire();
 
-  bool updateToTime(float i_time, Vector2f i_gravity);
-  void addParticle(Vector2f i_velocity, float i_killTime, std::string i_spriteName);
+  bool updateToTime(int i_time, Vector2f i_gravity);
+  void addParticle(Vector2f i_velocity, int i_killTime, std::string i_spriteName);
 
  private:
 };
@@ -161,7 +160,7 @@ class ParticlesSourceStar : public ParticlesSource {
   ParticlesSourceStar(const std::string& i_id);
   virtual ~ParticlesSourceStar();
 
-  void addParticle(Vector2f i_velocity, float i_killTime, std::string i_spriteName);
+  void addParticle(Vector2f i_velocity, int i_killTime, std::string i_spriteName);
 
  private:
 };
@@ -171,9 +170,9 @@ class ParticlesSourceDebris : public ParticlesSource {
   ParticlesSourceDebris(const std::string& i_id);
   virtual ~ParticlesSourceDebris();
 
-  bool updateToTime(float i_time, Vector2f i_gravity);
-  void addParticle(Vector2f i_velocity, float i_killTime);
-  void addParticle(Vector2f i_velocity, float i_killTime, std::string i_spriteName);
+  bool updateToTime(int i_time, Vector2f i_gravity);
+  void addParticle(Vector2f i_velocity, int i_killTime);
+  void addParticle(Vector2f i_velocity, int i_killTime, std::string i_spriteName);
 
  private:
 };
@@ -183,34 +182,34 @@ class ParticlesSourceDebris : public ParticlesSource {
 */
 class EntityParticle : public Entity {
  public:
-  EntityParticle(const Vector2f& i_position, const Vector2f i_velocity, float i_killTime);
+  EntityParticle(const Vector2f& i_position, const Vector2f i_velocity, int i_killTime);
   virtual ~EntityParticle();
 
-  virtual  bool updateToTime(float i_time, Vector2f i_gravity);
-  float    KillTime()  	   const;
+  virtual  bool updateToTime(int i_time, Vector2f i_gravity);
+  int    KillTime()  	   const;
   float    Angle()    	   const;
 
  protected:
     Vector2f m_velocity, m_acceleration; /* Position, velocity, and acceleration */
     float    m_ang, m_angVel, m_angAcc;  /* Angular version of the above */
-    float    m_killTime;
+    int    m_killTime;
 };
 
 class SmokeParticle : public EntityParticle {
  public:
-  SmokeParticle(const Vector2f& i_position, const Vector2f i_velocity, float i_killTime, std::string i_spriteName);
+  SmokeParticle(const Vector2f& i_position, const Vector2f i_velocity, int i_killTime, std::string i_spriteName);
   virtual ~SmokeParticle();
-  virtual bool updateToTime(float i_time, Vector2f i_gravity);
+  virtual bool updateToTime(int i_time, Vector2f i_gravity);
 
  private:
 };
 
 class FireParticle : public EntityParticle {
  public:
-  FireParticle(const Vector2f& i_position, const Vector2f i_velocity, float i_killTime, std::string i_spriteName);
+  FireParticle(const Vector2f& i_position, const Vector2f i_velocity, int i_killTime, std::string i_spriteName);
   virtual ~FireParticle();
 
-  virtual bool updateToTime(float i_time, Vector2f i_gravity);
+  virtual bool updateToTime(int i_time, Vector2f i_gravity);
 
  private:
   float m_fireSeed;
@@ -218,7 +217,7 @@ class FireParticle : public EntityParticle {
 
 class StarParticle : public EntityParticle {
  public:
-  StarParticle(const Vector2f& i_position, float i_killTime, std::string i_spriteName);
+  StarParticle(const Vector2f& i_position, int i_killTime, std::string i_spriteName);
   virtual ~StarParticle();
 
  private:
@@ -226,10 +225,10 @@ class StarParticle : public EntityParticle {
 
 class DebrisParticle : public EntityParticle {
  public:
-  DebrisParticle(const Vector2f& i_position, const Vector2f i_velocity, float i_killTime, std::string i_spriteName);
+  DebrisParticle(const Vector2f& i_position, const Vector2f i_velocity, int i_killTime, std::string i_spriteName);
   virtual ~DebrisParticle();
 
-  virtual bool updateToTime(float i_time, Vector2f i_gravity);
+  virtual bool updateToTime(int i_time, Vector2f i_gravity);
 
  private:
 };
