@@ -1,6 +1,5 @@
 /*=============================================================================
 XMOTO
-Copyright (C) 2005-2006 Rasmus Neckelmann (neckelmann@gmail.com)
 
 This file is part of XMOTO.
 
@@ -22,21 +21,19 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #ifndef __LEVELSRC_H__
 #define __LEVELSRC_H__
 
-#include "../VApp.h"
-#include "../VXml.h"
-#include "Scene.h"
-#include "Block.h"
-#include "Zone.h"
-#include "Entity.h"
+#include <string>
 #include "BasicSceneStructs.h"
-#include "SkyApparence.h"
+#include "helpers/VMath.h"
 
 class Block;
 class Entity;
-namespace vapp {
-  class MotoGame;
-}
+class MotoGame;
 class xmDatabase;
+class FileHandle;
+class SkyApparence;
+class Zone;
+class CollisionSystem;
+class XMLDocument;
 
 /*===========================================================================
   Level source object - holds all stored information about a level
@@ -49,8 +46,8 @@ class Level {
   bool loadReducedFromFile();
   void loadFullyFromFile();
   bool isFullyLoaded() const;
-  void exportBinaryHeader(vapp::FileHandle *pfh);
-  void importBinaryHeader(vapp::FileHandle *pfh);
+  void exportBinaryHeader(FileHandle *pfh);
+  void importBinaryHeader(FileHandle *pfh);
   void importHeader(const std::string& i_id,
 		    const std::string& i_checkSum,
 		    const std::string& i_pack,
@@ -86,7 +83,7 @@ class Level {
   float TopLimit()          const;
   float BottomLimit()       const;
   Vector2f PlayerStart()    const;
-  const SkyApparence& Sky()        const;
+  const SkyApparence* Sky()        const;
   void setLimits(float v_leftLimit, float v_rightLimit, float v_topLimit, float v_bottomLimit);
 
   std::string FileName() const;
@@ -94,17 +91,17 @@ class Level {
   std::string Checksum() const;
   bool isScripted() const;
 
-  Block&  getBlockById(const std::string& i_id);
-  Entity& getEntityById(const std::string& i_id);
-  Entity& getStartEntity();
-  Zone&   getZoneById(const std::string& i_id);
+  Block*  getBlockById(const std::string& i_id);
+  Entity* getEntityById(const std::string& i_id);
+  Entity* getStartEntity();
+  Zone*   getZoneById(const std::string& i_id);
 
   void setId(const std::string& i_id);
   void setName(const std::string& i_name);
   void setDescription(const std::string& i_description);
   void setDate(const std::string& i_date);
   void setAuthor(const std::string& i_author);
-  void setCollisionSystem(vapp::CollisionSystem* p_CollisionSystem);
+  void setCollisionSystem(CollisionSystem* p_CollisionSystem);
 
   std::string scriptFileName() const;
   std::string scriptSource() const;
@@ -126,7 +123,7 @@ class Level {
   static int compareVersionNumbers(const std::string &i_v1, const std::string &i_v2);
 
   /* because some objects like entities have an internal movement */
-  void updateToTime(vapp::MotoGame& i_scene);
+  void updateToTime(MotoGame& i_scene);
   /* this method calls objects because rewind in replay can required some actions (like removing particles) */
 
   /* the entity will be destroyed by the level */
@@ -167,7 +164,7 @@ class Level {
   std::string m_pack;               /* In this level pack */
   std::string m_packNum;            /* value to sort levels */
   std::string m_fileName;
-  vapp::XMLDocument *m_xmlSource;    /* Plain XML source */      
+  XMLDocument *m_xmlSource;    /* Plain XML source */      
   std::string m_scriptFileName;     /* Script file name */      
   std::string m_scriptSource;       /* Script source code */
   std::string m_checkSum;
@@ -181,11 +178,11 @@ class Level {
   std::vector<Entity *> m_entitiesExterns;
   Entity               *m_startEntity; /* entity where the player start */
   bool m_isBodyLoaded;
-  vapp::CollisionSystem* m_pCollisionSystem;
+  CollisionSystem* m_pCollisionSystem;
   /* to avoid calculate it each frame */
   int  m_nbEntitiesToTake;
   std::string m_borderTexture;
-  SkyApparence m_sky;
+  SkyApparence* m_sky;
   bool m_isScripted;
 
   int m_numberLayer;
